import { UserAsResponse } from "../definitions/UserAsResponse";
import { ProjectComponentAsResponse } from "../definitions/ProjectComponentAsResponse";
import { IssueTypeDetailsAsResponse } from "../definitions/IssueTypeDetailsAsResponse";
import { VersionAsResponse } from "../definitions/VersionAsResponse";
import { AvatarUrlsBeanAsResponse } from "../definitions/AvatarUrlsBeanAsResponse";
import { ProjectCategoryAsResponse } from "../definitions/ProjectCategoryAsResponse";
import { HierarchyAsResponse } from "../definitions/HierarchyAsResponse";
import { ProjectPermissionsAsResponse } from "../definitions/ProjectPermissionsAsResponse";
import { ProjectInsightAsResponse } from "../definitions/ProjectInsightAsResponse";
import { ProjectLandingPageInfoAsResponse } from "../definitions/ProjectLandingPageInfoAsResponse";
export interface ProjectAsResponse {
    /**
     * Expand options that include additional project details in the response.
     */
    expand?: string;
    /**
     * The URL of the project details.
     */
    self?: string;
    /**
     * The ID of the project.
     */
    id?: string;
    /**
     * The key of the project.
     */
    key?: string;
    /**
     * A brief description of the project.
     */
    description?: string;
    /**
     * The username of the project lead.
     */
    lead?: UserAsResponse;
    /**
     * List of the components contained in the project.
     */
    components?: Array<ProjectComponentAsResponse>;
    /**
     * List of the issue types available in the project.
     */
    issueTypes?: Array<IssueTypeDetailsAsResponse>;
    /**
     * A link to information about this project, such as project documentation.
     */
    url?: string;
    /**
     * An email address associated with the project.
     */
    email?: string;
    /**
     * The default assignee when creating issues for this project.
     */
    assigneeType?: "PROJECT_LEAD" | "UNASSIGNED";
    /**
     * The versions defined in the project. For more information, see [Create version](#api-rest-api-3-version-post).
     */
    versions?: Array<VersionAsResponse>;
    /**
     * The name of the project.
     */
    name?: string;
    /**
     * The name and self URL for each role defined in the project. For more information, see [Create project role](#api-rest-api-3-role-post).
     */
    roles?: {
        [x: string]: string;
    };
    /**
     * The URLs of the project's avatars.
     */
    avatarUrls?: AvatarUrlsBeanAsResponse;
    /**
     * The category the project belongs to.
     */
    projectCategory?: ProjectCategoryAsResponse;
    /**
     * The [project type](https://confluence.atlassian.com/x/GwiiLQ#Jiraapplicationsoverview-Productfeaturesandprojecttypes) of the project.
     */
    projectTypeKey?: "software" | "service_desk" | "business";
    /**
     * Whether the project is simplified.
     */
    simplified?: boolean;
    /**
     * The type of the project.
     */
    style?: "classic" | "next-gen";
    /**
     * Whether the project is selected as a favorite.
     */
    favourite?: boolean;
    /**
     * Whether the project is private.
     */
    isPrivate?: boolean;
    /**
     * The issue type hierarchy for the project.
     */
    issueTypeHierarchy?: HierarchyAsResponse;
    /**
     * User permissions on the project
     */
    permissions?: ProjectPermissionsAsResponse;
    /**
     * Map of project properties
     */
    properties?: {
        [x: string]: any;
    };
    /**
     * Unique ID for next-gen projects.
     */
    uuid?: string;
    /**
     * Insights about the project.
     */
    insight?: ProjectInsightAsResponse;
    /**
     * Whether the project is marked as deleted.
     */
    deleted?: boolean;
    /**
     * The date when the project is deleted permanently.
     */
    retentionTillDate?: string;
    /**
     * The date when the project was marked as deleted.
     */
    deletedDate?: string;
    /**
     * The user who marked the project as deleted.
     */
    deletedBy?: UserAsResponse;
    /**
     * Whether the project is archived.
     */
    archived?: boolean;
    /**
     * The date when the project was archived.
     */
    archivedDate?: string;
    /**
     * The user who archived the project.
     */
    archivedBy?: UserAsResponse;
    /**
     * The project landing page info.
     */
    landingPageInfo?: ProjectLandingPageInfoAsResponse;
}
//# sourceMappingURL=ProjectAsResponse.d.ts.map