export interface ProjectComponentAsInlineObject {
    /**
     * The unique name for the component in the project. Required when creating a component. Optional when updating a component. The maximum length is 255 characters.
     */
    name: string;
    /**
     * The description for the component. Optional when creating or updating a component.
     */
    description?: string;
    /**
     * This property is no longer available and will be removed from the documentation soon. See the [deprecation notice](https://developer.atlassian.com/cloud/jira/platform/deprecation-notice-user-privacy-api-migration-guide/) for details.
     */
    leadUserName?: string;
    /**
     * The accountId of the component's lead user. The accountId uniquely identifies the user across all Atlassian products. For example, *5b10ac8d82e05b22cc7d4ef5*.
     */
    leadAccountId?: string;
    /**
  * The nominal user type used to determine the assignee for issues created with this component. See `realAssigneeType` for details on how the type of the user, and hence the user, assigned to issues is determined. Can take the following values:
  
   *  `PROJECT_LEAD` the assignee to any issues created with this component is nominally the lead for the project the component is in.
   *  `COMPONENT_LEAD` the assignee to any issues created with this component is nominally the lead for the component.
   *  `UNASSIGNED` an assignee is not set for issues created with this component.
   *  `PROJECT_DEFAULT` the assignee to any issues created with this component is nominally the default assignee for the project that the component is in.
  
  Default value: `PROJECT_DEFAULT`.
  Optional when creating or updating a component.
  */
    assigneeType?: "PROJECT_DEFAULT" | "COMPONENT_LEAD" | "PROJECT_LEAD" | "UNASSIGNED";
    /**
     * The key of the project the component is assigned to. Required when creating a component. Can't be updated.
     */
    project: string;
}
//# sourceMappingURL=ProjectComponentAsInlineObject.d.ts.map