import { AvatarUrlsBeanAsResponse } from "../definitions/AvatarUrlsBeanAsResponse";
import { SimpleListWrapperGroupNameAsResponse } from "../definitions/SimpleListWrapperGroupNameAsResponse";
import { SimpleListWrapperApplicationRoleAsResponse } from "../definitions/SimpleListWrapperApplicationRoleAsResponse";
export interface UserAsResponse {
    /**
     * The URL of the user.
     */
    self?: string;
    /**
     * The account ID of the user, which uniquely identifies the user across all Atlassian products. For example, *5b10ac8d82e05b22cc7d4ef5*. Required in requests.
     */
    accountId?: string;
    /**
  * The user account type. Can take the following values:
  
   *  `atlassian` regular Atlassian user account
   *  `app` system account used for Connect applications and OAuth to represent external systems
   *  `customer` Jira Service Desk account representing an external service desk
  */
    accountType?: "atlassian" | "app" | "customer" | "unknown";
    /**
     * The email address of the user. Depending on the user’s privacy setting, this may be returned as null.
     */
    emailAddress?: string;
    /**
     * The avatars of the user.
     */
    avatarUrls?: AvatarUrlsBeanAsResponse;
    /**
     * The display name of the user. Depending on the user’s privacy setting, this may return an alternative value.
     */
    displayName?: string;
    /**
     * Whether the user is active.
     */
    active?: boolean;
    /**
     * The time zone specified in the user's profile. Depending on the user’s privacy setting, this may be returned as null.
     */
    timeZone?: string;
    /**
     * The locale of the user. Depending on the user’s privacy setting, this may be returned as null.
     */
    locale?: string;
    /**
     * The groups that the user belongs to.
     */
    groups?: SimpleListWrapperGroupNameAsResponse;
    /**
     * The application roles the user is assigned to.
     */
    applicationRoles?: SimpleListWrapperApplicationRoleAsResponse;
    /**
     * Expand options that include additional user details in the response.
     */
    expand?: string;
}
//# sourceMappingURL=UserAsResponse.d.ts.map