import { Visibility } from "../definitions/Visibility";
import { EntityProperty } from "../definitions/EntityProperty";
import { AtlassianDocumentFormat } from "@avst-lib/jira-cloud/types/adf";
export interface WorklogAsInlineObject {
    /**
     * A comment about the worklog in [Atlassian Document Format](https://developer.atlassian.com/cloud/jira/platform/apis/document/structure/). Optional when creating or updating a worklog.
     */
    comment?: AtlassianDocumentFormat;
    /**
     * Details about any restrictions in the visibility of the worklog. Optional when creating or updating a worklog.
     */
    visibility?: Visibility;
    /**
     * The datetime on which the worklog effort was started. Required when creating a worklog. Optional when updating a worklog.
     */
    started: string;
    /**
     * The time spent working on the issue as days (\#d), hours (\#h), or minutes (\#m or \#). Required when creating a worklog if `timeSpentSeconds` isn't provided. Optional when updating a worklog. Cannot be provided if `timeSpentSecond` is provided.
     */
    timeSpent?: string;
    /**
     * The time in seconds spent working on the issue. Required when creating a worklog if `timeSpent` isn't provided. Optional when updating a worklog. Cannot be provided if `timeSpent` is provided.
     */
    timeSpentSeconds?: number;
    /**
     * Details of properties for the worklog. Optional when creating or updating a worklog.
     */
    properties?: Array<EntityProperty>;
    [x: string]: any;
}
//# sourceMappingURL=WorklogAsInlineObject.d.ts.map