import { Dashboard } from "../types/dashboard";
/**
* Returns a list of dashboards owned by or shared with the user. The list may be filtered to include only favorite or owned dashboards.

This operation can be accessed anonymously.

**[Permissions](#permissions) required:** None.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-dashboards/#api-rest-api-3-dashboard-get
* @param options Request options.
*/
export declare function getDashboards<T = Dashboard.GetDashboards.Response.OK>(options: Dashboard.GetDashboards.Options.HandledApi): Promise<import("../definitions/PageOfDashboardsAsResponse").PageOfDashboardsAsResponse>;
/**
* Creates a dashboard.

**[Permissions](#permissions) required:** None.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-dashboards/#api-rest-api-3-dashboard-post
* @param options Request options.
*/
export declare function createDashboard<T = Dashboard.CreateDashboard.Response.OK>(options: Dashboard.CreateDashboard.Options.HandledApi): Promise<import("../definitions/DashboardAsResponse").DashboardAsResponse>;
/**
* Returns a [paginated](#pagination) list of dashboards. This operation is similar to [Get dashboards](#api-rest-api-3-dashboard-get) except that the results can be refined to include dashboards that have specific attributes. For example, dashboards with a particular name. When multiple attributes are specified only filters matching all attributes are returned.

This operation can be accessed anonymously.

**[Permissions](#permissions) required:** The following dashboards that match the query parameters are returned:

 *  Dashboards owned by the user. Not returned for anonymous users.
 *  Dashboards shared with a group that the user is a member of. Not returned for anonymous users.
 *  Dashboards shared with a private project that the user can browse. Not returned for anonymous users.
 *  Dashboards shared with a public project.
 *  Dashboards shared with the public.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-dashboards/#api-rest-api-3-dashboard-search-get
* @param options Request options.
*/
export declare function searchDashboards<T = Dashboard.SearchDashboards.Response.OK>(options: Dashboard.SearchDashboards.Options.HandledApi): Promise<import("../definitions/PageBeanDashboardAsResponse").PageBeanDashboardAsResponse>;
/**
* Returns a dashboard.

This operation can be accessed anonymously.

**[Permissions](#permissions) required:** None.

However, to get a dashboard, the dashboard must be shared with the user or the user must own it. Note, users with the *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg) are considered owners of the System dashboard. The System dashboard is considered to be shared with all other users.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-dashboards/#api-rest-api-3-dashboard-id-get
* @param options Request options.
*/
export declare function getDashboard<T = Dashboard.GetDashboard.Response.OK>(options: Dashboard.GetDashboard.Options.HandledApi): Promise<import("../definitions/DashboardAsResponse").DashboardAsResponse>;
/**
* Updates a dashboard, replacing all the dashboard details with those provided.

**[Permissions](#permissions) required:** None

The dashboard to be updated must be owned by the user.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-dashboards/#api-rest-api-3-dashboard-id-put
* @param options Request options.
*/
export declare function updateDashboard<T = Dashboard.UpdateDashboard.Response.OK>(options: Dashboard.UpdateDashboard.Options.HandledApi): Promise<import("../definitions/DashboardAsResponse").DashboardAsResponse>;
/**
* Deletes a dashboard.

**[Permissions](#permissions) required:** None

The dashboard to be deleted must be owned by the user.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-dashboards/#api-rest-api-3-dashboard-id-delete
* @param options Request options.
*/
export declare function deleteDashboard<T = Dashboard.DeleteDashboard.Response.OK>(options: Dashboard.DeleteDashboard.Options.HandledApi): Promise<undefined>;
/**
* Copies a dashboard. Any values provided in the `dashboard` parameter replace those in the copied dashboard.

**[Permissions](#permissions) required:** None

The dashboard to be copied must be owned by or shared with the user.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-dashboards/#api-rest-api-3-dashboard-id-copy-post
* @param options Request options.
*/
export declare function copyDashboard<T = Dashboard.CopyDashboard.Response.OK>(options: Dashboard.CopyDashboard.Options.HandledApi): Promise<import("../definitions/DashboardAsResponse").DashboardAsResponse>;
//# sourceMappingURL=dashboard.d.ts.map