import { getDashboards as getDashboardsFn } from "../raw-api/dashboard";
import { executeRequest } from "../handled-api/common";
import { createDashboard as createDashboardFn } from "../raw-api/dashboard";
import { searchDashboards as searchDashboardsFn } from "../raw-api/dashboard";
import { getDashboard as getDashboardFn } from "../raw-api/dashboard";
import { updateDashboard as updateDashboardFn } from "../raw-api/dashboard";
import { deleteDashboard as deleteDashboardFn } from "../raw-api/dashboard";
import { copyDashboard as copyDashboardFn } from "../raw-api/dashboard";
/**
* Returns a list of dashboards owned by or shared with the user. The list may be filtered to include only favorite or owned dashboards.

This operation can be accessed anonymously.

**[Permissions](#permissions) required:** None.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-dashboards/#api-rest-api-3-dashboard-get
* @param options Request options.
*/
export function getDashboards(options) {
    return executeRequest(() => getDashboardsFn(options), options.errorStrategy);
}
/**
* Creates a dashboard.

**[Permissions](#permissions) required:** None.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-dashboards/#api-rest-api-3-dashboard-post
* @param options Request options.
*/
export function createDashboard(options) {
    return executeRequest(() => createDashboardFn(options), options.errorStrategy);
}
/**
* Returns a [paginated](#pagination) list of dashboards. This operation is similar to [Get dashboards](#api-rest-api-3-dashboard-get) except that the results can be refined to include dashboards that have specific attributes. For example, dashboards with a particular name. When multiple attributes are specified only filters matching all attributes are returned.

This operation can be accessed anonymously.

**[Permissions](#permissions) required:** The following dashboards that match the query parameters are returned:

 *  Dashboards owned by the user. Not returned for anonymous users.
 *  Dashboards shared with a group that the user is a member of. Not returned for anonymous users.
 *  Dashboards shared with a private project that the user can browse. Not returned for anonymous users.
 *  Dashboards shared with a public project.
 *  Dashboards shared with the public.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-dashboards/#api-rest-api-3-dashboard-search-get
* @param options Request options.
*/
export function searchDashboards(options) {
    return executeRequest(() => searchDashboardsFn(options), options.errorStrategy);
}
/**
* Returns a dashboard.

This operation can be accessed anonymously.

**[Permissions](#permissions) required:** None.

However, to get a dashboard, the dashboard must be shared with the user or the user must own it. Note, users with the *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg) are considered owners of the System dashboard. The System dashboard is considered to be shared with all other users.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-dashboards/#api-rest-api-3-dashboard-id-get
* @param options Request options.
*/
export function getDashboard(options) {
    return executeRequest(() => getDashboardFn(options), options.errorStrategy);
}
/**
* Updates a dashboard, replacing all the dashboard details with those provided.

**[Permissions](#permissions) required:** None

The dashboard to be updated must be owned by the user.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-dashboards/#api-rest-api-3-dashboard-id-put
* @param options Request options.
*/
export function updateDashboard(options) {
    return executeRequest(() => updateDashboardFn(options), options.errorStrategy);
}
/**
* Deletes a dashboard.

**[Permissions](#permissions) required:** None

The dashboard to be deleted must be owned by the user.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-dashboards/#api-rest-api-3-dashboard-id-delete
* @param options Request options.
*/
export function deleteDashboard(options) {
    return executeRequest(() => deleteDashboardFn(options), options.errorStrategy);
}
/**
* Copies a dashboard. Any values provided in the `dashboard` parameter replace those in the copied dashboard.

**[Permissions](#permissions) required:** None

The dashboard to be copied must be owned by or shared with the user.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-dashboards/#api-rest-api-3-dashboard-id-copy-post
* @param options Request options.
*/
export function copyDashboard(options) {
    return executeRequest(() => copyDashboardFn(options), options.errorStrategy);
}
