import { Filter } from "../types/filter";
/**
* Creates a filter. The filter is shared according to the [default share scope](#api-rest-api-3-filter-post). The filter is not selected as a favorite.

**[Permissions](#permissions) required:** Permission to access Jira.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-filter-post
* @param options Request options.
*/
export declare function createFilter<T = Filter.CreateFilter.Response.OK>(options: Filter.CreateFilter.Options.HandledApi): Promise<import("../definitions/FilterAsResponse").FilterAsResponse>;
/**
* Returns the filters owned by the user. If `includeFavourites` is `true`, the user's visible favorite filters are also returned.

**[Permissions](#permissions) required:** Permission to access Jira, however, a favorite filters is only visible to the user where the filter is:

 *  owned by the user.
 *  shared with a group that the user is a member of.
 *  shared with a private project that the user has *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for.
 *  shared with a public project.
 *  shared with the public.

For example, if the user favorites a public filter that is subsequently made private that filter is not returned by this operation.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-filter-my-get
* @param options Request options.
*/
export declare function getMyFilters<T = Filter.GetMyFilters.Response.OK>(options: Filter.GetMyFilters.Options.HandledApi): Promise<Filter.GetMyFilters.Response.OK>;
/**
* Returns a [paginated](#pagination) list of filters. Use this operation to get:

 *  specific filters, by defining `id` only.
 *  filters that match all of the specified attributes. For example, all filters for a user with a particular word in their name. When multiple attributes are specified only filters matching all attributes are returned.

This operation can be accessed anonymously.

**[Permissions](#permissions) required:** None, however, only the following filters that match the query parameters are returned:

 *  filters owned by the user.
 *  filters shared with a group that the user is a member of.
 *  filters shared with a private project that the user has *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for.
 *  filters shared with a public project.
 *  filters shared with the public.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-filter-search-get
* @param options Request options.
*/
export declare function searchFilters<T = Filter.SearchFilters.Response.OK>(options: Filter.SearchFilters.Options.HandledApi): Promise<import("../definitions/PageBeanFilterDetailsAsResponse").PageBeanFilterDetailsAsResponse>;
/**
* Returns a filter.

This operation can be accessed anonymously.

**[Permissions](#permissions) required:** None, however, the filter is only returned where it is:

 *  owned by the user.
 *  shared with a group that the user is a member of.
 *  shared with a private project that the user has *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for.
 *  shared with a public project.
 *  shared with the public.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-filter-id-get
* @param options Request options.
*/
export declare function getFilter<T = Filter.GetFilter.Response.OK>(options: Filter.GetFilter.Options.HandledApi): Promise<import("../definitions/FilterAsResponse").FilterAsResponse>;
/**
* Updates a filter. Use this operation to update a filter's name, description, JQL, or sharing.

**[Permissions](#permissions) required:** Permission to access Jira, however the user must own the filter.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-filter-id-put
* @param options Request options.
*/
export declare function updateFilter<T = Filter.UpdateFilter.Response.OK>(options: Filter.UpdateFilter.Options.HandledApi): Promise<import("../definitions/FilterAsResponse").FilterAsResponse>;
/**
* Delete a filter.

**[Permissions](#permissions) required:** Permission to access Jira, however filters can only be deleted by the creator of the filter or a user with *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-filter-id-delete
* @param options Request options.
*/
export declare function deleteFilter<T = Filter.DeleteFilter.Response.OK>(options: Filter.DeleteFilter.Options.HandledApi): Promise<undefined>;
//# sourceMappingURL=filter.d.ts.map