import { Filter } from "../../types/filter";
/**
* Returns the visible favorite filters of the user.

This operation can be accessed anonymously.

**[Permissions](#permissions) required:** A favorite filter is only visible to the user where the filter is:

 *  owned by the user.
 *  shared with a group that the user is a member of.
 *  shared with a private project that the user has *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for.
 *  shared with a public project.
 *  shared with the public.

For example, if the user favorites a public filter that is subsequently made private that filter is not returned by this operation.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-filter-favourite-get
* @param options Request options.
*/
export declare function getFavouriteFilters<T = Filter.Favourite.GetFilters.Response.OK>(options: Filter.Favourite.GetFilters.Options.HandledApi): Promise<Filter.Favourite.GetFilters.Response.OK>;
/**
* Add a filter as a favorite for the user.

**[Permissions](#permissions) required:** Permission to access Jira, however, the user can only favorite:

 *  filters owned by the user.
 *  filters shared with a group that the user is a member of.
 *  filters shared with a private project that the user has *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for.
 *  filters shared with a public project.
 *  filters shared with the public.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-filter-id-favourite-put
* @param options Request options.
*/
export declare function addFilterAsFavourite<T = Filter.Favourite.AddFilter.Response.OK>(options: Filter.Favourite.AddFilter.Options.HandledApi): Promise<import("../../definitions/FilterAsResponse").FilterAsResponse>;
/**
* Removes a filter as a favorite for the user. Note that this operation only removes filters visible to the user from the user's favorites list. For example, if the user favorites a public filter that is subsequently made private (and is therefore no longer visible on their favorites list) they cannot remove it from their favorites list.

**[Permissions](#permissions) required:** Permission to access Jira.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-filter-id-favourite-delete
* @param options Request options.
*/
export declare function removeFilterAsFavourite<T = Filter.Favourite.RemoveFilter.Response.OK>(options: Filter.Favourite.RemoveFilter.Options.HandledApi): Promise<import("../../definitions/FilterAsResponse").FilterAsResponse>;
//# sourceMappingURL=favourite.d.ts.map