import { getFiltersSharePermissions as getFiltersSharePermissionsFn } from "../../../raw-api/filter/share/permission";
import { executeRequest } from "../../../handled-api/common";
import { addFiltersSharePermission as addFiltersSharePermissionFn } from "../../../raw-api/filter/share/permission";
import { getFiltersSharePermission as getFiltersSharePermissionFn } from "../../../raw-api/filter/share/permission";
import { deleteFiltersSharePermission as deleteFiltersSharePermissionFn } from "../../../raw-api/filter/share/permission";
/**
* Returns the share permissions for a filter. A filter can be shared with groups, projects, all logged-in users, or the public. Sharing with all logged-in users or the public is known as a global share permission.

This operation can be accessed anonymously.

**[Permissions](#permissions) required:** None, however, share permissions are only returned for:

 *  filters owned by the user.
 *  filters shared with a group that the user is a member of.
 *  filters shared with a private project that the user has *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for.
 *  filters shared with a public project.
 *  filters shared with the public.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-filter-sharing/#api-rest-api-3-filter-id-permission-get
* @param options Request options.
*/
export function getFiltersSharePermissions(options) {
    return executeRequest(() => getFiltersSharePermissionsFn(options), options.errorStrategy);
}
/**
* Add a share permissions to a filter. If you add a global share permission (one for all logged-in users or the public) it will overwrite all share permissions for the filter.

Be aware that this operation uses different objects for updating share permissions compared to [Update filter](#api-rest-api-3-filter-id-put).

**[Permissions](#permissions) required:** *Share dashboards and filters* [global permission](https://confluence.atlassian.com/x/x4dKLg) and the user must own the filter.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-filter-sharing/#api-rest-api-3-filter-id-permission-post
* @param options Request options.
*/
export function addFiltersSharePermission(options) {
    return executeRequest(() => addFiltersSharePermissionFn(options), options.errorStrategy);
}
/**
* Returns a share permission for a filter. A filter can be shared with groups, projects, all logged-in users, or the public. Sharing with all logged-in users or the public is known as a global share permission.

This operation can be accessed anonymously.

**[Permissions](#permissions) required:** None, however, a share permission is only returned for:

 *  filters owned by the user.
 *  filters shared with a group that the user is a member of.
 *  filters shared with a private project that the user has *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for.
 *  filters shared with a public project.
 *  filters shared with the public.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-filter-sharing/#api-rest-api-3-filter-id-permission-permissionid-get
* @param options Request options.
*/
export function getFiltersSharePermission(options) {
    return executeRequest(() => getFiltersSharePermissionFn(options), options.errorStrategy);
}
/**
* Deletes a share permission from a filter.

**[Permissions](#permissions) required:** Permission to access Jira and the user must own the filter.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-filter-sharing/#api-rest-api-3-filter-id-permission-permissionid-delete
* @param options Request options.
*/
export function deleteFiltersSharePermission(options) {
    return executeRequest(() => deleteFiltersSharePermissionFn(options), options.errorStrategy);
}
