import { createGroup as createGroupFn } from "../raw-api/group";
import { executeRequest } from "../handled-api/common";
import { removeGroup as removeGroupFn } from "../raw-api/group";
import { findGroups as findGroupsFn } from "../raw-api/group";
/**
* Creates a group.

**[Permissions](#permissions) required:** Site administration (that is, member of the *site-admin* [group](https://confluence.atlassian.com/x/24xjL)).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-group-post
* @param options Request options.
*/
export function createGroup(options) {
    return executeRequest(() => createGroupFn(options), options.errorStrategy);
}
/**
* Deletes a group.

**[Permissions](#permissions) required:** Site administration (that is, member of the *site-admin* strategic [group](https://confluence.atlassian.com/x/24xjL)).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-group-delete
* @param options Request options.
*/
export function removeGroup(options) {
    return executeRequest(() => removeGroupFn(options), options.errorStrategy);
}
/**
* Returns a list of groups whose names contain a query string. A list of group names can be provided to exclude groups from the results.

The primary use case for this resource is to populate a group picker suggestions list. To this end, the returned object includes the `html` field where the matched query term is highlighted in the group name with the HTML strong tag. Also, the groups list is wrapped in a response object that contains a header for use in the picker, specifically *Showing X of Y matching groups*.

The list returns with the groups sorted. If no groups match the list criteria, an empty list is returned.

This operation can be accessed anonymously.

**[Permissions](#permissions) required:** *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg). Anonymous calls and calls by users without the required permission return an empty list.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-groups-picker-get
* @param options Request options.
*/
export function findGroups(options) {
    return executeRequest(() => findGroupsFn(options), options.errorStrategy);
}
