import { Group } from "../../types/group";
/**
* Returns a [paginated](#pagination) list of all users in a group.

Note that users are ordered by username, however the username is not returned in the results due to privacy reasons.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-group-member-get
* @param options Request options.
*/
export declare function getUsersFromGroup<T = Group.User.GetUsers.Response.OK>(options: Group.User.GetUsers.Options.HandledApi): Promise<import("../../definitions/PageBeanUserDetailsAsResponse").PageBeanUserDetailsAsResponse>;
/**
* Adds a user to a group.

**[Permissions](#permissions) required:** Site administration (that is, member of the *site-admin* [group](https://confluence.atlassian.com/x/24xjL)).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-group-user-post
* @param options Request options.
*/
export declare function addUserToGroup<T = Group.User.AddUser.Response.OK>(options: Group.User.AddUser.Options.HandledApi): Promise<import("../../definitions/GroupAsResponse").GroupAsResponse>;
/**
* Removes a user from a group.

**[Permissions](#permissions) required:** Site administration (that is, member of the *site-admin* [group](https://confluence.atlassian.com/x/24xjL)).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-group-user-delete
* @param options Request options.
*/
export declare function removeUserFromGroup<T = Group.User.RemoveUser.Response.OK>(options: Group.User.RemoveUser.Options.HandledApi): Promise<undefined>;
//# sourceMappingURL=user.d.ts.map