import { getUsersFromGroup as getUsersFromGroupFn } from "../../raw-api/group/user";
import { executeRequest } from "../../handled-api/common";
import { addUserToGroup as addUserToGroupFn } from "../../raw-api/group/user";
import { removeUserFromGroup as removeUserFromGroupFn } from "../../raw-api/group/user";
/**
* Returns a [paginated](#pagination) list of all users in a group.

Note that users are ordered by username, however the username is not returned in the results due to privacy reasons.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-group-member-get
* @param options Request options.
*/
export function getUsersFromGroup(options) {
    return executeRequest(() => getUsersFromGroupFn(options), options.errorStrategy);
}
/**
* Adds a user to a group.

**[Permissions](#permissions) required:** Site administration (that is, member of the *site-admin* [group](https://confluence.atlassian.com/x/24xjL)).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-group-user-post
* @param options Request options.
*/
export function addUserToGroup(options) {
    return executeRequest(() => addUserToGroupFn(options), options.errorStrategy);
}
/**
* Removes a user from a group.

**[Permissions](#permissions) required:** Site administration (that is, member of the *site-admin* [group](https://confluence.atlassian.com/x/24xjL)).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-group-user-delete
* @param options Request options.
*/
export function removeUserFromGroup(options) {
    return executeRequest(() => removeUserFromGroupFn(options), options.errorStrategy);
}
