import { Issue } from "../../types/issue";
/**
* Returns a [paginated](#pagination) list of comments specified by a list of comment IDs.

This operation can be accessed anonymously.

**[Permissions](#permissions) required:** Comments are returned where the user:

 *  has *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project containing the comment.
 *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
 *  If the comment has visibility restrictions, belongs to the group or has the role visibility is restricted to.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-comment-list-post
* @param options Request options.
*/
export declare function getIssueCommentsByIds<T = Issue.Comment.GetCommentsByIds.Response.OK>(options: Issue.Comment.GetCommentsByIds.Options.HandledApi): Promise<import("../../definitions/PageBeanCommentAsResponse").PageBeanCommentAsResponse>;
/**
* Returns all comments for an issue.

This operation can be accessed anonymously.

**[Permissions](#permissions) required:** Comments are included in the response where the user has:

 *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project containing the comment.
 *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
 *  If the comment has visibility restrictions, belongs to the group or has the role visibility is role visibility is restricted to.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issue-issueIdOrKey-comment-get
* @param options Request options.
*/
export declare function getIssueComments<T = Issue.Comment.GetComments.Response.OK>(options: Issue.Comment.GetComments.Options.HandledApi): Promise<import("../../definitions/PageOfCommentsAsResponse").PageOfCommentsAsResponse>;
/**
* Adds a comment to an issue.

This operation can be accessed anonymously.

**[Permissions](#permissions) required:**

 *  *Browse projects* and *Add comments* [ project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue containing the comment is in.
 *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issue-issueIdOrKey-comment-post
* @param options Request options.
*/
export declare function addIssueComment<T = Issue.Comment.AddComment.Response.OK>(options: Issue.Comment.AddComment.Options.HandledApi): Promise<import("../../definitions/CommentAsResponse").CommentAsResponse>;
/**
* Returns a comment.

This operation can be accessed anonymously.

**[Permissions](#permissions) required:**

 *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project containing the comment.
 *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
 *  If the comment has visibility restrictions, the user belongs to the group or has the role visibility is restricted to.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issue-issueIdOrKey-comment-id-get
* @param options Request options.
*/
export declare function getIssueComment<T = Issue.Comment.GetComment.Response.OK>(options: Issue.Comment.GetComment.Options.HandledApi): Promise<import("../../definitions/CommentAsResponse").CommentAsResponse>;
/**
* Updates a comment.

This operation can be accessed anonymously.

**[Permissions](#permissions) required:**

 *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue containing the comment is in.
 *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
 *  *Edit all comments*[ project permission](https://confluence.atlassian.com/x/yodKLg) to update any comment or *Edit own comments* to update comment created by the user.
 *  If the comment has visibility restrictions, the user belongs to the group or has the role visibility is restricted to.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issue-issueIdOrKey-comment-id-put
* @param options Request options.
*/
export declare function updateIssueComment<T = Issue.Comment.UpdateComment.Response.OK>(options: Issue.Comment.UpdateComment.Options.HandledApi): Promise<import("../../definitions/CommentAsResponse").CommentAsResponse>;
/**
* Deletes a comment.

**[Permissions](#permissions) required:**

 *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue containing the comment is in.
 *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
 *  *Delete all comments*[ project permission](https://confluence.atlassian.com/x/yodKLg) to delete any comment or *Delete own comments* to delete comment created by the user,
 *  If the comment has visibility restrictions, the user belongs to the group or has the role visibility is restricted to.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issue-issueIdOrKey-comment-id-delete
* @param options Request options.
*/
export declare function deleteIssueComment<T = Issue.Comment.DeleteComment.Response.OK>(options: Issue.Comment.DeleteComment.Options.HandledApi): Promise<undefined>;
//# sourceMappingURL=comment.d.ts.map