import { Issue } from "../../../types/issue";
/**
* Returns the keys of all the properties of a comment.

This operation can be accessed anonymously.

**[Permissions](#permissions) required:**

 *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project.
 *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
 *  If the comment has visibility restrictions, belongs to the group or has the role visibility is restricted to.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-comment-commentId-properties-get
* @param options Request options.
*/
export declare function getIssueCommentPropertyKeys<T = Issue.Comment.Property.GetKeys.Response.OK>(options: Issue.Comment.Property.GetKeys.Options.HandledApi): Promise<import("../../../definitions/PropertyKeysAsResponse").PropertyKeysAsResponse>;
/**
* Returns the value of a comment property.

This operation can be accessed anonymously.

**[Permissions](#permissions) required:**

 *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project.
 *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
 *  If the comment has visibility restrictions, belongs to the group or has the role visibility is restricted to.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-comment-commentId-properties-propertyKey-get
* @param options Request options.
*/
export declare function getIssueCommentProperty<T = Issue.Comment.Property.GetProperty.Response.OK>(options: Issue.Comment.Property.GetProperty.Options.HandledApi): Promise<import("../../../definitions/EntityPropertyAsResponse").EntityPropertyAsResponse>;
/**
* Creates or updates the value of a property for a comment. Use this resource to store custom data against a comment.

The value of the request body must be a [valid](http://tools.ietf.org/html/rfc4627), non-empty JSON blob. The maximum length is 32768 characters.

**[Permissions](#permissions) required:** either of:

 *  *Edit All Comments* [project permission](https://confluence.atlassian.com/x/yodKLg) to create or update the value of a property on any comment.
 *  *Edit Own Comments* [project permission](https://confluence.atlassian.com/x/yodKLg) to create or update the value of a property on a comment created by the user.

Also, when the visibility of a comment is restricted to a role or group the user must be a member of that role or group.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-comment-commentId-properties-propertyKey-put
* @param options Request options.
*/
export declare function setIssueCommentProperty<T = Issue.Comment.Property.SetProperty.Response.OK>(options: Issue.Comment.Property.SetProperty.Options.HandledApi): Promise<any>;
/**
* Deletes a comment property.

**[Permissions](#permissions) required:** either of:

 *  *Edit All Comments* [project permission](https://confluence.atlassian.com/x/yodKLg) to delete a property from any comment.
 *  *Edit Own Comments* [project permission](https://confluence.atlassian.com/x/yodKLg) to delete a property from a comment created by the user.

Also, when the visibility of a comment is restricted to a role or group the user must be a member of that role or group.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-comment-commentId-properties-propertyKey-delete
* @param options Request options.
*/
export declare function deleteIssueCommentProperty<T = Issue.Comment.Property.DeleteProperty.Response.OK>(options: Issue.Comment.Property.DeleteProperty.Options.HandledApi): Promise<undefined>;
//# sourceMappingURL=property.d.ts.map