import { getIssueCommentPropertyKeys as getIssueCommentPropertyKeysFn } from "../../../raw-api/issue/comment/property";
import { executeRequest } from "../../../handled-api/common";
import { getIssueCommentProperty as getIssueCommentPropertyFn } from "../../../raw-api/issue/comment/property";
import { setIssueCommentProperty as setIssueCommentPropertyFn } from "../../../raw-api/issue/comment/property";
import { deleteIssueCommentProperty as deleteIssueCommentPropertyFn } from "../../../raw-api/issue/comment/property";
/**
* Returns the keys of all the properties of a comment.

This operation can be accessed anonymously.

**[Permissions](#permissions) required:**

 *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project.
 *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
 *  If the comment has visibility restrictions, belongs to the group or has the role visibility is restricted to.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-comment-commentId-properties-get
* @param options Request options.
*/
export function getIssueCommentPropertyKeys(options) {
    return executeRequest(() => getIssueCommentPropertyKeysFn(options), options.errorStrategy);
}
/**
* Returns the value of a comment property.

This operation can be accessed anonymously.

**[Permissions](#permissions) required:**

 *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project.
 *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
 *  If the comment has visibility restrictions, belongs to the group or has the role visibility is restricted to.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-comment-commentId-properties-propertyKey-get
* @param options Request options.
*/
export function getIssueCommentProperty(options) {
    return executeRequest(() => getIssueCommentPropertyFn(options), options.errorStrategy);
}
/**
* Creates or updates the value of a property for a comment. Use this resource to store custom data against a comment.

The value of the request body must be a [valid](http://tools.ietf.org/html/rfc4627), non-empty JSON blob. The maximum length is 32768 characters.

**[Permissions](#permissions) required:** either of:

 *  *Edit All Comments* [project permission](https://confluence.atlassian.com/x/yodKLg) to create or update the value of a property on any comment.
 *  *Edit Own Comments* [project permission](https://confluence.atlassian.com/x/yodKLg) to create or update the value of a property on a comment created by the user.

Also, when the visibility of a comment is restricted to a role or group the user must be a member of that role or group.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-comment-commentId-properties-propertyKey-put
* @param options Request options.
*/
export function setIssueCommentProperty(options) {
    return executeRequest(() => setIssueCommentPropertyFn(options), options.errorStrategy);
}
/**
* Deletes a comment property.

**[Permissions](#permissions) required:** either of:

 *  *Edit All Comments* [project permission](https://confluence.atlassian.com/x/yodKLg) to delete a property from any comment.
 *  *Edit Own Comments* [project permission](https://confluence.atlassian.com/x/yodKLg) to delete a property from a comment created by the user.

Also, when the visibility of a comment is restricted to a role or group the user must be a member of that role or group.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-comment-commentId-properties-propertyKey-delete
* @param options Request options.
*/
export function deleteIssueCommentProperty(options) {
    return executeRequest(() => deleteIssueCommentPropertyFn(options), options.errorStrategy);
}
