import { createIssueFieldConfiguration as createIssueFieldConfigurationFn } from "../../../raw-api/issue/field/configuration";
import { executeRequest } from "../../../handled-api/common";
import { getIssueFieldConfigurations as getIssueFieldConfigurationsFn } from "../../../raw-api/issue/field/configuration";
import { updateIssueFieldConfiguration as updateIssueFieldConfigurationFn } from "../../../raw-api/issue/field/configuration";
import { deleteIssueFieldConfiguration as deleteIssueFieldConfigurationFn } from "../../../raw-api/issue/field/configuration";
import { getIssueFieldConfigurationItems as getIssueFieldConfigurationItemsFn } from "../../../raw-api/issue/field/configuration";
import { getIssueFieldConfigurationIssueTypeItems as getIssueFieldConfigurationIssueTypeItemsFn } from "../../../raw-api/issue/field/configuration";
import { getIssueFieldConfigurationSchemes as getIssueFieldConfigurationSchemesFn } from "../../../raw-api/issue/field/configuration";
/**
* Creates a field configuration. The field configuration is created with the same field properties as the default configuration, with all the fields being optional.

This operation can only create configurations for use in company-managed (classic) projects.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-field-configurations/#api-rest-api-3-fieldconfiguration-post
* @param options Request options.
*/
export function createIssueFieldConfiguration(options) {
    return executeRequest(() => createIssueFieldConfigurationFn(options), options.errorStrategy);
}
/**
* Returns a [paginated](#pagination) list of field configurations. The list can be for all field configurations or a subset determined by any combination of these criteria:

 *  a list of field configuration item IDs.
 *  whether the field configuration is a default.
 *  whether the field configuration name or description contains a query string.

Only field configurations used in company-managed (classic) projects are returned.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-fieldconfiguration-get
* @param options Request options.
*/
export function getIssueFieldConfigurations(options) {
    return executeRequest(() => getIssueFieldConfigurationsFn(options), options.errorStrategy);
}
/**
* Updates a field configuration. The name and the description provided in the request override the existing values.

This operation can only update configurations used in company-managed (classic) projects.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-field-configurations/#api-rest-api-3-fieldconfiguration-id-put
* @param options Request options.
*/
export function updateIssueFieldConfiguration(options) {
    return executeRequest(() => updateIssueFieldConfigurationFn(options), options.errorStrategy);
}
/**
* Deletes a field configuration.

This operation can only delete configurations used in company-managed (classic) projects.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-field-configurations/#api-rest-api-3-fieldconfiguration-id-delete
* @param options Request options.
*/
export function deleteIssueFieldConfiguration(options) {
    return executeRequest(() => deleteIssueFieldConfigurationFn(options), options.errorStrategy);
}
/**
* Returns a [paginated](#pagination) list of all fields for a configuration.

Only the fields from configurations used in company-managed (classic) projects are returned.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-fieldconfiguration-id-fields-get
* @param options Request options.
*/
export function getIssueFieldConfigurationItems(options) {
    return executeRequest(() => getIssueFieldConfigurationItemsFn(options), options.errorStrategy);
}
/**
* Returns a [paginated](#pagination) list of field configuration issue type items.

Only items used in classic projects are returned.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-fieldconfigurationscheme-mapping-get
* @param options Request options.
*/
export function getIssueFieldConfigurationIssueTypeItems(options) {
    return executeRequest(() => getIssueFieldConfigurationIssueTypeItemsFn(options), options.errorStrategy);
}
/**
* Returns a [paginated](#pagination) list of field configuration schemes.

Only field configuration schemes used in classic projects are returned.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-field-configurations/#api-rest-api-3-fieldconfigurationscheme-get
* @param options Request options.
*/
export function getIssueFieldConfigurationSchemes(options) {
    return executeRequest(() => getIssueFieldConfigurationSchemesFn(options), options.errorStrategy);
}
