import { getIssueFieldConfigurationSchemesForProjects as getIssueFieldConfigurationSchemesForProjectsFn } from "../../../../raw-api/issue/field/configuration/scheme";
import { executeRequest } from "../../../../handled-api/common";
import { assignIssueFieldConfigurationSchemeToProject as assignIssueFieldConfigurationSchemeToProjectFn } from "../../../../raw-api/issue/field/configuration/scheme";
/**
* Returns a [paginated](#pagination) list of field configuration schemes and, for each scheme, a list of the projects that use it.

The list is sorted by field configuration scheme ID. The first item contains the list of project IDs assigned to the default field configuration scheme.

Only field configuration schemes used in classic projects are returned.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-fieldconfigurationscheme-project-get
* @param options Request options.
*/
export function getIssueFieldConfigurationSchemesForProjects(options) {
    return executeRequest(() => getIssueFieldConfigurationSchemesForProjectsFn(options), options.errorStrategy);
}
/**
* Assigns a field configuration scheme to a project. If the field configuration scheme ID is `null`, the operation assigns the default field configuration scheme.

Field configuration schemes can only be assigned to classic projects.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-field-configurations/#api-rest-api-3-fieldconfigurationscheme-project-put
* @param options Request options.
*/
export function assignIssueFieldConfigurationSchemeToProject(options) {
    return executeRequest(() => assignIssueFieldConfigurationSchemeToProjectFn(options), options.errorStrategy);
}
