import { getRemoteIssueLinks as getRemoteIssueLinksFn } from "../../../raw-api/issue/link/remote";
import { executeRequest } from "../../../handled-api/common";
import { createOrUpdateRemoteIssueLink as createOrUpdateRemoteIssueLinkFn } from "../../../raw-api/issue/link/remote";
import { deleteRemoteIssueLinkByGlobalId as deleteRemoteIssueLinkByGlobalIdFn } from "../../../raw-api/issue/link/remote";
import { getRemoteIssueLink as getRemoteIssueLinkFn } from "../../../raw-api/issue/link/remote";
import { updateRemoteIssueLink as updateRemoteIssueLinkFn } from "../../../raw-api/issue/link/remote";
import { deleteRemoteIssueLink as deleteRemoteIssueLinkFn } from "../../../raw-api/issue/link/remote";
/**
* Returns the remote issue links for an issue. When a remote issue link global ID is provided the record with that global ID is returned, otherwise all remote issue links are returned. Where a global ID includes reserved URL characters these must be escaped in the request. For example, pass `system=http://www.mycompany.com/support&id=1` as `system%3Dhttp%3A%2F%2Fwww.mycompany.com%2Fsupport%26id%3D1`.

This operation requires [issue linking to be active](https://confluence.atlassian.com/x/yoXKM).

This operation can be accessed anonymously.

**[Permissions](#permissions) required:**

 *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
 *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issue-issueIdOrKey-remotelink-get
* @param options Request options.
*/
export function getRemoteIssueLinks(options) {
    return executeRequest(() => getRemoteIssueLinksFn(options), options.errorStrategy);
}
/**
* Creates or updates a remote issue link for an issue.

If a `globalId` is provided and a remote issue link with that global ID is found it is updated. Any fields without values in the request are set to null. Otherwise, the remote issue link is created.

This operation requires [issue linking to be active](https://confluence.atlassian.com/x/yoXKM).

This operation can be accessed anonymously.

**[Permissions](#permissions) required:**

 *  *Browse projects* and *Link issues* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
 *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issue-issueIdOrKey-remotelink-post
* @param options Request options.
*/
export function createOrUpdateRemoteIssueLink(options) {
    return executeRequest(() => createOrUpdateRemoteIssueLinkFn(options), options.errorStrategy);
}
/**
* Deletes the remote issue link from the issue using the link's global ID. Where the global ID includes reserved URL characters these must be escaped in the request. For example, pass `system=http://www.mycompany.com/support&id=1` as `system%3Dhttp%3A%2F%2Fwww.mycompany.com%2Fsupport%26id%3D1`.

This operation requires [issue linking to be active](https://confluence.atlassian.com/x/yoXKM).

This operation can be accessed anonymously.

**[Permissions](#permissions) required:**

 *  *Browse projects* and *Link issues* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
 *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is implemented, issue-level security permission to view the issue.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issue-issueIdOrKey-remotelink-delete
* @param options Request options.
*/
export function deleteRemoteIssueLinkByGlobalId(options) {
    return executeRequest(() => deleteRemoteIssueLinkByGlobalIdFn(options), options.errorStrategy);
}
/**
* Returns a remote issue link for an issue.

This operation requires [issue linking to be active](https://confluence.atlassian.com/x/yoXKM).

This operation can be accessed anonymously.

**[Permissions](#permissions) required:**

 *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
 *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issue-issueIdOrKey-remotelink-linkId-get
* @param options Request options.
*/
export function getRemoteIssueLink(options) {
    return executeRequest(() => getRemoteIssueLinkFn(options), options.errorStrategy);
}
/**
* Updates a remote issue link for an issue.

Note: Fields without values in the request are set to null.

This operation requires [issue linking to be active](https://confluence.atlassian.com/x/yoXKM).

This operation can be accessed anonymously.

**[Permissions](#permissions) required:**

 *  *Browse projects* and *Link issues* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
 *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issue-issueIdOrKey-remotelink-linkId-put
* @param options Request options.
*/
export function updateRemoteIssueLink(options) {
    return executeRequest(() => updateRemoteIssueLinkFn(options), options.errorStrategy);
}
/**
* Deletes a remote issue link from an issue.

This operation requires [issue linking to be active](https://confluence.atlassian.com/x/yoXKM).

This operation can be accessed anonymously.

**[Permissions](#permissions) required:**

 *  *Browse projects*, *Edit issues*, and *Link issues* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
 *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issue-issueIdOrKey-remotelink-linkId-delete
* @param options Request options.
*/
export function deleteRemoteIssueLink(options) {
    return executeRequest(() => deleteRemoteIssueLinkFn(options), options.errorStrategy);
}
