import { Issue } from "../../../types/issue";
/**
* Returns a list of all issue link types.

To use this operation, the site must have [issue linking](https://confluence.atlassian.com/x/yoXKM) enabled.

This operation can be accessed anonymously.

**[Permissions](#permissions) required:** *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for a project in the site.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issueLinkType-get
* @param options Request options.
*/
export declare function getIssueLinkTypes<T = Issue.Link.Type.GetTypes.Response.OK>(options: Issue.Link.Type.GetTypes.Options.HandledApi): Promise<import("../../../definitions/IssueLinkTypesAsResponse").IssueLinkTypesAsResponse>;
/**
* Creates an issue link type. Use this operation to create descriptions of the reasons why issues are linked. The issue link type consists of a name and descriptions for a link's inward and outward relationships.

To use this operation, the site must have [issue linking](https://confluence.atlassian.com/x/yoXKM) enabled.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issueLinkType-post
* @param options Request options.
*/
export declare function createIssueLinkType<T = Issue.Link.Type.CreateType.Response.OK>(options: Issue.Link.Type.CreateType.Options.HandledApi): Promise<import("../../../definitions/IssueLinkTypeAsResponse").IssueLinkTypeAsResponse>;
/**
* Returns an issue link type.

To use this operation, the site must have [issue linking](https://confluence.atlassian.com/x/yoXKM) enabled.

This operation can be accessed anonymously.

**[Permissions](#permissions) required:** *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for a project in the site.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issueLinkType-issueLinkTypeId-get
* @param options Request options.
*/
export declare function getIssueLinkType<T = Issue.Link.Type.GetType.Response.OK>(options: Issue.Link.Type.GetType.Options.HandledApi): Promise<import("../../../definitions/IssueLinkTypeAsResponse").IssueLinkTypeAsResponse>;
/**
* Updates an issue link type.

To use this operation, the site must have [issue linking](https://confluence.atlassian.com/x/yoXKM) enabled.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issueLinkType-issueLinkTypeId-put
* @param options Request options.
*/
export declare function updateIssueLinkType<T = Issue.Link.Type.UpdateType.Response.OK>(options: Issue.Link.Type.UpdateType.Options.HandledApi): Promise<import("../../../definitions/IssueLinkTypeAsResponse").IssueLinkTypeAsResponse>;
/**
* Deletes an issue link type.

To use this operation, the site must have [issue linking](https://confluence.atlassian.com/x/yoXKM) enabled.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issueLinkType-issueLinkTypeId-delete
* @param options Request options.
*/
export declare function deleteIssueLinkType<T = Issue.Link.Type.DeleteType.Response.OK>(options: Issue.Link.Type.DeleteType.Options.HandledApi): Promise<undefined>;
//# sourceMappingURL=type.d.ts.map