import { getIssueLinkTypes as getIssueLinkTypesFn } from "../../../raw-api/issue/link/type";
import { executeRequest } from "../../../handled-api/common";
import { createIssueLinkType as createIssueLinkTypeFn } from "../../../raw-api/issue/link/type";
import { getIssueLinkType as getIssueLinkTypeFn } from "../../../raw-api/issue/link/type";
import { updateIssueLinkType as updateIssueLinkTypeFn } from "../../../raw-api/issue/link/type";
import { deleteIssueLinkType as deleteIssueLinkTypeFn } from "../../../raw-api/issue/link/type";
/**
* Returns a list of all issue link types.

To use this operation, the site must have [issue linking](https://confluence.atlassian.com/x/yoXKM) enabled.

This operation can be accessed anonymously.

**[Permissions](#permissions) required:** *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for a project in the site.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issueLinkType-get
* @param options Request options.
*/
export function getIssueLinkTypes(options) {
    return executeRequest(() => getIssueLinkTypesFn(options), options.errorStrategy);
}
/**
* Creates an issue link type. Use this operation to create descriptions of the reasons why issues are linked. The issue link type consists of a name and descriptions for a link's inward and outward relationships.

To use this operation, the site must have [issue linking](https://confluence.atlassian.com/x/yoXKM) enabled.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issueLinkType-post
* @param options Request options.
*/
export function createIssueLinkType(options) {
    return executeRequest(() => createIssueLinkTypeFn(options), options.errorStrategy);
}
/**
* Returns an issue link type.

To use this operation, the site must have [issue linking](https://confluence.atlassian.com/x/yoXKM) enabled.

This operation can be accessed anonymously.

**[Permissions](#permissions) required:** *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for a project in the site.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issueLinkType-issueLinkTypeId-get
* @param options Request options.
*/
export function getIssueLinkType(options) {
    return executeRequest(() => getIssueLinkTypeFn(options), options.errorStrategy);
}
/**
* Updates an issue link type.

To use this operation, the site must have [issue linking](https://confluence.atlassian.com/x/yoXKM) enabled.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issueLinkType-issueLinkTypeId-put
* @param options Request options.
*/
export function updateIssueLinkType(options) {
    return executeRequest(() => updateIssueLinkTypeFn(options), options.errorStrategy);
}
/**
* Deletes an issue link type.

To use this operation, the site must have [issue linking](https://confluence.atlassian.com/x/yoXKM) enabled.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issueLinkType-issueLinkTypeId-delete
* @param options Request options.
*/
export function deleteIssueLinkType(options) {
    return executeRequest(() => deleteIssueLinkTypeFn(options), options.errorStrategy);
}
