import { getIssueNavigatorDefaultColumns as getIssueNavigatorDefaultColumnsFn } from "../../raw-api/issue/navigator";
import { executeRequest } from "../../handled-api/common";
import { setIssueNavigatorDefaultColumns as setIssueNavigatorDefaultColumnsFn } from "../../raw-api/issue/navigator";
/**
* Returns the default issue navigator columns.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-navigator-settings/#api-rest-api-3-settings-columns-get
* @param options Request options.
*/
export function getIssueNavigatorDefaultColumns(options) {
    return executeRequest(() => getIssueNavigatorDefaultColumnsFn(options), options.errorStrategy);
}
/**
* Sets the default issue navigator columns.

The `columns` parameter accepts a navigable field value and is expressed as HTML form data. To specify multiple columns, pass multiple `columns` parameters. For example, in curl:

`curl -X PUT -d columns=summary -d columns=description https://your-domain.atlassian.net/rest/api/3/settings/columns`

If no column details are sent, then all default columns are removed.

A navigable field is one that can be used as a column on the issue navigator. Find details of navigable issue columns using [Get fields](#api-rest-api-3-field-get).

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-navigator-settings/#api-rest-api-3-settings-columns-put
* @param options Request options.
*/
export function setIssueNavigatorDefaultColumns(options) {
    return executeRequest(() => setIssueNavigatorDefaultColumnsFn(options), options.errorStrategy);
}
