import { getIssuePropertyKeys as getIssuePropertyKeysFn } from "../../raw-api/issue/property";
import { executeRequest } from "../../handled-api/common";
import { getIssueProperty as getIssuePropertyFn } from "../../raw-api/issue/property";
import { setIssueProperty as setIssuePropertyFn } from "../../raw-api/issue/property";
import { deleteIssueProperty as deleteIssuePropertyFn } from "../../raw-api/issue/property";
/**
* Returns the URLs and keys of an issue's properties.

This operation can be accessed anonymously.

**[Permissions](#permissions) required:** Property details are only returned where the user has:

 *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project containing the issue.
 *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issue-issueIdOrKey-properties-get
* @param options Request options.
*/
export function getIssuePropertyKeys(options) {
    return executeRequest(() => getIssuePropertyKeysFn(options), options.errorStrategy);
}
/**
* Returns the key and value of an issue's property.

This operation can be accessed anonymously.

**[Permissions](#permissions) required:**

 *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project containing the issue.
 *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issue-issueIdOrKey-properties-propertyKey-get
* @param options Request options.
*/
export function getIssueProperty(options) {
    return executeRequest(() => getIssuePropertyFn(options), options.errorStrategy);
}
/**
* Sets the value of an issue's property. Use this resource to store custom data against an issue.

The value of the request body must be a [valid](http://tools.ietf.org/html/rfc4627), non-empty JSON blob. The maximum length is 32768 characters.

This operation can be accessed anonymously.

**[Permissions](#permissions) required:**

 *  *Browse projects* and *Edit issues* [project permissions](https://confluence.atlassian.com/x/yodKLg) for the project containing the issue.
 *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issue-issueIdOrKey-properties-propertyKey-put
* @param options Request options.
*/
export function setIssueProperty(options) {
    return executeRequest(() => setIssuePropertyFn(options), options.errorStrategy);
}
/**
* Deletes an issue's property.

This operation can be accessed anonymously.

**[Permissions](#permissions) required:**

 *  *Browse projects* and *Edit issues* [project permissions](https://confluence.atlassian.com/x/yodKLg) for the project containing the issue.
 *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issue-issueIdOrKey-properties-propertyKey-delete
* @param options Request options.
*/
export function deleteIssueProperty(options) {
    return executeRequest(() => deleteIssuePropertyFn(options), options.errorStrategy);
}
