import { getIssueSecurityMembers as getIssueSecurityMembersFn } from "../../raw-api/issue/security";
import { executeRequest } from "../../handled-api/common";
import { getIssueSecurityLevel as getIssueSecurityLevelFn } from "../../raw-api/issue/security";
/**
* Returns issue security level members.

Only issue security level members in context of classic projects are returned.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issuesecurityschemes-issueSecuritySchemeId-members-get
* @param options Request options.
*/
export function getIssueSecurityMembers(options) {
    return executeRequest(() => getIssueSecurityMembersFn(options), options.errorStrategy);
}
/**
* Returns details of an issue security level.

Use [Get issue security scheme](#api-rest-api-3-issuesecurityschemes-id-get) to obtain the IDs of issue security levels associated with the issue security scheme.

This operation can be accessed anonymously.

**[Permissions](#permissions) required:** None.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-security-level/#api-rest-api-3-securitylevel-id-get
* @param options Request options.
*/
export function getIssueSecurityLevel(options) {
    return executeRequest(() => getIssueSecurityLevelFn(options), options.errorStrategy);
}
