import { getIssueSecuritySchemes as getIssueSecuritySchemesFn } from "../../../raw-api/issue/security/scheme";
import { executeRequest } from "../../../handled-api/common";
import { getIssueSecurityScheme as getIssueSecuritySchemeFn } from "../../../raw-api/issue/security/scheme";
/**
* Returns all [issue security schemes](https://confluence.atlassian.com/x/J4lKLg).

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-security-schemes/#api-rest-api-3-issuesecurityschemes-get
* @param options Request options.
*/
export function getIssueSecuritySchemes(options) {
    return executeRequest(() => getIssueSecuritySchemesFn(options), options.errorStrategy);
}
/**
* Returns an issue security scheme along with its security levels.

**[Permissions](#permissions) required:**

 *  *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
 *  *Administer Projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for a project that uses the requested issue security scheme.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-security-schemes/#api-rest-api-3-issuesecurityschemes-id-get
* @param options Request options.
*/
export function getIssueSecurityScheme(options) {
    return executeRequest(() => getIssueSecuritySchemeFn(options), options.errorStrategy);
}
