import { Issue } from "../../types/issue";
/**
* Returns all issue types.

This operation can be accessed anonymously.

**[Permissions](#permissions) required:** Issue types are only returned as follows:

 *  if the user has the *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg), all issue types are returned.
 *  if the user has the *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for one or more projects, the issue types associated with the projects the user has permission to browse are returned.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issuetype-get
* @param options Request options.
*/
export declare function getIssueTypesForUser<T = Issue.Type.GetTypesForUser.Response.OK>(options: Issue.Type.GetTypesForUser.Options.HandledApi): Promise<Issue.Type.GetTypesForUser.Response.OK>;
/**
* Creates an issue type and adds it to the default issue type scheme.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issuetype-post
* @param options Request options.
*/
export declare function createIssueType<T = Issue.Type.CreateType.Response.OK>(options: Issue.Type.CreateType.Options.HandledApi): Promise<import("../../definitions/IssueTypeDetailsAsResponse").IssueTypeDetailsAsResponse>;
/**
* Returns issue types for a project.

This operation can be accessed anonymously.

**[Permissions](#permissions) required:** *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) in the relevant project or *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-types/#api-rest-api-3-issuetype-project-get
* @param options Request options.
*/
export declare function getIssueTypesForProject<T = Issue.Type.GetTypesForProject.Response.OK>(options: Issue.Type.GetTypesForProject.Options.HandledApi): Promise<Issue.Type.GetTypesForProject.Response.OK>;
/**
* Returns an issue type.

This operation can be accessed anonymously.

**[Permissions](#permissions) required:** *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) in a project the issue type is associated with or *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issuetype-id-get
* @param options Request options.
*/
export declare function getIssueType<T = Issue.Type.GetType.Response.OK>(options: Issue.Type.GetType.Options.HandledApi): Promise<import("../../definitions/IssueTypeDetailsAsResponse").IssueTypeDetailsAsResponse>;
/**
* Updates the issue type.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issuetype-id-put
* @param options Request options.
*/
export declare function updateIssueType<T = Issue.Type.UpdateType.Response.OK>(options: Issue.Type.UpdateType.Options.HandledApi): Promise<import("../../definitions/IssueTypeDetailsAsResponse").IssueTypeDetailsAsResponse>;
/**
* Deletes the issue type. If the issue type is in use, all uses are updated with the alternative issue type (`alternativeIssueTypeId`). A list of alternative issue types are obtained from the [Get alternative issue types](#api-rest-api-3-issuetype-id-alternatives-get) resource.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issuetype-id-delete
* @param options Request options.
*/
export declare function deleteIssueType<T = Issue.Type.DeleteType.Response.OK>(options: Issue.Type.DeleteType.Options.HandledApi): Promise<undefined>;
/**
* Returns a list of issue types that can be used to replace the issue type. The alternative issue types are those assigned to the same workflow scheme, field configuration scheme, and screen scheme.

This operation can be accessed anonymously.

**[Permissions](#permissions) required:** None.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issuetype-id-alternatives-get
* @param options Request options.
*/
export declare function getAlternativeIssueTypes<T = Issue.Type.GetAlternativeTypes.Response.OK>(options: Issue.Type.GetAlternativeTypes.Options.HandledApi): Promise<Issue.Type.GetAlternativeTypes.Response.OK>;
/**
* Loads an avatar for the issue type.

Specify the avatar's local file location in the body of the request. Also, include the following headers:

 *  `X-Atlassian-Token: no-check` To prevent XSRF protection blocking the request, for more information see [Special Headers](#special-request-headers).
 *  `Content-Type: image/image type` Valid image types are JPEG, GIF, or PNG.

For example:
`curl --request POST \ --user email@example.com:<api_token> \ --header 'X-Atlassian-Token: no-check' \ --header 'Content-Type: image/< image_type>' \ --data-binary "<@/path/to/file/with/your/avatar>" \ --url 'https://your-domain.atlassian.net/rest/api/3/issuetype/{issueTypeId}'This`

The avatar is cropped to a square. If no crop parameters are specified, the square originates at the top left of the image. The length of the square's sides is set to the smaller of the height or width of the image.

The cropped image is then used to create avatars of 16x16, 24x24, 32x32, and 48x48 in size.

After creating the avatar, use [ Update issue type](#api-rest-api-3-issuetype-id-put) to set it as the issue type's displayed avatar.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issuetype-id-avatar2-post
* @param options Request options.
*/
export declare function loadIssueTypeAvatar<T = Issue.Type.LoadTypeAvatar.Response.OK>(options: Issue.Type.LoadTypeAvatar.Options.HandledApi): Promise<import("../../definitions/AvatarAsResponse").AvatarAsResponse>;
//# sourceMappingURL=type.d.ts.map