import { Issue } from "../../../types/issue";
/**
* Returns all the [issue type property](https://developer.atlassian.com/cloud/jira/platform/storing-data-without-a-database/#a-id-jira-entity-properties-a-jira-entity-properties) keys of the issue type.

This operation can be accessed anonymously.

**[Permissions](#permissions) required:**

 *  *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg) to get the property keys of any issue type.
 *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) to get the property keys of any issue types associated with the projects the user has permission to browse.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-type-properties/#api-rest-api-3-issuetype-issuetypeid-properties-get
* @param options Request options.
*/
export declare function getIssueTypePropertyKeys<T = Issue.Type.Property.GetPropertyKeys.Response.OK>(options: Issue.Type.Property.GetPropertyKeys.Options.HandledApi): Promise<import("../../../definitions/PropertyKeysAsResponse").PropertyKeysAsResponse>;
/**
* Returns the key and value of the [issue type property](https://developer.atlassian.com/cloud/jira/platform/storing-data-without-a-database/#a-id-jira-entity-properties-a-jira-entity-properties).

This operation can be accessed anonymously.

**[Permissions](#permissions) required:**

 *  *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg) to get the details of any issue type.
 *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) to get the details of any issue types associated with the projects the user has permission to browse.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-type-properties/#api-rest-api-3-issuetype-issuetypeid-properties-propertykey-get
* @param options Request options.
*/
export declare function getIssueTypeProperty<T = Issue.Type.Property.GetProperty.Response.OK>(options: Issue.Type.Property.GetProperty.Options.HandledApi): Promise<import("../../../definitions/EntityPropertyAsResponse").EntityPropertyAsResponse>;
/**
* Creates or updates the value of the [issue type property](https://developer.atlassian.com/cloud/jira/platform/storing-data-without-a-database/#a-id-jira-entity-properties-a-jira-entity-properties). Use this resource to store and update data against an issue type.

The value of the request body must be a [valid](http://tools.ietf.org/html/rfc4627), non-empty JSON blob. The maximum length is 32768 characters.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-type-properties/#api-rest-api-3-issuetype-issuetypeid-properties-propertykey-put
* @param options Request options.
*/
export declare function setIssueTypeProperty<T = Issue.Type.Property.SetProperty.Response.OK>(options: Issue.Type.Property.SetProperty.Options.HandledApi): Promise<any>;
/**
* Deletes the [issue type property](https://developer.atlassian.com/cloud/jira/platform/storing-data-without-a-database/#a-id-jira-entity-properties-a-jira-entity-properties).

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-type-properties/#api-rest-api-3-issuetype-issuetypeid-properties-propertykey-delete
* @param options Request options.
*/
export declare function deleteIssueTypeProperty<T = Issue.Type.Property.DeleteProperty.Response.OK>(options: Issue.Type.Property.DeleteProperty.Options.HandledApi): Promise<undefined>;
//# sourceMappingURL=property.d.ts.map