import { getIssueTypeSchemes as getIssueTypeSchemesFn } from "../../../raw-api/issue/type/scheme";
import { executeRequest } from "../../../handled-api/common";
import { createIssueTypeScheme as createIssueTypeSchemeFn } from "../../../raw-api/issue/type/scheme";
import { getIssueTypeSchemeItems as getIssueTypeSchemeItemsFn } from "../../../raw-api/issue/type/scheme";
import { getIssueTypeSchemesForProjects as getIssueTypeSchemesForProjectsFn } from "../../../raw-api/issue/type/scheme";
import { assignIssueTypeSchemeToProject as assignIssueTypeSchemeToProjectFn } from "../../../raw-api/issue/type/scheme";
import { addIssueTypesToIssueTypeScheme as addIssueTypesToIssueTypeSchemeFn } from "../../../raw-api/issue/type/scheme";
import { updateIssueTypeScheme as updateIssueTypeSchemeFn } from "../../../raw-api/issue/type/scheme";
import { deleteIssueTypeScheme as deleteIssueTypeSchemeFn } from "../../../raw-api/issue/type/scheme";
import { changeIssueTypeSchemeIssueTypesOrder as changeIssueTypeSchemeIssueTypesOrderFn } from "../../../raw-api/issue/type/scheme";
import { removeIssueTypesFromIssueTypeScheme as removeIssueTypesFromIssueTypeSchemeFn } from "../../../raw-api/issue/type/scheme";
/**
* Returns a [paginated](#pagination) list of issue type schemes.

Only issue type schemes used in classic projects are returned.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issuetypescheme-get
* @param options Request options.
*/
export function getIssueTypeSchemes(options) {
    return executeRequest(() => getIssueTypeSchemesFn(options), options.errorStrategy);
}
/**
* Creates an issue type scheme.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-type-schemes/#api-rest-api-3-issuetypescheme-post
* @param options Request options.
*/
export function createIssueTypeScheme(options) {
    return executeRequest(() => createIssueTypeSchemeFn(options), options.errorStrategy);
}
/**
* Returns a [paginated](#pagination) list of issue type scheme items.

Only issue type scheme items used in classic projects are returned.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issuetypescheme-mapping-get
* @param options Request options.
*/
export function getIssueTypeSchemeItems(options) {
    return executeRequest(() => getIssueTypeSchemeItemsFn(options), options.errorStrategy);
}
/**
* Returns a [paginated](#pagination) list of issue type schemes and, for each issue type scheme, a list of the projects that use it.

Only issue type schemes used in classic projects are returned.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issuetypescheme-project-get
* @param options Request options.
*/
export function getIssueTypeSchemesForProjects(options) {
    return executeRequest(() => getIssueTypeSchemesForProjectsFn(options), options.errorStrategy);
}
/**
* Assigns an issue type scheme to a project.

If any issues in the project are assigned issue types not present in the new scheme, the operation will fail. To complete the assignment those issues must be updated to use issue types in the new scheme.

Issue type schemes can only be assigned to classic projects.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-type-schemes/#api-rest-api-3-issuetypescheme-project-put
* @param options Request options.
*/
export function assignIssueTypeSchemeToProject(options) {
    return executeRequest(() => assignIssueTypeSchemeToProjectFn(options), options.errorStrategy);
}
/**
* Adds issue types to an issue type scheme.

The added issue types are appended to the issue types list.

If any of the issue types exist in the issue type scheme, the operation fails and no issue types are added.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-type-schemes/#api-rest-api-3-issuetypescheme-issuetypeschemeid-issuetype-put
* @param options Request options.
*/
export function addIssueTypesToIssueTypeScheme(options) {
    return executeRequest(() => addIssueTypesToIssueTypeSchemeFn(options), options.errorStrategy);
}
/**
* Updates an issue type scheme.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-type-schemes/#api-rest-api-3-issuetypescheme-issuetypeschemeid-put
* @param options Request options.
*/
export function updateIssueTypeScheme(options) {
    return executeRequest(() => updateIssueTypeSchemeFn(options), options.errorStrategy);
}
/**
* Deletes an issue type scheme.

Only issue type schemes used in classic projects can be deleted.

Any projects assigned to the scheme are reassigned to the default issue type scheme.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-type-schemes/#api-rest-api-3-issuetypescheme-issuetypeschemeid-delete
* @param options Request options.
*/
export function deleteIssueTypeScheme(options) {
    return executeRequest(() => deleteIssueTypeSchemeFn(options), options.errorStrategy);
}
/**
* Changes the order of issue types in an issue type scheme.

The request body parameters must meet the following requirements:

 *  all of the issue types must belong to the issue type scheme.
 *  either `after` or `position` must be provided.
 *  the issue type in `after` must not be in the issue type list.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-type-schemes/#api-rest-api-3-issuetypescheme-issuetypeschemeid-issuetype-move-put
* @param options Request options.
*/
export function changeIssueTypeSchemeIssueTypesOrder(options) {
    return executeRequest(() => changeIssueTypeSchemeIssueTypesOrderFn(options), options.errorStrategy);
}
/**
* Removes an issue type from an issue type scheme.

This operation cannot remove:

 *  any issue type used by issues.
 *  any issue types from the default issue type scheme.
 *  the last standard issue type from an issue type scheme.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-type-schemes/#api-rest-api-3-issuetypescheme-issuetypeschemeid-issuetype-issuetypeid-delete
* @param options Request options.
*/
export function removeIssueTypesFromIssueTypeScheme(options) {
    return executeRequest(() => removeIssueTypesFromIssueTypeSchemeFn(options), options.errorStrategy);
}
