import { Issue } from "../../../../types/issue";
/**
* Returns a [paginated](#pagination) list of projects associated with an issue type screen scheme.

Only company-managed projects associated with an issue type screen scheme are returned.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-type-screen-schemes/#api-rest-api-3-issuetypescreenscheme-issuetypescreenschemeid-project-get
* @param options Request options.
*/
export declare function getIssueTypeScreenSchemeProjects<T = Issue.Type.Screen.Scheme.GetProjects.Response.OK>(options: Issue.Type.Screen.Scheme.GetProjects.Options.HandledApi): Promise<import("../../../../definitions/PageBeanProjectDetailsAsResponse").PageBeanProjectDetailsAsResponse>;
/**
* Returns a [paginated](#pagination) list of issue type screen schemes.

Only issue type screen schemes used in classic projects are returned.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issuetypescreenscheme-get
* @param options Request options.
*/
export declare function getIssueTypeScreenSchemes<T = Issue.Type.Screen.Scheme.GetSchemes.Response.OK>(options: Issue.Type.Screen.Scheme.GetSchemes.Options.HandledApi): Promise<import("../../../../definitions/PageBeanIssueTypeScreenSchemeAsResponse").PageBeanIssueTypeScreenSchemeAsResponse>;
/**
* Creates an issue type screen scheme.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-type-screen-schemes/#api-rest-api-3-issuetypescreenscheme-post
* @param options Request options.
*/
export declare function createIssueTypeScreenScheme<T = Issue.Type.Screen.Scheme.CreateScheme.Response.OK>(options: Issue.Type.Screen.Scheme.CreateScheme.Options.HandledApi): Promise<import("../../../../definitions/IssueTypeScreenSchemeIdAsResponse").IssueTypeScreenSchemeIdAsResponse>;
/**
* Returns a [paginated](#pagination) list of issue type screen scheme items.

Only issue type screen schemes used in classic projects are returned.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issuetypescreenscheme-mapping-get
* @param options Request options.
*/
export declare function getIssueTypeScreenSchemeItems<T = Issue.Type.Screen.Scheme.GetSchemeItems.Response.OK>(options: Issue.Type.Screen.Scheme.GetSchemeItems.Options.HandledApi): Promise<import("../../../../definitions/PageBeanIssueTypeScreenSchemeItemAsResponse").PageBeanIssueTypeScreenSchemeItemAsResponse>;
/**
* Returns a [paginated](#pagination) list of issue type screen schemes and, for each issue type screen scheme, a list of the projects that use it.

Only issue type screen schemes used in classic projects are returned.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issuetypescreenscheme-project-get
* @param options Request options.
*/
export declare function getIssueTypeScreenSchemesForProjects<T = Issue.Type.Screen.Scheme.GetSchemesForProjects.Response.OK>(options: Issue.Type.Screen.Scheme.GetSchemesForProjects.Options.HandledApi): Promise<import("../../../../definitions/PageBeanIssueTypeScreenSchemesProjectsAsResponse").PageBeanIssueTypeScreenSchemesProjectsAsResponse>;
/**
* Assigns an issue type screen scheme to a project.

Issue type screen schemes can only be assigned to classic projects.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-type-screen-schemes/#api-rest-api-3-issuetypescreenscheme-project-put
* @param options Request options.
*/
export declare function assignIssueTypeScreenSchemeToProject<T = Issue.Type.Screen.Scheme.AssignSchemeToProject.Response.OK>(options: Issue.Type.Screen.Scheme.AssignSchemeToProject.Options.HandledApi): Promise<any>;
/**
* Updates an issue type screen scheme.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-type-screen-schemes/#api-rest-api-3-issuetypescreenscheme-issuetypescreenschemeid-put
* @param options Request options.
*/
export declare function updateIssueTypeScreenScheme<T = Issue.Type.Screen.Scheme.UpdateScheme.Response.OK>(options: Issue.Type.Screen.Scheme.UpdateScheme.Options.HandledApi): Promise<any>;
/**
* Deletes an issue type screen scheme.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-type-screen-schemes/#api-rest-api-3-issuetypescreenscheme-issuetypescreenschemeid-delete
* @param options Request options.
*/
export declare function deleteIssueTypeScreenScheme<T = Issue.Type.Screen.Scheme.DeleteScheme.Response.OK>(options: Issue.Type.Screen.Scheme.DeleteScheme.Options.HandledApi): Promise<any>;
/**
* Appends issue type to screen scheme mappings to an issue type screen scheme.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-type-screen-schemes/#api-rest-api-3-issuetypescreenscheme-issuetypescreenschemeid-mapping-put
* @param options Request options.
*/
export declare function appendMappingsToIssueTypeScreenScheme<T = Issue.Type.Screen.Scheme.AppendMappings.Response.OK>(options: Issue.Type.Screen.Scheme.AppendMappings.Options.HandledApi): Promise<any>;
/**
* Updates the default screen scheme of an issue type screen scheme. The default screen scheme is used for all unmapped issue types.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-type-screen-schemes/#api-rest-api-3-issuetypescreenscheme-issuetypescreenschemeid-mapping-default-put
* @param options Request options.
*/
export declare function updateDefaultIssueTypeScreenScheme<T = Issue.Type.Screen.Scheme.UpdateDefaultScheme.Response.OK>(options: Issue.Type.Screen.Scheme.UpdateDefaultScheme.Options.HandledApi): Promise<any>;
/**
* Removes issue type to screen scheme mappings from an issue type screen scheme.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-type-screen-schemes/#api-rest-api-3-issuetypescreenscheme-issuetypescreenschemeid-mapping-remove-post
* @param options Request options.
*/
export declare function removeMappingsFromIssueTypeScreenScheme<T = Issue.Type.Screen.Scheme.RemoveMappings.Response.OK>(options: Issue.Type.Screen.Scheme.RemoveMappings.Options.HandledApi): Promise<any>;
//# sourceMappingURL=scheme.d.ts.map