import { getIssueTypeScreenSchemeProjects as getIssueTypeScreenSchemeProjectsFn } from "../../../../raw-api/issue/type/screen/scheme";
import { executeRequest } from "../../../../handled-api/common";
import { getIssueTypeScreenSchemes as getIssueTypeScreenSchemesFn } from "../../../../raw-api/issue/type/screen/scheme";
import { createIssueTypeScreenScheme as createIssueTypeScreenSchemeFn } from "../../../../raw-api/issue/type/screen/scheme";
import { getIssueTypeScreenSchemeItems as getIssueTypeScreenSchemeItemsFn } from "../../../../raw-api/issue/type/screen/scheme";
import { getIssueTypeScreenSchemesForProjects as getIssueTypeScreenSchemesForProjectsFn } from "../../../../raw-api/issue/type/screen/scheme";
import { assignIssueTypeScreenSchemeToProject as assignIssueTypeScreenSchemeToProjectFn } from "../../../../raw-api/issue/type/screen/scheme";
import { updateIssueTypeScreenScheme as updateIssueTypeScreenSchemeFn } from "../../../../raw-api/issue/type/screen/scheme";
import { deleteIssueTypeScreenScheme as deleteIssueTypeScreenSchemeFn } from "../../../../raw-api/issue/type/screen/scheme";
import { appendMappingsToIssueTypeScreenScheme as appendMappingsToIssueTypeScreenSchemeFn } from "../../../../raw-api/issue/type/screen/scheme";
import { updateDefaultIssueTypeScreenScheme as updateDefaultIssueTypeScreenSchemeFn } from "../../../../raw-api/issue/type/screen/scheme";
import { removeMappingsFromIssueTypeScreenScheme as removeMappingsFromIssueTypeScreenSchemeFn } from "../../../../raw-api/issue/type/screen/scheme";
/**
* Returns a [paginated](#pagination) list of projects associated with an issue type screen scheme.

Only company-managed projects associated with an issue type screen scheme are returned.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-type-screen-schemes/#api-rest-api-3-issuetypescreenscheme-issuetypescreenschemeid-project-get
* @param options Request options.
*/
export function getIssueTypeScreenSchemeProjects(options) {
    return executeRequest(() => getIssueTypeScreenSchemeProjectsFn(options), options.errorStrategy);
}
/**
* Returns a [paginated](#pagination) list of issue type screen schemes.

Only issue type screen schemes used in classic projects are returned.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issuetypescreenscheme-get
* @param options Request options.
*/
export function getIssueTypeScreenSchemes(options) {
    return executeRequest(() => getIssueTypeScreenSchemesFn(options), options.errorStrategy);
}
/**
* Creates an issue type screen scheme.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-type-screen-schemes/#api-rest-api-3-issuetypescreenscheme-post
* @param options Request options.
*/
export function createIssueTypeScreenScheme(options) {
    return executeRequest(() => createIssueTypeScreenSchemeFn(options), options.errorStrategy);
}
/**
* Returns a [paginated](#pagination) list of issue type screen scheme items.

Only issue type screen schemes used in classic projects are returned.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issuetypescreenscheme-mapping-get
* @param options Request options.
*/
export function getIssueTypeScreenSchemeItems(options) {
    return executeRequest(() => getIssueTypeScreenSchemeItemsFn(options), options.errorStrategy);
}
/**
* Returns a [paginated](#pagination) list of issue type screen schemes and, for each issue type screen scheme, a list of the projects that use it.

Only issue type screen schemes used in classic projects are returned.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issuetypescreenscheme-project-get
* @param options Request options.
*/
export function getIssueTypeScreenSchemesForProjects(options) {
    return executeRequest(() => getIssueTypeScreenSchemesForProjectsFn(options), options.errorStrategy);
}
/**
* Assigns an issue type screen scheme to a project.

Issue type screen schemes can only be assigned to classic projects.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-type-screen-schemes/#api-rest-api-3-issuetypescreenscheme-project-put
* @param options Request options.
*/
export function assignIssueTypeScreenSchemeToProject(options) {
    return executeRequest(() => assignIssueTypeScreenSchemeToProjectFn(options), options.errorStrategy);
}
/**
* Updates an issue type screen scheme.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-type-screen-schemes/#api-rest-api-3-issuetypescreenscheme-issuetypescreenschemeid-put
* @param options Request options.
*/
export function updateIssueTypeScreenScheme(options) {
    return executeRequest(() => updateIssueTypeScreenSchemeFn(options), options.errorStrategy);
}
/**
* Deletes an issue type screen scheme.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-type-screen-schemes/#api-rest-api-3-issuetypescreenscheme-issuetypescreenschemeid-delete
* @param options Request options.
*/
export function deleteIssueTypeScreenScheme(options) {
    return executeRequest(() => deleteIssueTypeScreenSchemeFn(options), options.errorStrategy);
}
/**
* Appends issue type to screen scheme mappings to an issue type screen scheme.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-type-screen-schemes/#api-rest-api-3-issuetypescreenscheme-issuetypescreenschemeid-mapping-put
* @param options Request options.
*/
export function appendMappingsToIssueTypeScreenScheme(options) {
    return executeRequest(() => appendMappingsToIssueTypeScreenSchemeFn(options), options.errorStrategy);
}
/**
* Updates the default screen scheme of an issue type screen scheme. The default screen scheme is used for all unmapped issue types.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-type-screen-schemes/#api-rest-api-3-issuetypescreenscheme-issuetypescreenschemeid-mapping-default-put
* @param options Request options.
*/
export function updateDefaultIssueTypeScreenScheme(options) {
    return executeRequest(() => updateDefaultIssueTypeScreenSchemeFn(options), options.errorStrategy);
}
/**
* Removes issue type to screen scheme mappings from an issue type screen scheme.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-type-screen-schemes/#api-rest-api-3-issuetypescreenscheme-issuetypescreenschemeid-mapping-remove-post
* @param options Request options.
*/
export function removeMappingsFromIssueTypeScreenScheme(options) {
    return executeRequest(() => removeMappingsFromIssueTypeScreenSchemeFn(options), options.errorStrategy);
}
