import { getWorklogPropertyKeys as getWorklogPropertyKeysFn } from "../../../raw-api/issue/worklog/property";
import { executeRequest } from "../../../handled-api/common";
import { getWorklogProperty as getWorklogPropertyFn } from "../../../raw-api/issue/worklog/property";
import { setWorklogProperty as setWorklogPropertyFn } from "../../../raw-api/issue/worklog/property";
import { deleteWorklogProperty as deleteWorklogPropertyFn } from "../../../raw-api/issue/worklog/property";
/**
* Returns the keys of all properties for a worklog.

This operation can be accessed anonymously.

**[Permissions](#permissions) required:**

 *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
 *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
 *  If the worklog has visibility restrictions, belongs to the group or has the role visibility is restricted to.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-worklog-properties/#api-rest-api-3-issue-issueidorkey-worklog-worklogid-properties-get
* @param options Request options.
*/
export function getWorklogPropertyKeys(options) {
    return executeRequest(() => getWorklogPropertyKeysFn(options), options.errorStrategy);
}
/**
* Returns the value of a worklog property.

This operation can be accessed anonymously.

**[Permissions](#permissions) required:**

 *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
 *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
 *  If the worklog has visibility restrictions, belongs to the group or has the role visibility is restricted to.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-worklog-properties/#api-rest-api-3-issue-issueidorkey-worklog-worklogid-properties-propertykey-get
* @param options Request options.
*/
export function getWorklogProperty(options) {
    return executeRequest(() => getWorklogPropertyFn(options), options.errorStrategy);
}
/**
* Sets the value of a worklog property. Use this operation to store custom data against the worklog.

The value of the request body must be a [valid](http://tools.ietf.org/html/rfc4627), non-empty JSON blob. The maximum length is 32768 characters.

This operation can be accessed anonymously.

**[Permissions](#permissions) required:**

 *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
 *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
 *  *Edit all worklogs*[ project permission](https://confluence.atlassian.com/x/yodKLg) to update any worklog or *Edit own worklogs* to update worklogs created by the user.
 *  If the worklog has visibility restrictions, belongs to the group or has the role visibility is restricted to.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-worklog-properties/#api-rest-api-3-issue-issueidorkey-worklog-worklogid-properties-propertykey-put
* @param options Request options.
*/
export function setWorklogProperty(options) {
    return executeRequest(() => setWorklogPropertyFn(options), options.errorStrategy);
}
/**
* Deletes a worklog property.

This operation can be accessed anonymously.

**[Permissions](#permissions) required:**

 *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
 *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
 *  If the worklog has visibility restrictions, belongs to the group or has the role visibility is restricted to.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-worklog-properties/#api-rest-api-3-issue-issueidorkey-worklog-worklogid-properties-propertykey-delete
* @param options Request options.
*/
export function deleteWorklogProperty(options) {
    return executeRequest(() => deleteWorklogPropertyFn(options), options.errorStrategy);
}
