import { Jql } from "../types/jql";
/**
* Parses and validates JQL queries.

Validation is performed in context of the current user.

This operation can be accessed anonymously.

**[Permissions](#permissions) required:** None.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-jql-parse-post
* @param options Request options.
*/
export declare function parseJqlQuery<T = Jql.ParseQuery.Response.OK>(options: Jql.ParseQuery.Options.HandledApi): Promise<import("../definitions/ParsedJqlQueriesAsResponse").ParsedJqlQueriesAsResponse>;
/**
* Converts one or more JQL queries with user identifiers (username or user key) to equivalent JQL queries with account IDs.

You may wish to use this operation if your system stores JQL queries and you want to make them GDPR-compliant. For more information about GDPR-related changes, see the [migration guide](https://developer.atlassian.com/cloud/jira/platform/deprecation-notice-user-privacy-api-migration-guide/).

**[Permissions](#permissions) required:** Permission to access Jira.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-jql-pdcleaner-post
* @param options Request options.
*/
export declare function convertUserIdentifiersToAccountIdsInJqlQueries<T = Jql.ConvertUserIdentifiersToAccountIdsInQueries.Response.OK>(options: Jql.ConvertUserIdentifiersToAccountIdsInQueries.Options.HandledApi): Promise<import("../definitions/ConvertedJQLQueriesAsResponse").ConvertedJQLQueriesAsResponse>;
/**
* Returns reference data for JQL searches. This is a downloadable version of the documentation provided in [Advanced searching - fields reference](https://confluence.atlassian.com/x/gwORLQ) and [Advanced searching - functions reference](https://confluence.atlassian.com/x/hgORLQ), along with a list of JQL-reserved words. Use this information to assist with the programmatic creation of JQL queries or the validation of queries built in a custom query builder.

To filter visible field details by project or collapse non-unique fields by field type then [Get field reference data (POST)](#api-rest-api-3-jql-autocompletedata-post) can be used.

This operation can be accessed anonymously.

**[Permissions](#permissions) required:** None.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-jql/#api-rest-api-3-jql-autocompletedata-get
* @param options Request options.
*/
export declare function getReferenceDataForJql<T = Jql.GetReferenceData.Response.OK>(options: Jql.GetReferenceData.Options.HandledApi): Promise<import("../definitions/JQLReferenceDataAsResponse").JQLReferenceDataAsResponse>;
//# sourceMappingURL=jql.d.ts.map