import { getMyPreference as getMyPreferenceFn } from "../raw-api/myself";
import { executeRequest } from "../handled-api/common";
import { setMyPreference as setMyPreferenceFn } from "../raw-api/myself";
import { deleteMyPreference as deleteMyPreferenceFn } from "../raw-api/myself";
import { getMyLocale as getMyLocaleFn } from "../raw-api/myself";
import { getCurrentUser as getCurrentUserFn } from "../raw-api/myself";
/**
* Returns the value of a preference of the current user.

Note that these keys are deprecated:

 *  *jira.user.locale* The locale of the user. By default this is not set and the user takes the locale of the instance.
 *  *jira.user.timezone* The time zone of the user. By default this is not set and the user takes the timezone of the instance.

Use [ Update a user profile](https://developer.atlassian.com/cloud/admin/user-management/rest/#api-users-account-id-manage-profile-patch) from the user management REST API to manage timezone and locale instead.

**[Permissions](#permissions) required:** Permission to access Jira.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-mypreferences-get
* @param options Request options.
*/
export function getMyPreference(options) {
    return executeRequest(() => getMyPreferenceFn(options), options.errorStrategy);
}
/**
* Creates a preference for the user or updates a preference's value by sending a plain text string. For example, `false`. An arbitrary preference can be created with the value containing up to 255 characters. In addition, the following keys define system preferences that can be set or created:

 *  *user.notifications.mimetype* The mime type used in notifications sent to the user. Defaults to `html`.
 *  *user.notify.own.changes* Whether the user gets notified of their own changes. Defaults to `false`.
 *  *user.default.share.private* Whether new [ filters](https://confluence.atlassian.com/x/eQiiLQ) are set to private. Defaults to `true`.
 *  *user.keyboard.shortcuts.disabled* Whether keyboard shortcuts are disabled. Defaults to `false`.
 *  *user.autowatch.disabled* Whether the user automatically watches issues they create or add a comment to. By default, not set: the user takes the instance autowatch setting.

Note that these keys are deprecated:

 *  *jira.user.locale* The locale of the user. By default, not set. The user takes the instance locale.
 *  *jira.user.timezone* The time zone of the user. By default, not set. The user takes the instance timezone.

Use [ Update a user profile](https://developer.atlassian.com/cloud/admin/user-management/rest/#api-users-account-id-manage-profile-patch) from the user management REST API to manage timezone and locale instead.

**[Permissions](#permissions) required:** Permission to access Jira.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-mypreferences-put
* @param options Request options.
*/
export function setMyPreference(options) {
    return executeRequest(() => setMyPreferenceFn(options), options.errorStrategy);
}
/**
* Deletes a preference of the user, which restores the default value of system defined settings.

Note that these keys are deprecated:

 *  *jira.user.locale* The locale of the user. By default, not set. The user takes the instance locale.
 *  *jira.user.timezone* The time zone of the user. By default, not set. The user takes the instance timezone.

Use [ Update a user profile](https://developer.atlassian.com/cloud/admin/user-management/rest/#api-users-account-id-manage-profile-patch) from the user management REST API to manage timezone and locale instead.

**[Permissions](#permissions) required:** Permission to access Jira.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-mypreferences-delete
* @param options Request options.
*/
export function deleteMyPreference(options) {
    return executeRequest(() => deleteMyPreferenceFn(options), options.errorStrategy);
}
/**
* Returns the locale for the user.

If the user has no language preference set (which is the default setting) or this resource is accessed anonymous, the browser locale detected by Jira is returned. Jira detects the browser locale using the *Accept-Language* header in the request. However, if this doesn't match a locale available Jira, the site default locale is returned.

This operation can be accessed anonymously.

**[Permissions](#permissions) required:** None.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-mypreferences-locale-get
* @param options Request options.
*/
export function getMyLocale(options) {
    return executeRequest(() => getMyLocaleFn(options), options.errorStrategy);
}
/**
* Returns details for the current user.

**[Permissions](#permissions) required:** Permission to access Jira.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-myself-get
* @param options Request options.
*/
export function getCurrentUser(options) {
    return executeRequest(() => getCurrentUserFn(options), options.errorStrategy);
}
