import { Permission } from "../../../types/permission";
/**
* Returns all permission grants for a permission scheme.

**[Permissions](#permissions) required:** Permission to access Jira.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-permission-schemes/#api-rest-api-3-permissionscheme-schemeid-permission-get
* @param options Request options.
*/
export declare function getPermissionSchemeGrants<T = Permission.Scheme.Grant.GetGrants.Response.OK>(options: Permission.Scheme.Grant.GetGrants.Options.HandledApi): Promise<import("../../../definitions/PermissionGrantsAsResponse").PermissionGrantsAsResponse>;
/**
* Creates a permission grant in a permission scheme.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-permission-schemes/#api-rest-api-3-permissionscheme-schemeid-permission-post
* @param options Request options.
*/
export declare function createPermissionSchemeGrant<T = Permission.Scheme.Grant.CreateGrant.Response.OK>(options: Permission.Scheme.Grant.CreateGrant.Options.HandledApi): Promise<import("../../../definitions/PermissionGrantAsResponse").PermissionGrantAsResponse>;
/**
* Returns a permission grant.

**[Permissions](#permissions) required:** Permission to access Jira.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-permission-schemes/#api-rest-api-3-permissionscheme-schemeid-permission-permissionid-get
* @param options Request options.
*/
export declare function getPermissionSchemeGrant<T = Permission.Scheme.Grant.GetGrant.Response.OK>(options: Permission.Scheme.Grant.GetGrant.Options.HandledApi): Promise<import("../../../definitions/PermissionGrantAsResponse").PermissionGrantAsResponse>;
/**
* Deletes a permission grant from a permission scheme. See [About permission schemes and grants](../api-group-permission-schemes/#about-permission-schemes-and-grants) for more details.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-permission-schemes/#api-rest-api-3-permissionscheme-schemeid-permission-permissionid-delete
* @param options Request options.
*/
export declare function deletePermissionSchemeGrant<T = Permission.Scheme.Grant.DeleteGrant.Response.OK>(options: Permission.Scheme.Grant.DeleteGrant.Options.HandledApi): Promise<undefined>;
//# sourceMappingURL=grant.d.ts.map