import { getPermissionSchemeGrants as getPermissionSchemeGrantsFn } from "../../../raw-api/permission/scheme/grant";
import { executeRequest } from "../../../handled-api/common";
import { createPermissionSchemeGrant as createPermissionSchemeGrantFn } from "../../../raw-api/permission/scheme/grant";
import { getPermissionSchemeGrant as getPermissionSchemeGrantFn } from "../../../raw-api/permission/scheme/grant";
import { deletePermissionSchemeGrant as deletePermissionSchemeGrantFn } from "../../../raw-api/permission/scheme/grant";
/**
* Returns all permission grants for a permission scheme.

**[Permissions](#permissions) required:** Permission to access Jira.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-permission-schemes/#api-rest-api-3-permissionscheme-schemeid-permission-get
* @param options Request options.
*/
export function getPermissionSchemeGrants(options) {
    return executeRequest(() => getPermissionSchemeGrantsFn(options), options.errorStrategy);
}
/**
* Creates a permission grant in a permission scheme.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-permission-schemes/#api-rest-api-3-permissionscheme-schemeid-permission-post
* @param options Request options.
*/
export function createPermissionSchemeGrant(options) {
    return executeRequest(() => createPermissionSchemeGrantFn(options), options.errorStrategy);
}
/**
* Returns a permission grant.

**[Permissions](#permissions) required:** Permission to access Jira.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-permission-schemes/#api-rest-api-3-permissionscheme-schemeid-permission-permissionid-get
* @param options Request options.
*/
export function getPermissionSchemeGrant(options) {
    return executeRequest(() => getPermissionSchemeGrantFn(options), options.errorStrategy);
}
/**
* Deletes a permission grant from a permission scheme. See [About permission schemes and grants](../api-group-permission-schemes/#about-permission-schemes-and-grants) for more details.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-permission-schemes/#api-rest-api-3-permissionscheme-schemeid-permission-permissionid-delete
* @param options Request options.
*/
export function deletePermissionSchemeGrant(options) {
    return executeRequest(() => deletePermissionSchemeGrantFn(options), options.errorStrategy);
}
