import { getProjectCategories as getProjectCategoriesFn } from "../../raw-api/project/category";
import { executeRequest } from "../../handled-api/common";
import { createProjectCategory as createProjectCategoryFn } from "../../raw-api/project/category";
import { getProjectCategory as getProjectCategoryFn } from "../../raw-api/project/category";
import { updateProjectCategory as updateProjectCategoryFn } from "../../raw-api/project/category";
import { deleteProjectCategory as deleteProjectCategoryFn } from "../../raw-api/project/category";
/**
* Returns all project categories.

**[Permissions](#permissions) required:** Permission to access Jira.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-project-categories/#api-rest-api-3-projectcategory-get
* @param options Request options.
*/
export function getProjectCategories(options) {
    return executeRequest(() => getProjectCategoriesFn(options), options.errorStrategy);
}
/**
* Creates a project category.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-project-categories/#api-rest-api-3-projectcategory-post
* @param options Request options.
*/
export function createProjectCategory(options) {
    return executeRequest(() => createProjectCategoryFn(options), options.errorStrategy);
}
/**
* Returns a project category.

**[Permissions](#permissions) required:** Permission to access Jira.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-project-categories/#api-rest-api-3-projectcategory-id-get
* @param options Request options.
*/
export function getProjectCategory(options) {
    return executeRequest(() => getProjectCategoryFn(options), options.errorStrategy);
}
/**
* Updates a project category.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-project-categories/#api-rest-api-3-projectcategory-id-put
* @param options Request options.
*/
export function updateProjectCategory(options) {
    return executeRequest(() => updateProjectCategoryFn(options), options.errorStrategy);
}
/**
* Deletes a project category.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-project-categories/#api-rest-api-3-projectcategory-id-delete
* @param options Request options.
*/
export function deleteProjectCategory(options) {
    return executeRequest(() => deleteProjectCategoryFn(options), options.errorStrategy);
}
