import { Project } from "../../types/project";
/**
* Creates a component. Use components to provide containers for issues within a project.

This operation can be accessed anonymously.

**[Permissions](#permissions) required:** *Administer projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project in which the component is created or *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-component-post
* @param options Request options.
*/
export declare function createProjectComponent<T = Project.Component.CreateComponent.Response.OK>(options: Project.Component.CreateComponent.Options.HandledApi): Promise<import("../../definitions/ProjectComponentAsResponse").ProjectComponentAsResponse>;
/**
* Returns a component.

This operation can be accessed anonymously.

**[Permissions](#permissions) required:** *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for project containing the component.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-component-id-get
* @param options Request options.
*/
export declare function getProjectComponent<T = Project.Component.GetComponent.Response.OK>(options: Project.Component.GetComponent.Options.HandledApi): Promise<import("../../definitions/ProjectComponentAsResponse").ProjectComponentAsResponse>;
/**
* Updates a component. Any fields included in the request are overwritten. If `leadAccountId` is an empty string ("") the component lead is removed.

This operation can be accessed anonymously.

**[Permissions](#permissions) required:** *Administer projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project containing the component or *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-component-id-put
* @param options Request options.
*/
export declare function updateProjectComponent<T = Project.Component.UpdateComponent.Response.OK>(options: Project.Component.UpdateComponent.Options.HandledApi): Promise<import("../../definitions/ComponentAsResponse").ComponentAsResponse>;
/**
* Deletes a component.

This operation can be accessed anonymously.

**[Permissions](#permissions) required:** *Administer projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project containing the component or *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-component-id-delete
* @param options Request options.
*/
export declare function deleteProjectComponent<T = Project.Component.DeleteComponent.Response.OK>(options: Project.Component.DeleteComponent.Options.HandledApi): Promise<undefined>;
/**
* Returns the counts of issues assigned to the component.

This operation can be accessed anonymously.

**[Permissions](#permissions) required:** None.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-component-id-relatedIssueCounts-get
* @param options Request options.
*/
export declare function getProjectComponentIssueCount<T = Project.Component.GetIssueCount.Response.OK>(options: Project.Component.GetIssueCount.Options.HandledApi): Promise<import("../../definitions/ComponentIssuesCountAsResponse").ComponentIssuesCountAsResponse>;
/**
* Returns a [paginated](#pagination) list of all components in a project. See the [Get project components](#api-rest-api-3-project-projectIdOrKey-components-get) resource if you want to get a full list of versions without pagination.

This operation can be accessed anonymously.

**[Permissions](#permissions) required:** *Browse Projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-project-projectIdOrKey-component-get
* @param options Request options.
*/
export declare function getProjectComponentsPaginated<T = Project.Component.GetComponentsPaginated.Response.OK>(options: Project.Component.GetComponentsPaginated.Options.HandledApi): Promise<import("../../definitions/PageBeanComponentWithIssueCountAsResponse").PageBeanComponentWithIssueCountAsResponse>;
/**
* Returns all components in a project. See the [Get project components paginated](#api-rest-api-3-project-projectIdOrKey-component-get) resource if you want to get a full list of components with pagination.

This operation can be accessed anonymously.

**[Permissions](#permissions) required:** *Browse Projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-project-projectIdOrKey-components-get
* @param options Request options.
*/
export declare function getProjectComponents<T = Project.Component.GetComponents.Response.OK>(options: Project.Component.GetComponents.Options.HandledApi): Promise<Project.Component.GetComponents.Response.OK>;
//# sourceMappingURL=component.d.ts.map