import { createProjectComponent as createProjectComponentFn } from "../../raw-api/project/component";
import { executeRequest } from "../../handled-api/common";
import { getProjectComponent as getProjectComponentFn } from "../../raw-api/project/component";
import { updateProjectComponent as updateProjectComponentFn } from "../../raw-api/project/component";
import { deleteProjectComponent as deleteProjectComponentFn } from "../../raw-api/project/component";
import { getProjectComponentIssueCount as getProjectComponentIssueCountFn } from "../../raw-api/project/component";
import { getProjectComponentsPaginated as getProjectComponentsPaginatedFn } from "../../raw-api/project/component";
import { getProjectComponents as getProjectComponentsFn } from "../../raw-api/project/component";
/**
* Creates a component. Use components to provide containers for issues within a project.

This operation can be accessed anonymously.

**[Permissions](#permissions) required:** *Administer projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project in which the component is created or *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-component-post
* @param options Request options.
*/
export function createProjectComponent(options) {
    return executeRequest(() => createProjectComponentFn(options), options.errorStrategy);
}
/**
* Returns a component.

This operation can be accessed anonymously.

**[Permissions](#permissions) required:** *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for project containing the component.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-component-id-get
* @param options Request options.
*/
export function getProjectComponent(options) {
    return executeRequest(() => getProjectComponentFn(options), options.errorStrategy);
}
/**
* Updates a component. Any fields included in the request are overwritten. If `leadAccountId` is an empty string ("") the component lead is removed.

This operation can be accessed anonymously.

**[Permissions](#permissions) required:** *Administer projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project containing the component or *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-component-id-put
* @param options Request options.
*/
export function updateProjectComponent(options) {
    return executeRequest(() => updateProjectComponentFn(options), options.errorStrategy);
}
/**
* Deletes a component.

This operation can be accessed anonymously.

**[Permissions](#permissions) required:** *Administer projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project containing the component or *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-component-id-delete
* @param options Request options.
*/
export function deleteProjectComponent(options) {
    return executeRequest(() => deleteProjectComponentFn(options), options.errorStrategy);
}
/**
* Returns the counts of issues assigned to the component.

This operation can be accessed anonymously.

**[Permissions](#permissions) required:** None.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-component-id-relatedIssueCounts-get
* @param options Request options.
*/
export function getProjectComponentIssueCount(options) {
    return executeRequest(() => getProjectComponentIssueCountFn(options), options.errorStrategy);
}
/**
* Returns a [paginated](#pagination) list of all components in a project. See the [Get project components](#api-rest-api-3-project-projectIdOrKey-components-get) resource if you want to get a full list of versions without pagination.

This operation can be accessed anonymously.

**[Permissions](#permissions) required:** *Browse Projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-project-projectIdOrKey-component-get
* @param options Request options.
*/
export function getProjectComponentsPaginated(options) {
    return executeRequest(() => getProjectComponentsPaginatedFn(options), options.errorStrategy);
}
/**
* Returns all components in a project. See the [Get project components paginated](#api-rest-api-3-project-projectIdOrKey-component-get) resource if you want to get a full list of components with pagination.

This operation can be accessed anonymously.

**[Permissions](#permissions) required:** *Browse Projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-project-projectIdOrKey-components-get
* @param options Request options.
*/
export function getProjectComponents(options) {
    return executeRequest(() => getProjectComponentsFn(options), options.errorStrategy);
}
