import { assignProjectPermissionScheme as assignProjectPermissionSchemeFn } from "../../../raw-api/project/permission/scheme";
import { executeRequest } from "../../../handled-api/common";
import { getProjectPermissionScheme as getProjectPermissionSchemeFn } from "../../../raw-api/project/permission/scheme";
import { getProjectIssueSecurityLevels as getProjectIssueSecurityLevelsFn } from "../../../raw-api/project/permission/scheme";
/**
* Assigns a permission scheme with a project. See [Managing project permissions](https://confluence.atlassian.com/x/yodKLg) for more information about permission schemes.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg)
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-project-permission-schemes/#api-rest-api-3-project-projectkeyorid-permissionscheme-put
* @param options Request options.
*/
export function assignProjectPermissionScheme(options) {
    return executeRequest(() => assignProjectPermissionSchemeFn(options), options.errorStrategy);
}
/**
* Gets the [permission scheme](https://confluence.atlassian.com/x/yodKLg) associated with the project.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg) or *Administer projects* [project permission](https://confluence.atlassian.com/x/yodKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-project-permission-schemes/#api-rest-api-3-project-projectkeyorid-permissionscheme-get
* @param options Request options.
*/
export function getProjectPermissionScheme(options) {
    return executeRequest(() => getProjectPermissionSchemeFn(options), options.errorStrategy);
}
/**
* Returns all [issue security](https://confluence.atlassian.com/x/J4lKLg) levels for the project that the user has access to.

This operation can be accessed anonymously.

**[Permissions](#permissions) required:** *Browse projects* [global permission](https://confluence.atlassian.com/x/x4dKLg) for the project, however, issue security levels are only returned for authenticated user with *Set Issue Security* [global permission](https://confluence.atlassian.com/x/x4dKLg) for the project.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-project-permission-schemes/#api-rest-api-3-project-projectkeyorid-securitylevel-get
* @param options Request options.
*/
export function getProjectIssueSecurityLevels(options) {
    return executeRequest(() => getProjectIssueSecurityLevelsFn(options), options.errorStrategy);
}
