import { getProjectRolesForProject as getProjectRolesForProjectFn } from "../../raw-api/project/role";
import { executeRequest } from "../../handled-api/common";
import { getProjectRoleForProject as getProjectRoleForProjectFn } from "../../raw-api/project/role";
import { getProjectRoleDetails as getProjectRoleDetailsFn } from "../../raw-api/project/role";
import { getProjectRoles as getProjectRolesFn } from "../../raw-api/project/role";
import { createProjectRole as createProjectRoleFn } from "../../raw-api/project/role";
import { getProjectRole as getProjectRoleFn } from "../../raw-api/project/role";
import { fullyUpdateProjectRole as fullyUpdateProjectRoleFn } from "../../raw-api/project/role";
import { partiallyUpdateProjectRole as partiallyUpdateProjectRoleFn } from "../../raw-api/project/role";
import { deleteProjectRole as deleteProjectRoleFn } from "../../raw-api/project/role";
/**
* Returns a list of [project roles](https://confluence.atlassian.com/x/3odKLg) for the project returning the name and self URL for each role.

Note that all project roles are shared with all projects in Jira Cloud. See [Get all project roles](#api-rest-api-3-role-get) for more information.

This operation can be accessed anonymously.

**[Permissions](#permissions) required:** *Administer Projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for any project on the site or *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-project-projectIdOrKey-role-get
* @param options Request options.
*/
export function getProjectRolesForProject(options) {
    return executeRequest(() => getProjectRolesForProjectFn(options), options.errorStrategy);
}
/**
* Returns a project role's details and actors associated with the project. The list of actors is sorted by display name.

To check whether a user belongs to a role based on their group memberships, use [Get user](#api-rest-api-3-user-get) with the `groups` expand parameter selected. Then check whether the user keys and groups match with the actors returned for the project.

This operation can be accessed anonymously.

**[Permissions](#permissions) required:** *Administer Projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project or *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-project-projectIdOrKey-role-id-get
* @param options Request options.
*/
export function getProjectRoleForProject(options) {
    return executeRequest(() => getProjectRoleForProjectFn(options), options.errorStrategy);
}
/**
* Returns all [project roles](https://confluence.atlassian.com/x/3odKLg) and the details for each role. Note that the list of project roles is common to all projects.

This operation can be accessed anonymously.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg) or *Administer projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-project-projectIdOrKey-roledetails-get
* @param options Request options.
*/
export function getProjectRoleDetails(options) {
    return executeRequest(() => getProjectRoleDetailsFn(options), options.errorStrategy);
}
/**
* Gets a list of all project roles, complete with project role details and default actors.

### About project roles ###

[Project roles](https://confluence.atlassian.com/x/3odKLg) are a flexible way to to associate users and groups with projects. In Jira Cloud, the list of project roles is shared globally with all projects, but each project can have a different set of actors associated with it (unlike groups, which have the same membership throughout all Jira applications).

Project roles are used in [permission schemes](#api-rest-api-3-permissionscheme-get), [email notification schemes](#api-rest-api-3-notificationscheme-get), [issue security levels](#api-rest-api-3-issuesecurityschemes-get), [comment visibility](#api-rest-api-3-comment-list-post), and workflow conditions.

#### Members and actors ####

In the Jira REST API, a member of a project role is called an *actor*. An *actor* is a group or user associated with a project role.

Actors may be set as [default members](https://confluence.atlassian.com/x/3odKLg#Managingprojectroles-Specifying'defaultmembers'foraprojectrole) of the project role or set at the project level:

 *  Default actors: Users and groups that are assigned to the project role for all newly created projects. The default actors can be removed at the project level later if desired.
 *  Actors: Users and groups that are associated with a project role for a project, which may differ from the default actors. This enables you to assign a user to different roles in different projects.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-role-get
* @param options Request options.
*/
export function getProjectRoles(options) {
    return executeRequest(() => getProjectRolesFn(options), options.errorStrategy);
}
/**
* Creates a new project role with no [default actors](#api-rest-api-3-resolution-get). You can use the [Add default actors to project role](#api-rest-api-3-role-id-actors-post) operation to add default actors to the project role after creating it.

*Note that although a new project role is available to all projects upon creation, any default actors that are associated with the project role are not added to projects that existed prior to the role being created.*<

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-role-post
* @param options Request options.
*/
export function createProjectRole(options) {
    return executeRequest(() => createProjectRoleFn(options), options.errorStrategy);
}
/**
* Gets the project role details and the default actors associated with the role. The list of default actors is sorted by display name.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-role-id-get
* @param options Request options.
*/
export function getProjectRole(options) {
    return executeRequest(() => getProjectRoleFn(options), options.errorStrategy);
}
/**
* Updates the project role's name and description. You must include both a name and a description in the request.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-role-id-put
* @param options Request options.
*/
export function fullyUpdateProjectRole(options) {
    return executeRequest(() => fullyUpdateProjectRoleFn(options), options.errorStrategy);
}
/**
* Updates either the project role's name or its description.

You cannot update both the name and description at the same time using this operation. If you send a request with a name and a description only the name is updated.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-role-id-post
* @param options Request options.
*/
export function partiallyUpdateProjectRole(options) {
    return executeRequest(() => partiallyUpdateProjectRoleFn(options), options.errorStrategy);
}
/**
* Deletes a project role. You must specify a replacement project role if you wish to delete a project role that is in use.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-role-id-delete
* @param options Request options.
*/
export function deleteProjectRole(options) {
    return executeRequest(() => deleteProjectRoleFn(options), options.errorStrategy);
}
