import { setActorsForProjectRole as setActorsForProjectRoleFn } from "../../../raw-api/project/role/actor";
import { executeRequest } from "../../../handled-api/common";
import { addActorsToProjectRole as addActorsToProjectRoleFn } from "../../../raw-api/project/role/actor";
import { deleteActorsFromProjectRole as deleteActorsFromProjectRoleFn } from "../../../raw-api/project/role/actor";
/**
* Sets the actors for a project role for a project, replacing all existing actors.

To add actors to the project without overwriting the existing list, use [Add actors to project role](#api-rest-api-3-project-projectIdOrKey-role-id-post).

**[Permissions](#permissions) required:** *Administer Projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project or *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-project-projectIdOrKey-role-id-put
* @param options Request options.
*/
export function setActorsForProjectRole(options) {
    return executeRequest(() => setActorsForProjectRoleFn(options), options.errorStrategy);
}
/**
* Adds actors to a project role for the project.

To replace all actors for the project, use [Set actors for project role](#api-rest-api-3-project-projectIdOrKey-role-id-put).

This operation can be accessed anonymously.

**[Permissions](#permissions) required:** *Administer Projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project or *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-project-projectIdOrKey-role-id-post
* @param options Request options.
*/
export function addActorsToProjectRole(options) {
    return executeRequest(() => addActorsToProjectRoleFn(options), options.errorStrategy);
}
/**
* Deletes actors from a project role for the project.

To remove default actors from the project role, use [Delete default actors from project role](#api-rest-api-3-role-id-actors-delete).

This operation can be accessed anonymously.

**[Permissions](#permissions) required:** *Administer Projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project or *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-project-projectIdOrKey-role-id-delete
* @param options Request options.
*/
export function deleteActorsFromProjectRole(options) {
    return executeRequest(() => deleteActorsFromProjectRoleFn(options), options.errorStrategy);
}
