import { getDefaultActorsForProjectRole as getDefaultActorsForProjectRoleFn } from "../../../../raw-api/project/role/actor/default";
import { executeRequest } from "../../../../handled-api/common";
import { addDefaultActorsToProjectRole as addDefaultActorsToProjectRoleFn } from "../../../../raw-api/project/role/actor/default";
import { deleteDefaultActorsFromProjectRole as deleteDefaultActorsFromProjectRoleFn } from "../../../../raw-api/project/role/actor/default";
/**
* Returns the [default actors](#api-rest-api-3-resolution-get) for the project role.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-role-id-actors-get
* @param options Request options.
*/
export function getDefaultActorsForProjectRole(options) {
    return executeRequest(() => getDefaultActorsForProjectRoleFn(options), options.errorStrategy);
}
/**
* Adds [default actors](#api-rest-api-3-resolution-get) to a role. You may add groups or users, but you cannot add groups and users in the same request.

Changing a project role's default actors does not affect project role members for projects already created.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-role-id-actors-post
* @param options Request options.
*/
export function addDefaultActorsToProjectRole(options) {
    return executeRequest(() => addDefaultActorsToProjectRoleFn(options), options.errorStrategy);
}
/**
* Deletes the [default actors](#api-rest-api-3-resolution-get) from a project role. You may delete a group or user, but you cannot delete a group and a user in the same request.

Changing a project role's default actors does not affect project role members for projects already created.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-role-id-actors-delete
* @param options Request options.
*/
export function deleteDefaultActorsFromProjectRole(options) {
    return executeRequest(() => deleteDefaultActorsFromProjectRoleFn(options), options.errorStrategy);
}
