import { getProjectTypes as getProjectTypesFn } from "../../raw-api/project/type";
import { executeRequest } from "../../handled-api/common";
import { getLicensedProjectTypes as getLicensedProjectTypesFn } from "../../raw-api/project/type";
import { getProjectTypeByKey as getProjectTypeByKeyFn } from "../../raw-api/project/type";
import { getAccessibleProjectTypeByKey as getAccessibleProjectTypeByKeyFn } from "../../raw-api/project/type";
/**
* Returns all [project types](https://confluence.atlassian.com/x/Var1Nw), whether or not the instance has a valid license for each type.

This operation can be accessed anonymously.

**[Permissions](#permissions) required:** None.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-project-types/#api-rest-api-3-project-type-get
* @param options Request options.
*/
export function getProjectTypes(options) {
    return executeRequest(() => getProjectTypesFn(options), options.errorStrategy);
}
/**
 * Returns all [project types](https://confluence.atlassian.com/x/Var1Nw) with a valid license.
 * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-project-types/#api-rest-api-3-project-type-accessible-get
 * @param options Request options.
 */
export function getLicensedProjectTypes(options) {
    return executeRequest(() => getLicensedProjectTypesFn(options), options.errorStrategy);
}
/**
* Returns a [project type](https://confluence.atlassian.com/x/Var1Nw).

This operation can be accessed anonymously.

**[Permissions](#permissions) required:** None.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-project-types/#api-rest-api-3-project-type-projecttypekey-get
* @param options Request options.
*/
export function getProjectTypeByKey(options) {
    return executeRequest(() => getProjectTypeByKeyFn(options), options.errorStrategy);
}
/**
* Returns a [project type](https://confluence.atlassian.com/x/Var1Nw) if it is accessible to the user.

**[Permissions](#permissions) required:** Permission to access Jira.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-project-types/#api-rest-api-3-project-type-projecttypekey-accessible-get
* @param options Request options.
*/
export function getAccessibleProjectTypeByKey(options) {
    return executeRequest(() => getAccessibleProjectTypeByKeyFn(options), options.errorStrategy);
}
