import { validateProjectKey as validateProjectKeyFn } from "../../raw-api/project/validation";
import { executeRequest } from "../../handled-api/common";
import { getValidProjectKey as getValidProjectKeyFn } from "../../raw-api/project/validation";
import { getValidProjectName as getValidProjectNameFn } from "../../raw-api/project/validation";
/**
* Validates a project key by confirming the key is a valid string and not in use.

**[Permissions](#permissions) required:** None.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-projectvalidate-key-get
* @param options Request options.
*/
export function validateProjectKey(options) {
    return executeRequest(() => validateProjectKeyFn(options), options.errorStrategy);
}
/**
* Validates a project key and, if the key is invalid or in use, generates a valid random string for the project key.

**[Permissions](#permissions) required:** None.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-projectvalidate-validProjectKey-get
* @param options Request options.
*/
export function getValidProjectKey(options) {
    return executeRequest(() => getValidProjectKeyFn(options), options.errorStrategy);
}
/**
* Checks that a project name isn't in use. If the name isn't in use, the passed string is returned. If the name is in use, this operation attempts to generate a valid project name based on the one supplied, usually by adding a sequence number. If a valid project name cannot be generated, a 404 response is returned.

**[Permissions](#permissions) required:** None.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-projectvalidate-validProjectName-get
* @param options Request options.
*/
export function getValidProjectName(options) {
    return executeRequest(() => getValidProjectNameFn(options), options.errorStrategy);
}
