import { getProjectVersionsPaginated as getProjectVersionsPaginatedFn } from "../../raw-api/project/version";
import { executeRequest } from "../../handled-api/common";
import { getProjectVersions as getProjectVersionsFn } from "../../raw-api/project/version";
import { createProjectVersion as createProjectVersionFn } from "../../raw-api/project/version";
import { getProjectVersion as getProjectVersionFn } from "../../raw-api/project/version";
import { updateProjectVersion as updateProjectVersionFn } from "../../raw-api/project/version";
import { mergeProjectVersions as mergeProjectVersionsFn } from "../../raw-api/project/version";
import { moveProjectVersion as moveProjectVersionFn } from "../../raw-api/project/version";
import { deleteAndReplaceProjectVersion as deleteAndReplaceProjectVersionFn } from "../../raw-api/project/version";
/**
* Returns a [paginated](#pagination) list of all versions in a project. See the [Get project versions](#api-rest-api-3-project-projectIdOrKey-versions-get) resource if you want to get a full list of versions without pagination.

This operation can be accessed anonymously.

**[Permissions](#permissions) required:** *Browse Projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-project-projectIdOrKey-version-get
* @param options Request options.
*/
export function getProjectVersionsPaginated(options) {
    return executeRequest(() => getProjectVersionsPaginatedFn(options), options.errorStrategy);
}
/**
* Returns all versions in a project. The response is not paginated. Use [Get project versions paginated](#api-rest-api-3-project-projectIdOrKey-version-get) if you want to get the versions in a project with pagination.

This operation can be accessed anonymously.

**[Permissions](#permissions) required:** *Browse Projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-project-projectIdOrKey-versions-get
* @param options Request options.
*/
export function getProjectVersions(options) {
    return executeRequest(() => getProjectVersionsFn(options), options.errorStrategy);
}
/**
* Creates a project version.

This operation can be accessed anonymously.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg) or *Administer Projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project the version is added to.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-version-post
* @param options Request options.
*/
export function createProjectVersion(options) {
    return executeRequest(() => createProjectVersionFn(options), options.errorStrategy);
}
/**
* Returns a project version.

This operation can be accessed anonymously.

**[Permissions](#permissions) required:** *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project containing the version.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-version-id-get
* @param options Request options.
*/
export function getProjectVersion(options) {
    return executeRequest(() => getProjectVersionFn(options), options.errorStrategy);
}
/**
* Updates a project version.

This operation can be accessed anonymously.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg) or *Administer Projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that contains the version.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-version-id-put
* @param options Request options.
*/
export function updateProjectVersion(options) {
    return executeRequest(() => updateProjectVersionFn(options), options.errorStrategy);
}
/**
* Merges two project versions. The merge is completed by deleting the version specified in `id` and replacing any occurrences of its ID in `fixVersion` with the version ID specified in `moveIssuesTo`.

Consider using [ Delete and replace version](#api-rest-api-3-version-id-removeAndSwap-post) instead. This resource supports swapping version values in `fixVersion`, `affectedVersion`, and custom fields.

This operation can be accessed anonymously.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg) or *Administer Projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that contains the version.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-version-id-mergeto-moveIssuesTo-put
* @param options Request options.
*/
export function mergeProjectVersions(options) {
    return executeRequest(() => mergeProjectVersionsFn(options), options.errorStrategy);
}
/**
* Modifies the version's sequence within the project, which affects the display order of the versions in Jira.

This operation can be accessed anonymously.

**[Permissions](#permissions) required:** *Browse projects* project permission for the project that contains the version.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-version-id-move-post
* @param options Request options.
*/
export function moveProjectVersion(options) {
    return executeRequest(() => moveProjectVersionFn(options), options.errorStrategy);
}
/**
* Deletes a project version.

Alternative versions can be provided to update issues that use the deleted version in `fixVersion`, `affectedVersion`, or any version picker custom fields. If alternatives are not provided, occurrences of `fixVersion`, `affectedVersion`, and any version picker custom field, that contain the deleted version, are cleared. Any replacement version must be in the same project as the version being deleted and cannot be the version being deleted.

This operation can be accessed anonymously.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg) or *Administer Projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that contains the version.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-version-id-removeAndSwap-post
* @param options Request options.
*/
export function deleteAndReplaceProjectVersion(options) {
    return executeRequest(() => deleteAndReplaceProjectVersionFn(options), options.errorStrategy);
}
