import { getProjectVersionRelatedIssueCount as getProjectVersionRelatedIssueCountFn } from "../../../raw-api/project/version/count";
import { executeRequest } from "../../../handled-api/common";
import { getProjectVersionUnresolvedIssueCount as getProjectVersionUnresolvedIssueCountFn } from "../../../raw-api/project/version/count";
/**
* Returns the following counts for a version:

 *  Number of issues where the `fixVersion` is set to the version.
 *  Number of issues where the `affectedVersion` is set to the version.
 *  Number of issues where a version custom field is set to the version.

This operation can be accessed anonymously.

**[Permissions](#permissions) required:** *Browse projects* project permission for the project that contains the version.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-version-id-relatedIssueCounts-get
* @param options Request options.
*/
export function getProjectVersionRelatedIssueCount(options) {
    return executeRequest(() => getProjectVersionRelatedIssueCountFn(options), options.errorStrategy);
}
/**
* Returns counts of the issues and unresolved issues for the project version.

This operation can be accessed anonymously.

**[Permissions](#permissions) required:** *Browse projects* project permission for the project that contains the version.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-version-id-unresolvedIssueCount-get
* @param options Request options.
*/
export function getProjectVersionUnresolvedIssueCount(options) {
    return executeRequest(() => getProjectVersionUnresolvedIssueCountFn(options), options.errorStrategy);
}
