import { Screen } from "../types/screen";
/**
* Returns a [paginated](#pagination) list of the screens a field is used in.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-screens/#api-rest-api-3-field-fieldid-screens-get
* @param options Request options.
*/
export declare function getScreensForField<T = Screen.GetScreensForField.Response.OK>(options: Screen.GetScreensForField.Options.HandledApi): Promise<import("../definitions/PageBeanScreenWithTabAsResponse").PageBeanScreenWithTabAsResponse>;
/**
* Returns a [paginated](#pagination) list of all screens or those specified by one or more screen IDs.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-screens/#api-rest-api-3-screens-get
* @param options Request options.
*/
export declare function getScreens<T = Screen.GetScreens.Response.OK>(options: Screen.GetScreens.Options.HandledApi): Promise<import("../definitions/PageBeanScreenAsResponse").PageBeanScreenAsResponse>;
/**
* Creates a screen with a default field tab.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-screens/#api-rest-api-3-screens-post
* @param options Request options.
*/
export declare function createScreen<T = Screen.CreateScreen.Response.OK>(options: Screen.CreateScreen.Options.HandledApi): Promise<import("../definitions/ScreenAsResponse").ScreenAsResponse>;
/**
* Adds a field to the default tab of the default screen.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-screens/#api-rest-api-3-screens-addtodefault-fieldid-post
* @param options Request options.
*/
export declare function addFieldToDefaultScreen<T = Screen.AddFieldToDefaultScreen.Response.OK>(options: Screen.AddFieldToDefaultScreen.Options.HandledApi): Promise<"CREATED">;
/**
* Returns the fields that can be added to a tab on a screen.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-screens/#api-rest-api-3-screens-screenid-availablefields-get
* @param options Request options.
*/
export declare function getAvailableScreenFields<T = Screen.GetAvailableScreenFields.Response.OK>(options: Screen.GetAvailableScreenFields.Options.HandledApi): Promise<Screen.GetAvailableScreenFields.Response.OK>;
/**
* Updates a screen. Only screens used in classic projects can be updated.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-screens/#api-rest-api-3-screens-screenid-put
* @param options Request options.
*/
export declare function updateScreen<T = Screen.UpdateScreen.Response.OK>(options: Screen.UpdateScreen.Options.HandledApi): Promise<import("../definitions/ScreenAsResponse").ScreenAsResponse>;
/**
* Deletes a screen. A screen cannot be deleted if it is used in a screen scheme, workflow, or workflow draft.

Only screens used in classic projects can be deleted.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-screens/#api-rest-api-3-screens-screenid-delete
* @param options Request options.
*/
export declare function deleteScreen<T = Screen.DeleteScreen.Response.OK>(options: Screen.DeleteScreen.Options.HandledApi): Promise<undefined>;
//# sourceMappingURL=screen.d.ts.map