import { getScreensForField as getScreensForFieldFn } from "../raw-api/screen";
import { executeRequest } from "../handled-api/common";
import { getScreens as getScreensFn } from "../raw-api/screen";
import { createScreen as createScreenFn } from "../raw-api/screen";
import { addFieldToDefaultScreen as addFieldToDefaultScreenFn } from "../raw-api/screen";
import { getAvailableScreenFields as getAvailableScreenFieldsFn } from "../raw-api/screen";
import { updateScreen as updateScreenFn } from "../raw-api/screen";
import { deleteScreen as deleteScreenFn } from "../raw-api/screen";
/**
* Returns a [paginated](#pagination) list of the screens a field is used in.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-screens/#api-rest-api-3-field-fieldid-screens-get
* @param options Request options.
*/
export function getScreensForField(options) {
    return executeRequest(() => getScreensForFieldFn(options), options.errorStrategy);
}
/**
* Returns a [paginated](#pagination) list of all screens or those specified by one or more screen IDs.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-screens/#api-rest-api-3-screens-get
* @param options Request options.
*/
export function getScreens(options) {
    return executeRequest(() => getScreensFn(options), options.errorStrategy);
}
/**
* Creates a screen with a default field tab.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-screens/#api-rest-api-3-screens-post
* @param options Request options.
*/
export function createScreen(options) {
    return executeRequest(() => createScreenFn(options), options.errorStrategy);
}
/**
* Adds a field to the default tab of the default screen.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-screens/#api-rest-api-3-screens-addtodefault-fieldid-post
* @param options Request options.
*/
export function addFieldToDefaultScreen(options) {
    return executeRequest(() => addFieldToDefaultScreenFn(options), options.errorStrategy);
}
/**
* Returns the fields that can be added to a tab on a screen.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-screens/#api-rest-api-3-screens-screenid-availablefields-get
* @param options Request options.
*/
export function getAvailableScreenFields(options) {
    return executeRequest(() => getAvailableScreenFieldsFn(options), options.errorStrategy);
}
/**
* Updates a screen. Only screens used in classic projects can be updated.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-screens/#api-rest-api-3-screens-screenid-put
* @param options Request options.
*/
export function updateScreen(options) {
    return executeRequest(() => updateScreenFn(options), options.errorStrategy);
}
/**
* Deletes a screen. A screen cannot be deleted if it is used in a screen scheme, workflow, or workflow draft.

Only screens used in classic projects can be deleted.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-screens/#api-rest-api-3-screens-screenid-delete
* @param options Request options.
*/
export function deleteScreen(options) {
    return executeRequest(() => deleteScreenFn(options), options.errorStrategy);
}
