import { Screen } from "../../types/screen";
/**
* Returns a [paginated](#pagination) list of screen schemes.

Only screen schemes used in classic projects are returned.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-screenscheme-get
* @param options Request options.
*/
export declare function getScreenSchemes<T = Screen.Scheme.GetSchemes.Response.OK>(options: Screen.Scheme.GetSchemes.Options.HandledApi): Promise<import("../../definitions/PageBeanScreenSchemeAsResponse").PageBeanScreenSchemeAsResponse>;
/**
* Creates a screen scheme.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-screen-schemes/#api-rest-api-3-screenscheme-post
* @param options Request options.
*/
export declare function createScreenScheme<T = Screen.Scheme.CreateScheme.Response.OK>(options: Screen.Scheme.CreateScheme.Options.HandledApi): Promise<import("../../definitions/ScreenSchemeIdAsResponse").ScreenSchemeIdAsResponse>;
/**
* Updates a screen scheme. Only screen schemes used in classic projects can be updated.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-screen-schemes/#api-rest-api-3-screenscheme-screenschemeid-put
* @param options Request options.
*/
export declare function updateScreenScheme<T = Screen.Scheme.UpdateScheme.Response.OK>(options: Screen.Scheme.UpdateScheme.Options.HandledApi): Promise<any>;
/**
* Deletes a screen scheme. A screen scheme cannot be deleted if it is used in an issue type screen scheme.

Only screens schemes used in classic projects can be deleted.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-screen-schemes/#api-rest-api-3-screenscheme-screenschemeid-delete
* @param options Request options.
*/
export declare function deleteScreenScheme<T = Screen.Scheme.DeleteScheme.Response.OK>(options: Screen.Scheme.DeleteScheme.Options.HandledApi): Promise<undefined>;
//# sourceMappingURL=scheme.d.ts.map