import { getScreenSchemes as getScreenSchemesFn } from "../../raw-api/screen/scheme";
import { executeRequest } from "../../handled-api/common";
import { createScreenScheme as createScreenSchemeFn } from "../../raw-api/screen/scheme";
import { updateScreenScheme as updateScreenSchemeFn } from "../../raw-api/screen/scheme";
import { deleteScreenScheme as deleteScreenSchemeFn } from "../../raw-api/screen/scheme";
/**
* Returns a [paginated](#pagination) list of screen schemes.

Only screen schemes used in classic projects are returned.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-screenscheme-get
* @param options Request options.
*/
export function getScreenSchemes(options) {
    return executeRequest(() => getScreenSchemesFn(options), options.errorStrategy);
}
/**
* Creates a screen scheme.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-screen-schemes/#api-rest-api-3-screenscheme-post
* @param options Request options.
*/
export function createScreenScheme(options) {
    return executeRequest(() => createScreenSchemeFn(options), options.errorStrategy);
}
/**
* Updates a screen scheme. Only screen schemes used in classic projects can be updated.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-screen-schemes/#api-rest-api-3-screenscheme-screenschemeid-put
* @param options Request options.
*/
export function updateScreenScheme(options) {
    return executeRequest(() => updateScreenSchemeFn(options), options.errorStrategy);
}
/**
* Deletes a screen scheme. A screen scheme cannot be deleted if it is used in an issue type screen scheme.

Only screens schemes used in classic projects can be deleted.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-screen-schemes/#api-rest-api-3-screenscheme-screenschemeid-delete
* @param options Request options.
*/
export function deleteScreenScheme(options) {
    return executeRequest(() => deleteScreenSchemeFn(options), options.errorStrategy);
}
