import { Screen } from "../../types/screen";
/**
* Returns the list of tabs for a screen.

**[Permissions](#permissions) required:**

 *  *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
 *  *Administer projects* [project permission](https://confluence.atlassian.com/x/yodKLg) when the project key is specified, providing that the screen is associated with the project through a Screen Scheme and Issue Type Screen Scheme.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-screens/#api-rest-api-3-screens-screenid-tabs-get
* @param options Request options.
*/
export declare function getScreenTabs<T = Screen.Tab.GetTabs.Response.OK>(options: Screen.Tab.GetTabs.Options.HandledApi): Promise<Screen.Tab.GetTabs.Response.OK>;
/**
* Creates a tab for a screen.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-screens/#api-rest-api-3-screens-screenid-tabs-post
* @param options Request options.
*/
export declare function createScreenTab<T = Screen.Tab.CreateTab.Response.OK>(options: Screen.Tab.CreateTab.Options.HandledApi): Promise<import("../../definitions/ScreenableTabAsResponse").ScreenableTabAsResponse>;
/**
* Updates the name of a screen tab.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-screens/#api-rest-api-3-screens-screenid-tabs-tabid-put
* @param options Request options.
*/
export declare function updateScreenTab<T = Screen.Tab.UpdateTab.Response.OK>(options: Screen.Tab.UpdateTab.Options.HandledApi): Promise<import("../../definitions/ScreenableTabAsResponse").ScreenableTabAsResponse>;
/**
* Deletes a screen tab.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-screens/#api-rest-api-3-screens-screenid-tabs-tabid-delete
* @param options Request options.
*/
export declare function deleteScreenTab<T = Screen.Tab.DeleteTab.Response.OK>(options: Screen.Tab.DeleteTab.Options.HandledApi): Promise<undefined>;
/**
* Moves a screen tab.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-screens/#api-rest-api-3-screens-screenid-tabs-tabid-move-pos-post
* @param options Request options.
*/
export declare function moveScreenTab<T = Screen.Tab.MoveTab.Response.OK>(options: Screen.Tab.MoveTab.Options.HandledApi): Promise<any>;
//# sourceMappingURL=tab.d.ts.map