import { getScreenTabs as getScreenTabsFn } from "../../raw-api/screen/tab";
import { executeRequest } from "../../handled-api/common";
import { createScreenTab as createScreenTabFn } from "../../raw-api/screen/tab";
import { updateScreenTab as updateScreenTabFn } from "../../raw-api/screen/tab";
import { deleteScreenTab as deleteScreenTabFn } from "../../raw-api/screen/tab";
import { moveScreenTab as moveScreenTabFn } from "../../raw-api/screen/tab";
/**
* Returns the list of tabs for a screen.

**[Permissions](#permissions) required:**

 *  *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
 *  *Administer projects* [project permission](https://confluence.atlassian.com/x/yodKLg) when the project key is specified, providing that the screen is associated with the project through a Screen Scheme and Issue Type Screen Scheme.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-screens/#api-rest-api-3-screens-screenid-tabs-get
* @param options Request options.
*/
export function getScreenTabs(options) {
    return executeRequest(() => getScreenTabsFn(options), options.errorStrategy);
}
/**
* Creates a tab for a screen.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-screens/#api-rest-api-3-screens-screenid-tabs-post
* @param options Request options.
*/
export function createScreenTab(options) {
    return executeRequest(() => createScreenTabFn(options), options.errorStrategy);
}
/**
* Updates the name of a screen tab.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-screens/#api-rest-api-3-screens-screenid-tabs-tabid-put
* @param options Request options.
*/
export function updateScreenTab(options) {
    return executeRequest(() => updateScreenTabFn(options), options.errorStrategy);
}
/**
* Deletes a screen tab.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-screens/#api-rest-api-3-screens-screenid-tabs-tabid-delete
* @param options Request options.
*/
export function deleteScreenTab(options) {
    return executeRequest(() => deleteScreenTabFn(options), options.errorStrategy);
}
/**
* Moves a screen tab.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-screens/#api-rest-api-3-screens-screenid-tabs-tabid-move-pos-post
* @param options Request options.
*/
export function moveScreenTab(options) {
    return executeRequest(() => moveScreenTabFn(options), options.errorStrategy);
}
