import { getScreenTabFields as getScreenTabFieldsFn } from "../../../raw-api/screen/tab/field";
import { executeRequest } from "../../../handled-api/common";
import { addScreenTabField as addScreenTabFieldFn } from "../../../raw-api/screen/tab/field";
import { removeScreenTabField as removeScreenTabFieldFn } from "../../../raw-api/screen/tab/field";
import { moveScreenTabField as moveScreenTabFieldFn } from "../../../raw-api/screen/tab/field";
/**
* Returns all fields for a screen tab.

**[Permissions](#permissions) required:**

 *  *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
 *  *Administer projects* [project permission](https://confluence.atlassian.com/x/yodKLg) when the project key is specified, providing that the screen is associated with the project through a Screen Scheme and Issue Type Screen Scheme.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-screens/#api-rest-api-3-screens-screenid-tabs-tabid-fields-get
* @param options Request options.
*/
export function getScreenTabFields(options) {
    return executeRequest(() => getScreenTabFieldsFn(options), options.errorStrategy);
}
/**
* Adds a field to a screen tab.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-screens/#api-rest-api-3-screens-screenid-tabs-tabid-fields-post
* @param options Request options.
*/
export function addScreenTabField(options) {
    return executeRequest(() => addScreenTabFieldFn(options), options.errorStrategy);
}
/**
* Removes a field from a screen tab.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-screens/#api-rest-api-3-screens-screenid-tabs-tabid-fields-id-delete
* @param options Request options.
*/
export function removeScreenTabField(options) {
    return executeRequest(() => removeScreenTabFieldFn(options), options.errorStrategy);
}
/**
* Moves a screen tab field.

If `after` and `position` are provided in the request, `position` is ignored.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-screens/#api-rest-api-3-screens-screenid-tabs-tabid-fields-id-move-post
* @param options Request options.
*/
export function moveScreenTabField(options) {
    return executeRequest(() => moveScreenTabFieldFn(options), options.errorStrategy);
}
