import { getUserDefaultColumns as getUserDefaultColumnsFn } from "../raw-api/user";
import { executeRequest } from "../handled-api/common";
import { setUserDefaultColumns as setUserDefaultColumnsFn } from "../raw-api/user";
import { resetUserDefaultColumns as resetUserDefaultColumnsFn } from "../raw-api/user";
import { getUser as getUserFn } from "../raw-api/user";
import { createUser as createUserFn } from "../raw-api/user";
import { deleteUser as deleteUserFn } from "../raw-api/user";
import { getAccountIdsForUsers as getAccountIdsForUsersFn } from "../raw-api/user";
import { getUserEmail as getUserEmailFn } from "../raw-api/user";
import { getUserGroups as getUserGroupsFn } from "../raw-api/user";
import { getUsers as getUsersFn } from "../raw-api/user";
/**
* Returns the default [issue table columns](https://confluence.atlassian.com/x/XYdKLg) for the user. If `accountId` is not passed in the request, the calling user's details are returned.

**[Permissions](#permissions) required:**

 *  *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLgl), to get the column details for any user.
 *  Permission to access Jira, to get the calling user's column details.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-users/#api-rest-api-3-user-columns-get
* @param options Request options.
*/
export function getUserDefaultColumns(options) {
    return executeRequest(() => getUserDefaultColumnsFn(options), options.errorStrategy);
}
/**
* Sets the default [ issue table columns](https://confluence.atlassian.com/x/XYdKLg) for the user. If an account ID is not passed, the calling user's default columns are set. If no column details are sent, then all default columns are removed.

The parameters for this resource are expressed as HTML form data. For example, in curl:

`curl -X PUT -d columns=summary -d columns=description https://your-domain.atlassian.net/rest/api/3/user/columns?accountId=5b10ac8d82e05b22cc7d4ef5'`

**[Permissions](#permissions) required:**

 *  *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg), to set the columns on any user.
 *  Permission to access Jira, to set the calling user's columns.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-users/#api-rest-api-3-user-columns-put
* @param options Request options.
*/
export function setUserDefaultColumns(options) {
    return executeRequest(() => setUserDefaultColumnsFn(options), options.errorStrategy);
}
/**
* Resets the default [ issue table columns](https://confluence.atlassian.com/x/XYdKLg) for the user to the system default. If `accountId` is not passed, the calling user's default columns are reset.

**[Permissions](#permissions) required:**

 *  *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg), to set the columns on any user.
 *  Permission to access Jira, to set the calling user's columns.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-users/#api-rest-api-3-user-columns-delete
* @param options Request options.
*/
export function resetUserDefaultColumns(options) {
    return executeRequest(() => resetUserDefaultColumnsFn(options), options.errorStrategy);
}
/**
* Returns a user.

**[Permissions](#permissions) required:** *Browse users and groups* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-user-get
* @param options Request options.
*/
export function getUser(options) {
    return executeRequest(() => getUserFn(options), options.errorStrategy);
}
/**
* Creates a user. This resource is retained for legacy compatibility. As soon as a more suitable alternative is available this resource will be deprecated.

If the user exists and has access to Jira, the operation returns a 201 status. If the user exists but does not have access to Jira, the operation returns a 400 status.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-user-post
* @param options Request options.
*/
export function createUser(options) {
    return executeRequest(() => createUserFn(options), options.errorStrategy);
}
/**
* Deletes a user.

**[Permissions](#permissions) required:** Site administration (that is, membership of the *site-admin* [group](https://confluence.atlassian.com/x/24xjL)).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-user-delete
* @param options Request options.
*/
export function deleteUser(options) {
    return executeRequest(() => deleteUserFn(options), options.errorStrategy);
}
/**
* Returns the account IDs for the users specified in the `key` or `username` parameters. Note that multiple `key` or `username` parameters can be specified.

**[Permissions](#permissions) required:** Permission to access Jira.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-user-bulk-migration-get
* @param options Request options.
*/
export function getAccountIdsForUsers(options) {
    return executeRequest(() => getAccountIdsForUsersFn(options), options.errorStrategy);
}
/**
 * Returns a user's email address. This API is only available to apps approved by Atlassian, according to these [guidelines](https://community.developer.atlassian.com/t/guidelines-for-requesting-access-to-email-address/27603).
 * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-user-email-get
 * @param options Request options.
 */
export function getUserEmail(options) {
    return executeRequest(() => getUserEmailFn(options), options.errorStrategy);
}
/**
* Returns the groups to which a user belongs.

**[Permissions](#permissions) required:** *Browse users and groups* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-user-groups-get
* @param options Request options.
*/
export function getUserGroups(options) {
    return executeRequest(() => getUserGroupsFn(options), options.errorStrategy);
}
/**
* Returns a list of all (active and inactive) users.

**[Permissions](#permissions) required:** *Browse users and groups* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-users-search-get
* @param options Request options.
*/
export function getUsers(options) {
    return executeRequest(() => getUsersFn(options), options.errorStrategy);
}
