import { getWorkflowSchemes as getWorkflowSchemesFn } from "../../raw-api/workflow/scheme";
import { executeRequest } from "../../handled-api/common";
import { createWorkflowScheme as createWorkflowSchemeFn } from "../../raw-api/workflow/scheme";
import { getWorkflowScheme as getWorkflowSchemeFn } from "../../raw-api/workflow/scheme";
import { updateWorkflowScheme as updateWorkflowSchemeFn } from "../../raw-api/workflow/scheme";
import { deleteWorkflowScheme as deleteWorkflowSchemeFn } from "../../raw-api/workflow/scheme";
import { getWorkflowForIssueTypeInWorkflowScheme as getWorkflowForIssueTypeInWorkflowSchemeFn } from "../../raw-api/workflow/scheme";
import { setWorkflowForIssueTypeInWorkflowScheme as setWorkflowForIssueTypeInWorkflowSchemeFn } from "../../raw-api/workflow/scheme";
import { deleteWorkflowForIssueTypeInWorkflowScheme as deleteWorkflowForIssueTypeInWorkflowSchemeFn } from "../../raw-api/workflow/scheme";
import { getIssueTypesForWorkflowInWorkflowScheme as getIssueTypesForWorkflowInWorkflowSchemeFn } from "../../raw-api/workflow/scheme";
import { setIssueTypesForWorkflowInWorkflowScheme as setIssueTypesForWorkflowInWorkflowSchemeFn } from "../../raw-api/workflow/scheme";
import { deleteIssueTypesForWorkflowInWorkflowScheme as deleteIssueTypesForWorkflowInWorkflowSchemeFn } from "../../raw-api/workflow/scheme";
import { getDefaultWorkflowForWorkflowScheme as getDefaultWorkflowForWorkflowSchemeFn } from "../../raw-api/workflow/scheme";
import { updateDefaultWorkflowForWorkflowScheme as updateDefaultWorkflowForWorkflowSchemeFn } from "../../raw-api/workflow/scheme";
import { deleteDefaultWorkflowForWorkflowScheme as deleteDefaultWorkflowForWorkflowSchemeFn } from "../../raw-api/workflow/scheme";
/**
* Returns a [paginated](#pagination) list of all workflow schemes, not including draft workflow schemes.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-workflowscheme-get
* @param options Request options.
*/
export function getWorkflowSchemes(options) {
    return executeRequest(() => getWorkflowSchemesFn(options), options.errorStrategy);
}
/**
* Creates a workflow scheme.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-workflow-schemes/#api-rest-api-3-workflowscheme-post
* @param options Request options.
*/
export function createWorkflowScheme(options) {
    return executeRequest(() => createWorkflowSchemeFn(options), options.errorStrategy);
}
/**
* Returns a workflow scheme.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-workflow-schemes/#api-rest-api-3-workflowscheme-id-get
* @param options Request options.
*/
export function getWorkflowScheme(options) {
    return executeRequest(() => getWorkflowSchemeFn(options), options.errorStrategy);
}
/**
* Updates a workflow scheme, including the name, default workflow, issue type to project mappings, and more. If the workflow scheme is active (that is, being used by at least one project), then a draft workflow scheme is created or updated instead, provided that `updateDraftIfNeeded` is set to `true`.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-workflow-schemes/#api-rest-api-3-workflowscheme-id-put
* @param options Request options.
*/
export function updateWorkflowScheme(options) {
    return executeRequest(() => updateWorkflowSchemeFn(options), options.errorStrategy);
}
/**
* Deletes a workflow scheme. Note that a workflow scheme cannot be deleted if it is active (that is, being used by at least one project).

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-workflow-schemes/#api-rest-api-3-workflowscheme-id-delete
* @param options Request options.
*/
export function deleteWorkflowScheme(options) {
    return executeRequest(() => deleteWorkflowSchemeFn(options), options.errorStrategy);
}
/**
* Returns the issue type-workflow mapping for an issue type in a workflow scheme.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-workflow-schemes/#api-rest-api-3-workflowscheme-id-issuetype-issuetype-get
* @param options Request options.
*/
export function getWorkflowForIssueTypeInWorkflowScheme(options) {
    return executeRequest(() => getWorkflowForIssueTypeInWorkflowSchemeFn(options), options.errorStrategy);
}
/**
* Sets the workflow for an issue type in a workflow scheme.

Note that active workflow schemes cannot be edited. If the workflow scheme is active, set `updateDraftIfNeeded` to `true` in the request body and a draft workflow scheme is created or updated with the new issue type-workflow mapping. The draft workflow scheme can be published in Jira.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-workflow-schemes/#api-rest-api-3-workflowscheme-id-issuetype-issuetype-put
* @param options Request options.
*/
export function setWorkflowForIssueTypeInWorkflowScheme(options) {
    return executeRequest(() => setWorkflowForIssueTypeInWorkflowSchemeFn(options), options.errorStrategy);
}
/**
* Deletes the issue type-workflow mapping for an issue type in a workflow scheme.

Note that active workflow schemes cannot be edited. If the workflow scheme is active, set `updateDraftIfNeeded` to `true` and a draft workflow scheme is created or updated with the issue type-workflow mapping deleted. The draft workflow scheme can be published in Jira.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-workflow-schemes/#api-rest-api-3-workflowscheme-id-issuetype-issuetype-delete
* @param options Request options.
*/
export function deleteWorkflowForIssueTypeInWorkflowScheme(options) {
    return executeRequest(() => deleteWorkflowForIssueTypeInWorkflowSchemeFn(options), options.errorStrategy);
}
/**
* Returns the workflow-issue type mappings for a workflow scheme.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-workflow-schemes/#api-rest-api-3-workflowscheme-id-workflow-get
* @param options Request options.
*/
export function getIssueTypesForWorkflowInWorkflowScheme(options) {
    return executeRequest(() => getIssueTypesForWorkflowInWorkflowSchemeFn(options), options.errorStrategy);
}
/**
* Sets the issue types for a workflow in a workflow scheme. The workflow can also be set as the default workflow for the workflow scheme. Unmapped issues types are mapped to the default workflow.

Note that active workflow schemes cannot be edited. If the workflow scheme is active, set `updateDraftIfNeeded` to `true` in the request body and a draft workflow scheme is created or updated with the new workflow-issue types mappings. The draft workflow scheme can be published in Jira.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-workflow-schemes/#api-rest-api-3-workflowscheme-id-workflow-put
* @param options Request options.
*/
export function setIssueTypesForWorkflowInWorkflowScheme(options) {
    return executeRequest(() => setIssueTypesForWorkflowInWorkflowSchemeFn(options), options.errorStrategy);
}
/**
* Deletes the workflow-issue type mapping for a workflow in a workflow scheme.

Note that active workflow schemes cannot be edited. If the workflow scheme is active, set `updateDraftIfNeeded` to `true` and a draft workflow scheme is created or updated with the workflow-issue type mapping deleted. The draft workflow scheme can be published in Jira.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-workflow-schemes/#api-rest-api-3-workflowscheme-id-workflow-delete
* @param options Request options.
*/
export function deleteIssueTypesForWorkflowInWorkflowScheme(options) {
    return executeRequest(() => deleteIssueTypesForWorkflowInWorkflowSchemeFn(options), options.errorStrategy);
}
/**
* Returns the default workflow for a workflow scheme. The default workflow is the workflow that is assigned any issue types that have not been mapped to any other workflow. The default workflow has *All Unassigned Issue Types* listed in its issue types for the workflow scheme in Jira.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-workflow-schemes/#api-rest-api-3-workflowscheme-id-default-get
* @param options Request options.
*/
export function getDefaultWorkflowForWorkflowScheme(options) {
    return executeRequest(() => getDefaultWorkflowForWorkflowSchemeFn(options), options.errorStrategy);
}
/**
* Sets the default workflow for a workflow scheme.

Note that active workflow schemes cannot be edited. If the workflow scheme is active, set `updateDraftIfNeeded` to `true` in the request object and a draft workflow scheme is created or updated with the new default workflow. The draft workflow scheme can be published in Jira.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-workflow-schemes/#api-rest-api-3-workflowscheme-id-default-put
* @param options Request options.
*/
export function updateDefaultWorkflowForWorkflowScheme(options) {
    return executeRequest(() => updateDefaultWorkflowForWorkflowSchemeFn(options), options.errorStrategy);
}
/**
* Resets the default workflow for a workflow scheme. That is, the default workflow is set to Jira's system workflow (the *jira* workflow).

Note that active workflow schemes cannot be edited. If the workflow scheme is active, set `updateDraftIfNeeded` to `true` and a draft workflow scheme is created or updated with the default workflow reset. The draft workflow scheme can be published in Jira.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-workflow-schemes/#api-rest-api-3-workflowscheme-id-default-delete
* @param options Request options.
*/
export function deleteDefaultWorkflowForWorkflowScheme(options) {
    return executeRequest(() => deleteDefaultWorkflowForWorkflowSchemeFn(options), options.errorStrategy);
}
