import { Workflow } from "../../../types/workflow";
/**
* Updates a workflow transition by changing the property value. Trying to update a property that does not exist results in a new property being added to the transition. Transition properties are used to change the behavior of a transition. For more information, see [Transition properties](https://confluence.atlassian.com/x/zIhKLg#Advancedworkflowconfiguration-transitionproperties) and [Workflow properties](https://confluence.atlassian.com/x/JYlKLg).

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-workflow-transition-properties/#api-rest-api-3-workflow-transitions-transitionid-properties-put
* @param options Request options.
*/
export declare function updateWorkflowTransitionProperty<T = Workflow.Transition.Property.UpdateProperty.Response.OK>(options: Workflow.Transition.Property.UpdateProperty.Options.HandledApi): Promise<import("../../../definitions/WorkflowTransitionPropertyAsResponse").WorkflowTransitionPropertyAsResponse>;
/**
* Adds a property to a workflow transition. Transition properties are used to change the behavior of a transition. For more information, see [Transition properties](https://confluence.atlassian.com/x/zIhKLg#Advancedworkflowconfiguration-transitionproperties) and [Workflow properties](https://confluence.atlassian.com/x/JYlKLg).

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-workflow-transition-properties/#api-rest-api-3-workflow-transitions-transitionid-properties-post
* @param options Request options.
*/
export declare function createWorkflowTransitionProperty<T = Workflow.Transition.Property.CreateProperty.Response.OK>(options: Workflow.Transition.Property.CreateProperty.Options.HandledApi): Promise<import("../../../definitions/WorkflowTransitionPropertyAsResponse").WorkflowTransitionPropertyAsResponse>;
/**
* Deletes a property from a workflow transition. Transition properties are used to change the behavior of a transition. For more information, see [Transition properties](https://confluence.atlassian.com/x/zIhKLg#Advancedworkflowconfiguration-transitionproperties) and [Workflow properties](https://confluence.atlassian.com/x/JYlKLg).

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-workflow-transition-properties/#api-rest-api-3-workflow-transitions-transitionid-properties-delete
* @param options Request options.
*/
export declare function deleteWorkflowTransitionProperty<T = Workflow.Transition.Property.DeleteProperty.Response.OK>(options: Workflow.Transition.Property.DeleteProperty.Options.HandledApi): Promise<undefined>;
//# sourceMappingURL=property.d.ts.map