import { updateWorkflowTransitionProperty as updateWorkflowTransitionPropertyFn } from "../../../raw-api/workflow/transition/property";
import { executeRequest } from "../../../handled-api/common";
import { createWorkflowTransitionProperty as createWorkflowTransitionPropertyFn } from "../../../raw-api/workflow/transition/property";
import { deleteWorkflowTransitionProperty as deleteWorkflowTransitionPropertyFn } from "../../../raw-api/workflow/transition/property";
/**
* Updates a workflow transition by changing the property value. Trying to update a property that does not exist results in a new property being added to the transition. Transition properties are used to change the behavior of a transition. For more information, see [Transition properties](https://confluence.atlassian.com/x/zIhKLg#Advancedworkflowconfiguration-transitionproperties) and [Workflow properties](https://confluence.atlassian.com/x/JYlKLg).

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-workflow-transition-properties/#api-rest-api-3-workflow-transitions-transitionid-properties-put
* @param options Request options.
*/
export function updateWorkflowTransitionProperty(options) {
    return executeRequest(() => updateWorkflowTransitionPropertyFn(options), options.errorStrategy);
}
/**
* Adds a property to a workflow transition. Transition properties are used to change the behavior of a transition. For more information, see [Transition properties](https://confluence.atlassian.com/x/zIhKLg#Advancedworkflowconfiguration-transitionproperties) and [Workflow properties](https://confluence.atlassian.com/x/JYlKLg).

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-workflow-transition-properties/#api-rest-api-3-workflow-transitions-transitionid-properties-post
* @param options Request options.
*/
export function createWorkflowTransitionProperty(options) {
    return executeRequest(() => createWorkflowTransitionPropertyFn(options), options.errorStrategy);
}
/**
* Deletes a property from a workflow transition. Transition properties are used to change the behavior of a transition. For more information, see [Transition properties](https://confluence.atlassian.com/x/zIhKLg#Advancedworkflowconfiguration-transitionproperties) and [Workflow properties](https://confluence.atlassian.com/x/JYlKLg).

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-workflow-transition-properties/#api-rest-api-3-workflow-transitions-transitionid-properties-delete
* @param options Request options.
*/
export function deleteWorkflowTransitionProperty(options) {
    return executeRequest(() => deleteWorkflowTransitionPropertyFn(options), options.errorStrategy);
}
