import { httpGet } from "../../raw-api/common";
/**
* Returns all application roles. In Jira, application roles are managed using the [Application access configuration](https://confluence.atlassian.com/x/3YxjL) page.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-application-roles/#api-rest-api-3-applicationrole-get
* @param options Request options.
*/
export function getApplicationRoles(options) {
    const { connectionId: instanceId, headers } = options;
    return httpGet(instanceId, `/rest/api/3/applicationrole`, headers);
}
/**
* Returns an application role.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-application-roles/#api-rest-api-3-applicationrole-key-get
* @param options Request options.
*/
export function getApplicationRole(options) {
    const { connectionId: instanceId, headers, key } = options;
    return httpGet(instanceId, `/rest/api/3/applicationrole/${key}`, headers);
}
