import { httpGet } from "../../raw-api/common";
import { httpPut } from "../../raw-api/common";
import { httpDelete } from "../../raw-api/common";
/**
* Returns the columns configured for a filter. The column configuration is used when the filter's results are viewed in *List View* with the *Columns* set to *Filter*.

This operation can be accessed anonymously.

**[Permissions](#permissions) required:** None, however, column details are only returned for:

 *  filters owned by the user.
 *  filters shared with a group that the user is a member of.
 *  filters shared with a private project that the user has *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for.
 *  filters shared with a public project.
 *  filters shared with the public.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-filter-id-columns-get
* @param options Request options.
*/
export function getFilterColumns(options) {
    const { connectionId: instanceId, headers, id } = options;
    return httpGet(instanceId, `/rest/api/3/filter/${id}/columns`, headers);
}
/**
* Sets the columns for a filter. Only navigable fields can be set as columns. Use [Get fields](#api-rest-api-3-field-get) to get the list fields in Jira. A navigable field has `navigable` set to `true`.

The parameters for this resource are expressed as HTML form data. For example, in curl:

`curl -X PUT -d columns=summary -d columns=description https://your-domain.atlassian.net/rest/api/3/filter/10000/columns`

**[Permissions](#permissions) required:** Permission to access Jira, however, columns are only set for:

 *  filters owned by the user.
 *  filters shared with a group that the user is a member of.
 *  filters shared with a private project that the user has *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for.
 *  filters shared with a public project.
 *  filters shared with the public.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-filter-id-columns-put
* @param options Request options.
*/
export function setFilterColumns(options) {
    const { connectionId: instanceId, headers, id, body } = options;
    return httpPut(instanceId, `/rest/api/3/filter/${id}/columns`, body, headers);
}
/**
* Reset the user's column configuration for the filter to the default.

**[Permissions](#permissions) required:** Permission to access Jira, however, columns are only reset for:

 *  filters owned by the user.
 *  filters shared with a group that the user is a member of.
 *  filters shared with a private project that the user has *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for.
 *  filters shared with a public project.
 *  filters shared with the public.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-filter-id-columns-delete
* @param options Request options.
*/
export function resetFilterColumns(options) {
    const { connectionId: instanceId, headers, id } = options;
    return httpDelete(instanceId, `/rest/api/3/filter/${id}/columns`, headers, true);
}
