import { Filter } from "../../../types/filter";
/**
* Returns the share permissions for a filter. A filter can be shared with groups, projects, all logged-in users, or the public. Sharing with all logged-in users or the public is known as a global share permission.

This operation can be accessed anonymously.

**[Permissions](#permissions) required:** None, however, share permissions are only returned for:

 *  filters owned by the user.
 *  filters shared with a group that the user is a member of.
 *  filters shared with a private project that the user has *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for.
 *  filters shared with a public project.
 *  filters shared with the public.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-filter-sharing/#api-rest-api-3-filter-id-permission-get
* @param options Request options.
*/
export declare function getFiltersSharePermissions(options: Filter.Share.Permission.GetPermissions.Options.RawApi): Promise<import("@avst-api/commons").Response<Filter.Share.Permission.GetPermissions.Response.OK | undefined>>;
/**
* Add a share permissions to a filter. If you add a global share permission (one for all logged-in users or the public) it will overwrite all share permissions for the filter.

Be aware that this operation uses different objects for updating share permissions compared to [Update filter](#api-rest-api-3-filter-id-put).

**[Permissions](#permissions) required:** *Share dashboards and filters* [global permission](https://confluence.atlassian.com/x/x4dKLg) and the user must own the filter.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-filter-sharing/#api-rest-api-3-filter-id-permission-post
* @param options Request options.
*/
export declare function addFiltersSharePermission(options: Filter.Share.Permission.AddPermission.Options.RawApi): Promise<import("@avst-api/commons").Response<Filter.Share.Permission.AddPermission.Response.OK | undefined>>;
/**
* Returns a share permission for a filter. A filter can be shared with groups, projects, all logged-in users, or the public. Sharing with all logged-in users or the public is known as a global share permission.

This operation can be accessed anonymously.

**[Permissions](#permissions) required:** None, however, a share permission is only returned for:

 *  filters owned by the user.
 *  filters shared with a group that the user is a member of.
 *  filters shared with a private project that the user has *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for.
 *  filters shared with a public project.
 *  filters shared with the public.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-filter-sharing/#api-rest-api-3-filter-id-permission-permissionid-get
* @param options Request options.
*/
export declare function getFiltersSharePermission(options: Filter.Share.Permission.GetPermission.Options.RawApi): Promise<import("@avst-api/commons").Response<import("../../../definitions/SharePermissionAsResponse").SharePermissionAsResponse | undefined>>;
/**
* Deletes a share permission from a filter.

**[Permissions](#permissions) required:** Permission to access Jira and the user must own the filter.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-filter-sharing/#api-rest-api-3-filter-id-permission-permissionid-delete
* @param options Request options.
*/
export declare function deleteFiltersSharePermission(options: Filter.Share.Permission.DeletePermission.Options.RawApi): Promise<import("@avst-api/commons").Response<undefined>>;
//# sourceMappingURL=permission.d.ts.map