import { httpGet } from "../../raw-api/common";
import { constructUrl } from "@avst-api/commons";
import { httpPost } from "../../raw-api/common";
import { httpDelete } from "../../raw-api/common";
/**
* Returns a [paginated](#pagination) list of all users in a group.

Note that users are ordered by username, however the username is not returned in the results due to privacy reasons.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-group-member-get
* @param options Request options.
*/
export function getUsersFromGroup(options) {
    const { connectionId: instanceId, headers, groupname, includeInactiveUsers, startAt, maxResults } = options;
    const queryParams = { groupname, includeInactiveUsers, startAt, maxResults };
    return httpGet(instanceId, constructUrl(`/rest/api/3/group/member`, queryParams), headers);
}
/**
* Adds a user to a group.

**[Permissions](#permissions) required:** Site administration (that is, member of the *site-admin* [group](https://confluence.atlassian.com/x/24xjL)).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-group-user-post
* @param options Request options.
*/
export function addUserToGroup(options) {
    const { connectionId: instanceId, headers, body, groupname } = options;
    const queryParams = { groupname };
    return httpPost(instanceId, constructUrl(`/rest/api/3/group/user`, queryParams), body, headers);
}
/**
* Removes a user from a group.

**[Permissions](#permissions) required:** Site administration (that is, member of the *site-admin* [group](https://confluence.atlassian.com/x/24xjL)).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-group-user-delete
* @param options Request options.
*/
export function removeUserFromGroup(options) {
    const { connectionId: instanceId, headers, groupname, username, accountId } = options;
    const queryParams = { groupname, username, accountId };
    return httpDelete(instanceId, constructUrl(`/rest/api/3/group/user`, queryParams), headers, true);
}
