import { Issue } from "../../../types/issue";
/**
* Returns the metadata for an attachment. Note that the attachment itself is not returned.

This operation can be accessed anonymously.

**[Permissions](#permissions) required:**

 *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
 *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-attachment-id-get
* @param options Request options.
*/
export declare function getIssueAttachmentMetadata(options: Issue.Attachment.Metadata.GetMetadata.Options.RawApi): Promise<import("@avst-api/commons").Response<import("../../../definitions/AttachmentMetadataAsResponse").AttachmentMetadataAsResponse | undefined>>;
/**
* Returns the metadata for the contents of an attachment, if it is an archive, and metadata for the attachment itself. For example, if the attachment is a ZIP archive, then information about the files in the archive is returned and metadata for the ZIP archive. Currently, only the ZIP archive format is supported.

Use this operation to retrieve data that is presented to the user, as this operation returns the metadata for the attachment itself, such as the attachment's ID and name. Otherwise, use [ Get contents metadata for an expanded attachment](#api-rest-api-3-attachment-id-expand-raw-get), which only returns the metadata for the attachment's contents.

This operation can be accessed anonymously.

**[Permissions](#permissions) required:** For the issue containing the attachment:

 *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
 *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-attachment-id-expand-human-get
* @param options Request options.
*/
export declare function getMetadataForExpandedIssueAttachment(options: Issue.Attachment.Metadata.GetMetadataForExpandedAttachment.Options.RawApi): Promise<import("@avst-api/commons").Response<import("../../../definitions/AttachmentArchiveMetadataReadableAsResponse").AttachmentArchiveMetadataReadableAsResponse | undefined>>;
/**
* Returns the metadata for the contents of an attachment, if it is an archive. For example, if the attachment is a ZIP archive, then information about the files in the archive is returned. Currently, only the ZIP archive format is supported.

Use this operation if you are processing the data without presenting it to the user, as this operation only returns the metadata for the contents of the attachment. Otherwise, to retrieve data to present to the user, use [ Get all metadata for an expanded attachment](#api-rest-api-3-attachment-id-expand-human-get) which also returns the metadata for the attachment itself, such as the attachment's ID and name.

This operation can be accessed anonymously.

**[Permissions](#permissions) required:** For the issue containing the attachment:

 *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
 *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-attachment-id-expand-raw-get
* @param options Request options.
*/
export declare function getContentsMetadataForExpandedIssueAttachment(options: Issue.Attachment.Metadata.GetContentsMetadataForExpandedAttachment.Options.RawApi): Promise<import("@avst-api/commons").Response<import("../../../definitions/AttachmentArchiveImplAsResponse").AttachmentArchiveImplAsResponse | undefined>>;
//# sourceMappingURL=metadata.d.ts.map