import { Issue } from "../../types/issue";
/**
* Returns system and custom issue fields according to the following rules:

 *  Fields that cannot be added to the issue navigator are always returned.
 *  Fields that cannot be placed on an issue screen are always returned.
 *  Fields that depend on global Jira settings are only returned if the setting is enabled. That is, timetracking fields, subtasks, votes, and watches.
 *  For all other fields, this operation only returns the fields that the user has permission to view (that is, the field is used in at least one project that the user has *Browse Projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for.)

This operation can be accessed anonymously.

**[Permissions](#permissions) required:** None.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-field-get
* @param options Request options.
*/
export declare function getIssueFields(options: Issue.Field.GetFields.Options.RawApi): Promise<import("@avst-api/commons").Response<Issue.Field.GetFields.Response.OK | undefined>>;
/**
* Returns a [paginated](#pagination) list of fields for Classic Jira projects. The list can include:

 *  all fields.
 *  specific fields, by defining `id`.
 *  fields that contain a string in the field name or description, by defining `query`.
 *  specific fields that contain a string in the field name or description, by defining `id` and `query`.

Only custom fields can be queried, `type` must be set to `custom`.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-field-search-get
* @param options Request options.
*/
export declare function getFieldsPaginated(options: Issue.Field.GetFieldsPaginated.Options.RawApi): Promise<import("@avst-api/commons").Response<import("../../definitions/ErrorCollectionAsResponse").ErrorCollectionAsResponse | import("../../definitions/PageBeanFieldAsResponse").PageBeanFieldAsResponse | undefined>>;
/**
* Returns a [paginated](#pagination) list of the contexts a field is used in. Deprecated, use [ Get custom field contexts](#api-rest-api-3-field-fieldId-context-get).

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-fields/#api-rest-api-3-field-fieldid-contexts-get
* @param options Request options.
* @deprecated
*/
export declare function getFieldContexts(options: Issue.Field.GetContexts.Options.RawApi): Promise<import("@avst-api/commons").Response<import("../../definitions/PageBeanContextAsResponse").PageBeanContextAsResponse | undefined>>;
/**
* Deletes a custom field. The custom field is deleted whether it is in the trash or not. See [Edit or delete a custom field](https://confluence.atlassian.com/x/Z44fOw) for more information on trashing and deleting custom fields.

This operation is [asynchronous](#async). Follow the `location` link in the response to determine the status of the task and use [Get task](#api-rest-api-3-task-taskId-get) to obtain subsequent updates.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-fields/#api-rest-api-3-field-id-delete
* @param options Request options.
*/
export declare function deleteIssueCustomField(options: Issue.Field.DeleteField.Options.RawApi): Promise<import("@avst-api/commons").Response<any>>;
/**
* Restores a custom field from trash. See [Edit or delete a custom field](https://confluence.atlassian.com/x/Z44fOw) for more information on trashing and deleting custom fields.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-fields/#api-rest-api-3-field-id-restore-post
* @param options Request options.
*/
export declare function restoreIssueCustomField(options: Issue.Field.RestoreField.Options.RawApi): Promise<import("@avst-api/commons").Response<any>>;
/**
* Moves a custom field to trash. See [Edit or delete a custom field](https://confluence.atlassian.com/x/Z44fOw) for more information on trashing and deleting custom fields.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-fields/#api-rest-api-3-field-id-trash-post
* @param options Request options.
*/
export declare function moveIssueCustomFieldToTrash(options: Issue.Field.MoveToTrash.Options.RawApi): Promise<import("@avst-api/commons").Response<any>>;
//# sourceMappingURL=field.d.ts.map