import { Issue } from "../../../types/issue";
/**
* Creates a field configuration. The field configuration is created with the same field properties as the default configuration, with all the fields being optional.

This operation can only create configurations for use in company-managed (classic) projects.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-field-configurations/#api-rest-api-3-fieldconfiguration-post
* @param options Request options.
*/
export declare function createIssueFieldConfiguration(options: Issue.Field.Configuration.CreateConfiguration.Options.RawApi): Promise<import("@avst-api/commons").Response<import("../../../definitions/FieldConfigurationAsResponse").FieldConfigurationAsResponse | undefined>>;
/**
* Returns a [paginated](#pagination) list of field configurations. The list can be for all field configurations or a subset determined by any combination of these criteria:

 *  a list of field configuration item IDs.
 *  whether the field configuration is a default.
 *  whether the field configuration name or description contains a query string.

Only field configurations used in company-managed (classic) projects are returned.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-fieldconfiguration-get
* @param options Request options.
*/
export declare function getIssueFieldConfigurations(options: Issue.Field.Configuration.GetConfigurations.Options.RawApi): Promise<import("@avst-api/commons").Response<import("../../../definitions/PageBeanFieldConfigurationDetailsAsResponse").PageBeanFieldConfigurationDetailsAsResponse | undefined>>;
/**
* Updates a field configuration. The name and the description provided in the request override the existing values.

This operation can only update configurations used in company-managed (classic) projects.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-field-configurations/#api-rest-api-3-fieldconfiguration-id-put
* @param options Request options.
*/
export declare function updateIssueFieldConfiguration(options: Issue.Field.Configuration.UpdateConfiguration.Options.RawApi): Promise<import("@avst-api/commons").Response<any>>;
/**
* Deletes a field configuration.

This operation can only delete configurations used in company-managed (classic) projects.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-field-configurations/#api-rest-api-3-fieldconfiguration-id-delete
* @param options Request options.
*/
export declare function deleteIssueFieldConfiguration(options: Issue.Field.Configuration.DeleteConfiguration.Options.RawApi): Promise<import("@avst-api/commons").Response<any>>;
/**
* Returns a [paginated](#pagination) list of all fields for a configuration.

Only the fields from configurations used in company-managed (classic) projects are returned.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-fieldconfiguration-id-fields-get
* @param options Request options.
*/
export declare function getIssueFieldConfigurationItems(options: Issue.Field.Configuration.GetConfigurationItems.Options.RawApi): Promise<import("@avst-api/commons").Response<import("../../../definitions/PageBeanFieldConfigurationItemAsResponse").PageBeanFieldConfigurationItemAsResponse | undefined>>;
/**
* Returns a [paginated](#pagination) list of field configuration issue type items.

Only items used in classic projects are returned.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-fieldconfigurationscheme-mapping-get
* @param options Request options.
*/
export declare function getIssueFieldConfigurationIssueTypeItems(options: Issue.Field.Configuration.GetConfigurationIssueTypeItems.Options.RawApi): Promise<import("@avst-api/commons").Response<import("../../../definitions/PageBeanFieldConfigurationIssueTypeItemAsResponse").PageBeanFieldConfigurationIssueTypeItemAsResponse | undefined>>;
/**
* Returns a [paginated](#pagination) list of field configuration schemes.

Only field configuration schemes used in classic projects are returned.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-field-configurations/#api-rest-api-3-fieldconfigurationscheme-get
* @param options Request options.
*/
export declare function getIssueFieldConfigurationSchemes(options: Issue.Field.Configuration.GetSchemes.Options.RawApi): Promise<import("@avst-api/commons").Response<import("../../../definitions/PageBeanFieldConfigurationSchemeAsResponse").PageBeanFieldConfigurationSchemeAsResponse | undefined>>;
//# sourceMappingURL=configuration.d.ts.map