import { Issue } from "../../../../types/issue";
/**
* Returns a [paginated](#pagination) list of [ contexts](https://confluence.atlassian.com/adminjiracloud/what-are-custom-field-contexts-991923859.html) for a custom field. Contexts can be returned as follows:

 *  With no other parameters set, all contexts.
 *  By defining `id` only, all contexts from the list of IDs.
 *  By defining `isAnyIssueType`, limit the list of contexts returned to either those that apply to all issue types (true) or those that apply to only a subset of issue types (false)
 *  By defining `isGlobalContext`, limit the list of contexts return to either those that apply to all projects (global contexts) (true) or those that apply to only a subset of projects (false).

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-custom-field-contexts/#api-rest-api-3-field-fieldid-context-get
* @param options Request options.
*/
export declare function getIssueCustomFieldContexts(options: Issue.Field.Custom.Context.GetContexts.Options.RawApi): Promise<import("@avst-api/commons").Response<import("../../../../definitions/PageBeanCustomFieldContextAsResponse").PageBeanCustomFieldContextAsResponse | undefined>>;
/**
* Creates a custom field context.

If `projectIds` is empty, a global context is created. A global context is one that applies to all project. If `issueTypeIds` is empty, the context applies to all issue types.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-custom-field-contexts/#api-rest-api-3-field-fieldid-context-post
* @param options Request options.
*/
export declare function createIssueCustomFieldContext(options: Issue.Field.Custom.Context.CreateContext.Options.RawApi): Promise<import("@avst-api/commons").Response<import("../../../../definitions/CreateCustomFieldContextAsResponse").CreateCustomFieldContextAsResponse | undefined>>;
/**
* Returns a [paginated](#pagination) list of defaults for a custom field. The results can be filtered by `contextId`, otherwise all values are returned. If no defaults are set for a context, nothing is returned.
The returned object depends on type of the custom field:

 *  `CustomFieldContextDefaultValueDate` (type `datepicker`) for date fields.
 *  `CustomFieldContextDefaultValueDateTime` (type `datetimepicker`) for date-time fields.
 *  `CustomFieldContextDefaultValueSingleOption` (type `option.single`) for single choice select lists and radio buttons.
 *  `CustomFieldContextDefaultValueMultipleOption` (type `option.multiple`) for multiple choice select lists and checkboxes.
 *  `CustomFieldContextDefaultValueCascadingOption` (type `option.cascading`) for cascading select lists.
 *  `CustomFieldContextSingleUserPickerDefaults` (type `single.user.select`) for single users.
 *  `CustomFieldContextDefaultValueMultiUserPicker` (type `multi.user.select`) for user lists.
 *  `CustomFieldContextDefaultValueSingleGroupPicker` (type `grouppicker.single`) for single choice group picker.
 *  `CustomFieldContextDefaultValueMultipleGroupPicker` (type `grouppicker.multiple`) for multiple choice group picker.
 *  `CustomFieldContextDefaultValueURL` (type `url`) for URL.
 *  `CustomFieldContextDefaultValueProject` (type `project`) for project picker.
 *  `CustomFieldContextDefaultValueFloat` (type `float`) for float (a floating-point number).
 *  `CustomFieldContextDefaultValueLabels` (type `labels`) for labels.
 *  `CustomFieldContextDefaultValueTextField` (type `textfield`) for text field.
 *  `CustomFieldContextDefaultValueTextArea` (type `textarea`) for text area field.
 *  `CustomFieldContextDefaultValueReadOnly` (type `readonly`) for read only (text) field.
 *  `CustomFieldContextDefaultValueMultipleVersion` (type `version.multiple`) for single choice version picker.
 *  `CustomFieldContextDefaultValueSingleVersion` (type `version.single`) for multiple choice version picker.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-custom-field-contexts/#api-rest-api-3-field-fieldid-context-defaultvalue-get
* @param options Request options.
*/
export declare function getIssueCustomFieldDefaultContexts(options: Issue.Field.Custom.Context.GetDefaultContexts.Options.RawApi): Promise<import("@avst-api/commons").Response<import("../../../../definitions/PageBeanCustomFieldContextDefaultValueAsResponse").PageBeanCustomFieldContextDefaultValueAsResponse | undefined>>;
/**
* Sets default for contexts of a custom field. Default are defined using these objects:

 *  `CustomFieldContextDefaultValueDate` (type `datepicker`) for date fields.
 *  `CustomFieldContextDefaultValueDateTime` (type `datetimepicker`) for date-time fields.
 *  `CustomFieldContextDefaultValueSingleOption` (type `option.single`) for single choice select lists and radio buttons.
 *  `CustomFieldContextDefaultValueMultipleOption` (type `option.multiple`) for multiple choice select lists and checkboxes.
 *  `CustomFieldContextDefaultValueCascadingOption` (type `option.cascading`) for cascading select lists.
 *  `CustomFieldContextSingleUserPickerDefaults` (type `single.user.select`) for single users.
 *  `CustomFieldContextDefaultValueMultiUserPicker` (type `multi.user.select`) for user lists.
 *  `CustomFieldContextDefaultValueSingleGroupPicker` (type `grouppicker.single`) for single choice group picker.
 *  `CustomFieldContextDefaultValueMultipleGroupPicker` (type `grouppicker.multiple`) for multiple choice group picker.
 *  `CustomFieldContextDefaultValueURL` (type `url`) for URL.
 *  `CustomFieldContextDefaultValueProject` (type `project`) for project picker.
 *  `CustomFieldContextDefaultValueFloat` (type `float`) for float (a floating-point number).
 *  `CustomFieldContextDefaultValueLabels` (type `labels`) for labels.
 *  `CustomFieldContextDefaultValueTextField` (type `textfield`) for text field.
 *  `CustomFieldContextDefaultValueTextArea` (type `textarea`) for text area field.
 *  `CustomFieldContextDefaultValueReadOnly` (type `readonly`) for read only (text) field.
 *  `CustomFieldContextDefaultValueMultipleVersion` (type `version.multiple`) for single choice version picker.
 *  `CustomFieldContextDefaultValueSingleVersion` (type `version.single`) for multiple choice version picker.

Only one type of default object can be included in a request. To remove a default for a context, set the default parameter to `null`.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-custom-field-contexts/#api-rest-api-3-field-fieldid-context-defaultvalue-put
* @param options Request options.
*/
export declare function setIssueCustomFieldDefaultContexts(options: Issue.Field.Custom.Context.SetDefaultContexts.Options.RawApi): Promise<import("@avst-api/commons").Response<any>>;
/**
* Returns a [paginated](#pagination) list of context to issue type mappings for a custom field. Mappings are returned for all contexts or a list of contexts. Mappings are ordered first by context ID and then by issue type ID.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-custom-field-contexts/#api-rest-api-3-field-fieldid-context-issuetypemapping-get
* @param options Request options.
*/
export declare function getIssueCustomFieldIssueTypesForContext(options: Issue.Field.Custom.Context.GetIssueTypes.Options.RawApi): Promise<import("@avst-api/commons").Response<import("../../../../definitions/PageBeanIssueTypeToContextMappingAsResponse").PageBeanIssueTypeToContextMappingAsResponse | undefined>>;
/**
* Returns a [paginated](#pagination) list of context to project mappings for a custom field. The result can be filtered by `contextId`. Otherwise, all mappings are returned. Invalid IDs are ignored.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-custom-field-contexts/#api-rest-api-3-field-fieldid-context-projectmapping-get
* @param options Request options.
*/
export declare function getIssueCustomFieldContextToProjectMappings(options: Issue.Field.Custom.Context.GetProjectMappings.Options.RawApi): Promise<import("@avst-api/commons").Response<import("../../../../definitions/PageBeanCustomFieldContextProjectMappingAsResponse").PageBeanCustomFieldContextProjectMappingAsResponse | undefined>>;
/**
* Updates a [ custom field context](https://confluence.atlassian.com/adminjiracloud/what-are-custom-field-contexts-991923859.html).

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-custom-field-contexts/#api-rest-api-3-field-fieldid-context-contextid-put
* @param options Request options.
*/
export declare function updateIssueCustomFieldContext(options: Issue.Field.Custom.Context.UpdateContext.Options.RawApi): Promise<import("@avst-api/commons").Response<any>>;
/**
* Adds issue types to a custom field context, appending the issue types to the issue types list.

A custom field context without any issue types applies to all issue types. Adding issue types to such a custom field context would result in it applying to only the listed issue types.

If any of the issue types exists in the custom field context, the operation fails and no issue types are added.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-custom-field-contexts/#api-rest-api-3-field-fieldid-context-contextid-issuetype-put
* @param options Request options.
*/
export declare function addIssueTypesToIssueCustomFieldContext(options: Issue.Field.Custom.Context.AddIssueTypes.Options.RawApi): Promise<import("@avst-api/commons").Response<any>>;
/**
* Removes issue types from a custom field context.

A custom field context without any issue types applies to all issue types.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-custom-field-contexts/#api-rest-api-3-field-fieldid-context-contextid-issuetype-remove-post
* @param options Request options.
*/
export declare function removeIssueTypesFromIssueCustomFieldContext(options: Issue.Field.Custom.Context.RemoveIssueTypes.Options.RawApi): Promise<import("@avst-api/commons").Response<any>>;
/**
* Assigns a custom field context to projects.

If any project in the request is assigned to any context of the custom field, the operation fails.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-custom-field-contexts/#api-rest-api-3-field-fieldid-context-contextid-project-put
* @param options Request options.
*/
export declare function assignIssueCustomFieldContextToProjects(options: Issue.Field.Custom.Context.AssignToProjects.Options.RawApi): Promise<import("@avst-api/commons").Response<any>>;
/**
* Removes a custom field context from projects.

A custom field context without any projects applies to all projects. Removing all projects from a custom field context would result in it applying to all projects.

If any project in the request is not assigned to the context, or the operation would result in two global contexts for the field, the operation fails.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-custom-field-contexts/#api-rest-api-3-field-fieldid-context-contextid-project-remove-post
* @param options Request options.
*/
export declare function removeIssueCustomFieldContextFromProjects(options: Issue.Field.Custom.Context.RemoveFromProjects.Options.RawApi): Promise<import("@avst-api/commons").Response<any>>;
//# sourceMappingURL=context.d.ts.map