import { Issue } from "../../../../../types/issue";
/**
* Returns a [paginated](#pagination) list of all custom field option for a context. Options are returned first then cascading options, in the order they display in Jira.

This operation works for custom field options created in Jira or the operations from this resource. **To work with issue field select list options created for Connect apps use the [Issue custom field options (apps)](#api-group-issue-custom-field-options--apps-) operations.**

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-custom-field-options/#api-rest-api-3-field-fieldid-context-contextid-option-get
* @param options Request options.
*/
export declare function getIssueCustomFieldContextOptions(options: Issue.Field.Custom.Context.Option.GetOptions.Options.RawApi): Promise<import("@avst-api/commons").Response<import("../../../../../definitions/PageBeanCustomFieldContextOptionAsResponse").PageBeanCustomFieldContextOptionAsResponse | undefined>>;
/**
* Creates options and, where the custom select field is of the type Select List (cascading), cascading options for a custom select field. The options are added to a context of the field.

The maximum number of options that can be created per request is 1000 and each field can have a maximum of 10000 options.

This operation works for custom field options created in Jira or the operations from this resource. **To work with issue field select list options created for Connect apps use the [Issue custom field options (apps)](#api-group-issue-custom-field-options--apps-) operations.**

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-custom-field-options/#api-rest-api-3-field-fieldid-context-contextid-option-post
* @param options Request options.
*/
export declare function createIssueCustomFieldContextOptions(options: Issue.Field.Custom.Context.Option.CreateOptions.Options.RawApi): Promise<import("@avst-api/commons").Response<import("../../../../../definitions/CustomFieldCreatedContextOptionsListAsResponse").CustomFieldCreatedContextOptionsListAsResponse | undefined>>;
/**
* Updates the options of a custom field.

If any of the options are not found, no options are updated. Options where the values in the request match the current values aren't updated and aren't reported in the response.

Note that this operation **only works for issue field select list options created in Jira or using operations from the [Issue custom field options](#api-group-Issue-custom-field-options) resource**, it cannot be used with issue field select list options created by Connect apps.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-custom-field-options/#api-rest-api-3-field-fieldid-context-contextid-option-put
* @param options Request options.
*/
export declare function updateIssueCustomFieldContextOptions(options: Issue.Field.Custom.Context.Option.UpdateOptions.Options.RawApi): Promise<import("@avst-api/commons").Response<import("../../../../../definitions/CustomFieldUpdatedContextOptionsListAsResponse").CustomFieldUpdatedContextOptionsListAsResponse | undefined>>;
/**
* Changes the order of custom field options or cascading options in a context.

This operation works for custom field options created in Jira or the operations from this resource. **To work with issue field select list options created for Connect apps use the [Issue custom field options (apps)](#api-group-issue-custom-field-options--apps-) operations.**

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-custom-field-options/#api-rest-api-3-field-fieldid-context-contextid-option-move-put
* @param options Request options.
*/
export declare function reorderIssueCustomFieldContextOptions(options: Issue.Field.Custom.Context.Option.ReorderOptions.Options.RawApi): Promise<import("@avst-api/commons").Response<any>>;
/**
* Deletes a custom field option.

Options with cascading options cannot be deleted without deleting the cascading options first.

This operation works for custom field options created in Jira or the operations from this resource. **To work with issue field select list options created for Connect apps use the [Issue custom field options (apps)](#api-group-issue-custom-field-options--apps-) operations.**

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-custom-field-options/#api-rest-api-3-field-fieldid-context-contextid-option-optionid-delete
* @param options Request options.
*/
export declare function deleteIssueCustomFieldContextOption(options: Issue.Field.Custom.Context.Option.DeleteOption.Options.RawApi): Promise<import("@avst-api/commons").Response<undefined>>;
//# sourceMappingURL=option.d.ts.map