import { Issue } from "../../../types/issue";
/**
* Returns a list of all issue link types.

To use this operation, the site must have [issue linking](https://confluence.atlassian.com/x/yoXKM) enabled.

This operation can be accessed anonymously.

**[Permissions](#permissions) required:** *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for a project in the site.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issueLinkType-get
* @param options Request options.
*/
export declare function getIssueLinkTypes(options: Issue.Link.Type.GetTypes.Options.RawApi): Promise<import("@avst-api/commons").Response<import("../../../definitions/IssueLinkTypesAsResponse").IssueLinkTypesAsResponse | undefined>>;
/**
* Creates an issue link type. Use this operation to create descriptions of the reasons why issues are linked. The issue link type consists of a name and descriptions for a link's inward and outward relationships.

To use this operation, the site must have [issue linking](https://confluence.atlassian.com/x/yoXKM) enabled.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issueLinkType-post
* @param options Request options.
*/
export declare function createIssueLinkType(options: Issue.Link.Type.CreateType.Options.RawApi): Promise<import("@avst-api/commons").Response<import("../../../definitions/IssueLinkTypeAsResponse").IssueLinkTypeAsResponse | undefined>>;
/**
* Returns an issue link type.

To use this operation, the site must have [issue linking](https://confluence.atlassian.com/x/yoXKM) enabled.

This operation can be accessed anonymously.

**[Permissions](#permissions) required:** *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for a project in the site.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issueLinkType-issueLinkTypeId-get
* @param options Request options.
*/
export declare function getIssueLinkType(options: Issue.Link.Type.GetType.Options.RawApi): Promise<import("@avst-api/commons").Response<import("../../../definitions/IssueLinkTypeAsResponse").IssueLinkTypeAsResponse | undefined>>;
/**
* Updates an issue link type.

To use this operation, the site must have [issue linking](https://confluence.atlassian.com/x/yoXKM) enabled.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issueLinkType-issueLinkTypeId-put
* @param options Request options.
*/
export declare function updateIssueLinkType(options: Issue.Link.Type.UpdateType.Options.RawApi): Promise<import("@avst-api/commons").Response<import("../../../definitions/IssueLinkTypeAsResponse").IssueLinkTypeAsResponse | undefined>>;
/**
* Deletes an issue link type.

To use this operation, the site must have [issue linking](https://confluence.atlassian.com/x/yoXKM) enabled.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issueLinkType-issueLinkTypeId-delete
* @param options Request options.
*/
export declare function deleteIssueLinkType(options: Issue.Link.Type.DeleteType.Options.RawApi): Promise<import("@avst-api/commons").Response<undefined>>;
//# sourceMappingURL=type.d.ts.map