import { httpGet } from "../../../raw-api/common";
import { httpPost } from "../../../raw-api/common";
import { httpPut } from "../../../raw-api/common";
import { httpDelete } from "../../../raw-api/common";
/**
* Returns a list of all issue link types.

To use this operation, the site must have [issue linking](https://confluence.atlassian.com/x/yoXKM) enabled.

This operation can be accessed anonymously.

**[Permissions](#permissions) required:** *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for a project in the site.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issueLinkType-get
* @param options Request options.
*/
export function getIssueLinkTypes(options) {
    const { connectionId: instanceId, headers } = options;
    return httpGet(instanceId, `/rest/api/3/issueLinkType`, headers);
}
/**
* Creates an issue link type. Use this operation to create descriptions of the reasons why issues are linked. The issue link type consists of a name and descriptions for a link's inward and outward relationships.

To use this operation, the site must have [issue linking](https://confluence.atlassian.com/x/yoXKM) enabled.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issueLinkType-post
* @param options Request options.
*/
export function createIssueLinkType(options) {
    const { connectionId: instanceId, headers, body } = options;
    return httpPost(instanceId, `/rest/api/3/issueLinkType`, body, headers);
}
/**
* Returns an issue link type.

To use this operation, the site must have [issue linking](https://confluence.atlassian.com/x/yoXKM) enabled.

This operation can be accessed anonymously.

**[Permissions](#permissions) required:** *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for a project in the site.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issueLinkType-issueLinkTypeId-get
* @param options Request options.
*/
export function getIssueLinkType(options) {
    const { connectionId: instanceId, headers, issueLinkTypeId } = options;
    return httpGet(instanceId, `/rest/api/3/issueLinkType/${issueLinkTypeId}`, headers);
}
/**
* Updates an issue link type.

To use this operation, the site must have [issue linking](https://confluence.atlassian.com/x/yoXKM) enabled.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issueLinkType-issueLinkTypeId-put
* @param options Request options.
*/
export function updateIssueLinkType(options) {
    const { connectionId: instanceId, headers, issueLinkTypeId, body } = options;
    return httpPut(instanceId, `/rest/api/3/issueLinkType/${issueLinkTypeId}`, body, headers);
}
/**
* Deletes an issue link type.

To use this operation, the site must have [issue linking](https://confluence.atlassian.com/x/yoXKM) enabled.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issueLinkType-issueLinkTypeId-delete
* @param options Request options.
*/
export function deleteIssueLinkType(options) {
    const { connectionId: instanceId, headers, issueLinkTypeId } = options;
    return httpDelete(instanceId, `/rest/api/3/issueLinkType/${issueLinkTypeId}`, headers, true);
}
