import { httpGet } from "../../raw-api/common";
import { constructUrl } from "@avst-api/commons";
/**
* Returns details of projects, issue types within projects, and, when requested, the create screen fields for each issue type for the user. Use the information to populate the requests in [ Create issue](#api-rest-api-3-issue-post) and [Create issues](#api-rest-api-3-issue-bulk-post).

The request can be restricted to specific projects or issue types using the query parameters. The response will contain information for the valid projects, issue types, or project and issue type combinations requested. Note that invalid project, issue type, or project and issue type combinations do not generate errors.

This operation can be accessed anonymously.

**[Permissions](#permissions) required:** *Create issues* [project permission](https://confluence.atlassian.com/x/yodKLg) in the requested projects.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issue-createmeta-get
* @param options Request options.
*/
export function getCreateIssueMetadata(options) {
    const { connectionId: instanceId, headers, projectIds, projectKeys, issuetypeIds, issuetypeNames, expand } = options;
    const queryParams = { projectIds, projectKeys, issuetypeIds, issuetypeNames, expand };
    return httpGet(instanceId, constructUrl(`/rest/api/3/issue/createmeta`, queryParams), headers);
}
/**
* Returns the edit screen fields for an issue that are visible to and editable by the user. Use the information to populate the requests in [Edit issue](#api-rest-api-3-issue-issueIdOrKey-put).

Connect app users with admin permission (from user permissions and app scopes) and Forge app users with the `manage:jira-configuration` scope can return additional details using:

 *  `overrideScreenSecurity` Returns hidden fields.
 *  `overrideEditableFlag` Returns uneditable fields. For example, where an issue has a workflow status of closed none of its fields are editable.

This operation can be accessed anonymously.

**[Permissions](#permissions) required:**

 *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
 *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.

Note: For any fields to be editable the user must have the *Edit issues* [project permission](https://confluence.atlassian.com/x/yodKLg) for the issue.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issue-issueIdOrKey-editmeta-get
* @param options Request options.
*/
export function getEditIssueMetadata(options) {
    const { connectionId: instanceId, headers, issueIdOrKey, overrideScreenSecurity, overrideEditableFlag } = options;
    const queryParams = { overrideScreenSecurity, overrideEditableFlag };
    return httpGet(instanceId, constructUrl(`/rest/api/3/issue/${issueIdOrKey}/editmeta`, queryParams), headers);
}
