import { Issue } from "../../types/issue";
/**
* Returns the URLs and keys of an issue's properties.

This operation can be accessed anonymously.

**[Permissions](#permissions) required:** Property details are only returned where the user has:

 *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project containing the issue.
 *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issue-issueIdOrKey-properties-get
* @param options Request options.
*/
export declare function getIssuePropertyKeys(options: Issue.Property.GetKeys.Options.RawApi): Promise<import("@avst-api/commons").Response<import("../../definitions/PropertyKeysAsResponse").PropertyKeysAsResponse | undefined>>;
/**
* Returns the key and value of an issue's property.

This operation can be accessed anonymously.

**[Permissions](#permissions) required:**

 *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project containing the issue.
 *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issue-issueIdOrKey-properties-propertyKey-get
* @param options Request options.
*/
export declare function getIssueProperty(options: Issue.Property.GetProperty.Options.RawApi): Promise<import("@avst-api/commons").Response<import("../../definitions/EntityPropertyAsResponse").EntityPropertyAsResponse | undefined>>;
/**
* Sets the value of an issue's property. Use this resource to store custom data against an issue.

The value of the request body must be a [valid](http://tools.ietf.org/html/rfc4627), non-empty JSON blob. The maximum length is 32768 characters.

This operation can be accessed anonymously.

**[Permissions](#permissions) required:**

 *  *Browse projects* and *Edit issues* [project permissions](https://confluence.atlassian.com/x/yodKLg) for the project containing the issue.
 *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issue-issueIdOrKey-properties-propertyKey-put
* @param options Request options.
*/
export declare function setIssueProperty(options: Issue.Property.SetProperty.Options.RawApi): Promise<import("@avst-api/commons").Response<any>>;
/**
* Deletes an issue's property.

This operation can be accessed anonymously.

**[Permissions](#permissions) required:**

 *  *Browse projects* and *Edit issues* [project permissions](https://confluence.atlassian.com/x/yodKLg) for the project containing the issue.
 *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issue-issueIdOrKey-properties-propertyKey-delete
* @param options Request options.
*/
export declare function deleteIssueProperty(options: Issue.Property.DeleteProperty.Options.RawApi): Promise<import("@avst-api/commons").Response<undefined>>;
//# sourceMappingURL=property.d.ts.map