import { Issue } from "../../types/issue";
/**
* Checks whether one or more issues would be returned by one or more JQL queries.

**[Permissions](#permissions) required:** None, however, issues are only matched against JQL queries where the user has:

 *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
 *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-search-post
* @param options Request options.
*/
export declare function checkIssuesAgainstJql(options: Issue.Search.CheckAgainstJql.Options.RawApi): Promise<import("@avst-api/commons").Response<import("../../definitions/IssueMatchesAsResponse").IssueMatchesAsResponse | undefined>>;
/**
* Searches for issues using [JQL](https://confluence.atlassian.com/x/egORLQ).

There is a [GET](#api-rest-api-3-search-get) version of this resource that can be used for smaller JQL query expressions.

This operation can be accessed anonymously.

**[Permissions](#permissions) required:** Issues are included in the response where the user has:

 *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project containing the issue.
 *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-search-get
* @param options Request options.
*/
export declare function searchIssuesByJql(options: Issue.Search.SearchByJql.Options.RawApi): Promise<import("@avst-api/commons").Response<import("../../definitions/SearchResultsAsResponse").SearchResultsAsResponse | undefined>>;
//# sourceMappingURL=search.d.ts.map