import { httpPost } from "../../raw-api/common";
/**
* Checks whether one or more issues would be returned by one or more JQL queries.

**[Permissions](#permissions) required:** None, however, issues are only matched against JQL queries where the user has:

 *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
 *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-search-post
* @param options Request options.
*/
export function checkIssuesAgainstJql(options) {
    const { connectionId: instanceId, headers, body } = options;
    return httpPost(instanceId, `/rest/api/3/jql/match`, body, headers);
}
/**
* Searches for issues using [JQL](https://confluence.atlassian.com/x/egORLQ).

There is a [GET](#api-rest-api-3-search-get) version of this resource that can be used for smaller JQL query expressions.

This operation can be accessed anonymously.

**[Permissions](#permissions) required:** Issues are included in the response where the user has:

 *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project containing the issue.
 *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-search-get
* @param options Request options.
*/
export function searchIssuesByJql(options) {
    const { connectionId: instanceId, headers, body } = options;
    return httpPost(instanceId, `/rest/api/3/search`, body, headers);
}
