import { httpGet } from "../../raw-api/common";
import { constructUrl } from "@avst-api/commons";
/**
* Returns issue security level members.

Only issue security level members in context of classic projects are returned.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issuesecurityschemes-issueSecuritySchemeId-members-get
* @param options Request options.
*/
export function getIssueSecurityMembers(options) {
    const { connectionId: instanceId, headers, issueSecuritySchemeId, startAt, maxResults, issueSecurityLevelId, expand } = options;
    const queryParams = { startAt, maxResults, issueSecurityLevelId, expand };
    return httpGet(instanceId, constructUrl(`/rest/api/3/issuesecurityschemes/${issueSecuritySchemeId}/members`, queryParams, true), headers);
}
/**
* Returns details of an issue security level.

Use [Get issue security scheme](#api-rest-api-3-issuesecurityschemes-id-get) to obtain the IDs of issue security levels associated with the issue security scheme.

This operation can be accessed anonymously.

**[Permissions](#permissions) required:** None.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-security-level/#api-rest-api-3-securitylevel-id-get
* @param options Request options.
*/
export function getIssueSecurityLevel(options) {
    const { connectionId: instanceId, headers, id } = options;
    return httpGet(instanceId, `/rest/api/3/securitylevel/${id}`, headers);
}
