import { httpGet } from "../../../raw-api/common";
/**
* Returns all [issue security schemes](https://confluence.atlassian.com/x/J4lKLg).

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-security-schemes/#api-rest-api-3-issuesecurityschemes-get
* @param options Request options.
*/
export function getIssueSecuritySchemes(options) {
    const { connectionId: instanceId, headers } = options;
    return httpGet(instanceId, `/rest/api/3/issuesecurityschemes`, headers);
}
/**
* Returns an issue security scheme along with its security levels.

**[Permissions](#permissions) required:**

 *  *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
 *  *Administer Projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for a project that uses the requested issue security scheme.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-security-schemes/#api-rest-api-3-issuesecurityschemes-id-get
* @param options Request options.
*/
export function getIssueSecurityScheme(options) {
    const { connectionId: instanceId, headers, id } = options;
    return httpGet(instanceId, `/rest/api/3/issuesecurityschemes/${id}`, headers);
}
