import { Issue } from "../../../types/issue";
/**
* Returns a [paginated](#pagination) list of issue type schemes.

Only issue type schemes used in classic projects are returned.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issuetypescheme-get
* @param options Request options.
*/
export declare function getIssueTypeSchemes(options: Issue.Type.Scheme.GetSchemes.Options.RawApi): Promise<import("@avst-api/commons").Response<import("../../../definitions/PageBeanIssueTypeSchemeAsResponse").PageBeanIssueTypeSchemeAsResponse | undefined>>;
/**
* Creates an issue type scheme.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-type-schemes/#api-rest-api-3-issuetypescheme-post
* @param options Request options.
*/
export declare function createIssueTypeScheme(options: Issue.Type.Scheme.CreateScheme.Options.RawApi): Promise<import("@avst-api/commons").Response<import("../../../definitions/IssueTypeSchemeIDAsResponse").IssueTypeSchemeIDAsResponse | undefined>>;
/**
* Returns a [paginated](#pagination) list of issue type scheme items.

Only issue type scheme items used in classic projects are returned.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issuetypescheme-mapping-get
* @param options Request options.
*/
export declare function getIssueTypeSchemeItems(options: Issue.Type.Scheme.GetSchemeItems.Options.RawApi): Promise<import("@avst-api/commons").Response<import("../../../definitions/PageBeanIssueTypeSchemeMappingAsResponse").PageBeanIssueTypeSchemeMappingAsResponse | undefined>>;
/**
* Returns a [paginated](#pagination) list of issue type schemes and, for each issue type scheme, a list of the projects that use it.

Only issue type schemes used in classic projects are returned.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issuetypescheme-project-get
* @param options Request options.
*/
export declare function getIssueTypeSchemesForProjects(options: Issue.Type.Scheme.GetSchemesForProjects.Options.RawApi): Promise<import("@avst-api/commons").Response<import("../../../definitions/PageBeanIssueTypeSchemeProjectsAsResponse").PageBeanIssueTypeSchemeProjectsAsResponse | undefined>>;
/**
* Assigns an issue type scheme to a project.

If any issues in the project are assigned issue types not present in the new scheme, the operation will fail. To complete the assignment those issues must be updated to use issue types in the new scheme.

Issue type schemes can only be assigned to classic projects.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-type-schemes/#api-rest-api-3-issuetypescheme-project-put
* @param options Request options.
*/
export declare function assignIssueTypeSchemeToProject(options: Issue.Type.Scheme.AssignToProject.Options.RawApi): Promise<import("@avst-api/commons").Response<any>>;
/**
* Adds issue types to an issue type scheme.

The added issue types are appended to the issue types list.

If any of the issue types exist in the issue type scheme, the operation fails and no issue types are added.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-type-schemes/#api-rest-api-3-issuetypescheme-issuetypeschemeid-issuetype-put
* @param options Request options.
*/
export declare function addIssueTypesToIssueTypeScheme(options: Issue.Type.Scheme.AddIssueTypesToScheme.Options.RawApi): Promise<import("@avst-api/commons").Response<any>>;
/**
* Updates an issue type scheme.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-type-schemes/#api-rest-api-3-issuetypescheme-issuetypeschemeid-put
* @param options Request options.
*/
export declare function updateIssueTypeScheme(options: Issue.Type.Scheme.UpdateScheme.Options.RawApi): Promise<import("@avst-api/commons").Response<any>>;
/**
* Deletes an issue type scheme.

Only issue type schemes used in classic projects can be deleted.

Any projects assigned to the scheme are reassigned to the default issue type scheme.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-type-schemes/#api-rest-api-3-issuetypescheme-issuetypeschemeid-delete
* @param options Request options.
*/
export declare function deleteIssueTypeScheme(options: Issue.Type.Scheme.DeleteScheme.Options.RawApi): Promise<import("@avst-api/commons").Response<any>>;
/**
* Changes the order of issue types in an issue type scheme.

The request body parameters must meet the following requirements:

 *  all of the issue types must belong to the issue type scheme.
 *  either `after` or `position` must be provided.
 *  the issue type in `after` must not be in the issue type list.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-type-schemes/#api-rest-api-3-issuetypescheme-issuetypeschemeid-issuetype-move-put
* @param options Request options.
*/
export declare function changeIssueTypeSchemeIssueTypesOrder(options: Issue.Type.Scheme.ChangeIssueTypesOrder.Options.RawApi): Promise<import("@avst-api/commons").Response<any>>;
/**
* Removes an issue type from an issue type scheme.

This operation cannot remove:

 *  any issue type used by issues.
 *  any issue types from the default issue type scheme.
 *  the last standard issue type from an issue type scheme.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-type-schemes/#api-rest-api-3-issuetypescheme-issuetypeschemeid-issuetype-issuetypeid-delete
* @param options Request options.
*/
export declare function removeIssueTypesFromIssueTypeScheme(options: Issue.Type.Scheme.RemoveIssueTypesFromScheme.Options.RawApi): Promise<import("@avst-api/commons").Response<any>>;
//# sourceMappingURL=scheme.d.ts.map