import { Issue } from "../../../../types/issue";
/**
* Returns a [paginated](#pagination) list of projects associated with an issue type screen scheme.

Only company-managed projects associated with an issue type screen scheme are returned.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-type-screen-schemes/#api-rest-api-3-issuetypescreenscheme-issuetypescreenschemeid-project-get
* @param options Request options.
*/
export declare function getIssueTypeScreenSchemeProjects(options: Issue.Type.Screen.Scheme.GetProjects.Options.RawApi): Promise<import("@avst-api/commons").Response<import("../../../../definitions/PageBeanProjectDetailsAsResponse").PageBeanProjectDetailsAsResponse | undefined>>;
/**
* Returns a [paginated](#pagination) list of issue type screen schemes.

Only issue type screen schemes used in classic projects are returned.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issuetypescreenscheme-get
* @param options Request options.
*/
export declare function getIssueTypeScreenSchemes(options: Issue.Type.Screen.Scheme.GetSchemes.Options.RawApi): Promise<import("@avst-api/commons").Response<import("../../../../definitions/PageBeanIssueTypeScreenSchemeAsResponse").PageBeanIssueTypeScreenSchemeAsResponse | undefined>>;
/**
* Creates an issue type screen scheme.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-type-screen-schemes/#api-rest-api-3-issuetypescreenscheme-post
* @param options Request options.
*/
export declare function createIssueTypeScreenScheme(options: Issue.Type.Screen.Scheme.CreateScheme.Options.RawApi): Promise<import("@avst-api/commons").Response<import("../../../../definitions/IssueTypeScreenSchemeIdAsResponse").IssueTypeScreenSchemeIdAsResponse | undefined>>;
/**
* Returns a [paginated](#pagination) list of issue type screen scheme items.

Only issue type screen schemes used in classic projects are returned.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issuetypescreenscheme-mapping-get
* @param options Request options.
*/
export declare function getIssueTypeScreenSchemeItems(options: Issue.Type.Screen.Scheme.GetSchemeItems.Options.RawApi): Promise<import("@avst-api/commons").Response<import("../../../../definitions/PageBeanIssueTypeScreenSchemeItemAsResponse").PageBeanIssueTypeScreenSchemeItemAsResponse | undefined>>;
/**
* Returns a [paginated](#pagination) list of issue type screen schemes and, for each issue type screen scheme, a list of the projects that use it.

Only issue type screen schemes used in classic projects are returned.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issuetypescreenscheme-project-get
* @param options Request options.
*/
export declare function getIssueTypeScreenSchemesForProjects(options: Issue.Type.Screen.Scheme.GetSchemesForProjects.Options.RawApi): Promise<import("@avst-api/commons").Response<import("../../../../definitions/PageBeanIssueTypeScreenSchemesProjectsAsResponse").PageBeanIssueTypeScreenSchemesProjectsAsResponse | undefined>>;
/**
* Assigns an issue type screen scheme to a project.

Issue type screen schemes can only be assigned to classic projects.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-type-screen-schemes/#api-rest-api-3-issuetypescreenscheme-project-put
* @param options Request options.
*/
export declare function assignIssueTypeScreenSchemeToProject(options: Issue.Type.Screen.Scheme.AssignSchemeToProject.Options.RawApi): Promise<import("@avst-api/commons").Response<any>>;
/**
* Updates an issue type screen scheme.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-type-screen-schemes/#api-rest-api-3-issuetypescreenscheme-issuetypescreenschemeid-put
* @param options Request options.
*/
export declare function updateIssueTypeScreenScheme(options: Issue.Type.Screen.Scheme.UpdateScheme.Options.RawApi): Promise<import("@avst-api/commons").Response<any>>;
/**
* Deletes an issue type screen scheme.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-type-screen-schemes/#api-rest-api-3-issuetypescreenscheme-issuetypescreenschemeid-delete
* @param options Request options.
*/
export declare function deleteIssueTypeScreenScheme(options: Issue.Type.Screen.Scheme.DeleteScheme.Options.RawApi): Promise<import("@avst-api/commons").Response<any>>;
/**
* Appends issue type to screen scheme mappings to an issue type screen scheme.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-type-screen-schemes/#api-rest-api-3-issuetypescreenscheme-issuetypescreenschemeid-mapping-put
* @param options Request options.
*/
export declare function appendMappingsToIssueTypeScreenScheme(options: Issue.Type.Screen.Scheme.AppendMappings.Options.RawApi): Promise<import("@avst-api/commons").Response<any>>;
/**
* Updates the default screen scheme of an issue type screen scheme. The default screen scheme is used for all unmapped issue types.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-type-screen-schemes/#api-rest-api-3-issuetypescreenscheme-issuetypescreenschemeid-mapping-default-put
* @param options Request options.
*/
export declare function updateDefaultIssueTypeScreenScheme(options: Issue.Type.Screen.Scheme.UpdateDefaultScheme.Options.RawApi): Promise<import("@avst-api/commons").Response<any>>;
/**
* Removes issue type to screen scheme mappings from an issue type screen scheme.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-type-screen-schemes/#api-rest-api-3-issuetypescreenscheme-issuetypescreenschemeid-mapping-remove-post
* @param options Request options.
*/
export declare function removeMappingsFromIssueTypeScreenScheme(options: Issue.Type.Screen.Scheme.RemoveMappings.Options.RawApi): Promise<import("@avst-api/commons").Response<any>>;
//# sourceMappingURL=scheme.d.ts.map