import { httpGet } from "../../raw-api/common";
import { httpPost } from "../../raw-api/common";
import { httpDelete } from "../../raw-api/common";
/**
* Returns details about the votes on an issue.

This operation requires the **Allow users to vote on issues** option to be *ON*. This option is set in General configuration for Jira. See [Configuring Jira application options](https://confluence.atlassian.com/x/uYXKM) for details.

This operation can be accessed anonymously.

**[Permissions](#permissions) required:**

 *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is ini
 *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.

Note that users with the necessary permissions for this operation but without the *View voters and watchers* project permissions are not returned details in the `voters` field.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issue-issueIdOrKey-votes-get
* @param options Request options.
*/
export function getIssueVotes(options) {
    const { connectionId: instanceId, headers, issueIdOrKey } = options;
    return httpGet(instanceId, `/rest/api/3/issue/${issueIdOrKey}/votes`, headers);
}
/**
* Adds the user's vote to an issue. This is the equivalent of the user clicking *Vote* on an issue in Jira.

This operation requires the **Allow users to vote on issues** option to be *ON*. This option is set in General configuration for Jira. See [Configuring Jira application options](https://confluence.atlassian.com/x/uYXKM) for details.

**[Permissions](#permissions) required:**

 *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
 *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issue-issueIdOrKey-votes-post
* @param options Request options.
*/
export function addIssueVote(options) {
    const { connectionId: instanceId, headers, issueIdOrKey } = options;
    return httpPost(instanceId, `/rest/api/3/issue/${issueIdOrKey}/votes`, undefined, headers);
}
/**
* Deletes a user's vote from an issue. This is the equivalent of the user clicking *Unvote* on an issue in Jira.

This operation requires the **Allow users to vote on issues** option to be *ON*. This option is set in General configuration for Jira. See [Configuring Jira application options](https://confluence.atlassian.com/x/uYXKM) for details.

**[Permissions](#permissions) required:**

 *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
 *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issue-issueIdOrKey-votes-delete
* @param options Request options.
*/
export function deleteIssueVote(options) {
    const { connectionId: instanceId, headers, issueIdOrKey } = options;
    return httpDelete(instanceId, `/rest/api/3/issue/${issueIdOrKey}/votes`, headers, true);
}
