import { httpGet } from "../../raw-api/common";
import { httpPost } from "../../raw-api/common";
import { httpDelete } from "../../raw-api/common";
import { constructUrl } from "@avst-api/commons";
/**
* Returns the watchers for an issue.

This operation requires the **Allow users to watch issues** option to be *ON*. This option is set in General configuration for Jira. See [Configuring Jira application options](https://confluence.atlassian.com/x/uYXKM) for details.

This operation can be accessed anonymously.

**[Permissions](#permissions) required:**

 *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is ini
 *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
 *  To see details of users on the watchlist other than themselves, *View voters and watchers* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issue-issueIdOrKey-watchers-get
* @param options Request options.
*/
export function getIssueWatchers(options) {
    const { connectionId: instanceId, headers, issueIdOrKey } = options;
    return httpGet(instanceId, `/rest/api/3/issue/${issueIdOrKey}/watchers`, headers);
}
/**
* Adds a user as a watcher of an issue by passing the account ID of the user. For example, `"5b10ac8d82e05b22cc7d4ef5"`. If no user is specified the calling user is added.

This operation requires the **Allow users to watch issues** option to be *ON*. This option is set in General configuration for Jira. See [Configuring Jira application options](https://confluence.atlassian.com/x/uYXKM) for details.

**[Permissions](#permissions) required:**

 *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
 *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
 *  To add users other than themselves to the watchlist, *Manage watcher list* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issue-issueIdOrKey-watchers-post
* @param options Request options.
*/
export function addIssueWatcher(options) {
    const { connectionId: instanceId, headers, issueIdOrKey, body } = options;
    return httpPost(instanceId, `/rest/api/3/issue/${issueIdOrKey}/watchers`, body, headers);
}
/**
* Deletes a user as a watcher of an issue.

This operation requires the **Allow users to watch issues** option to be *ON*. This option is set in General configuration for Jira. See [Configuring Jira application options](https://confluence.atlassian.com/x/uYXKM) for details.

**[Permissions](#permissions) required:**

 *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
 *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
 *  To remove users other than themselves from the watchlist, *Manage watcher list* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issue-issueIdOrKey-watchers-delete
* @param options Request options.
*/
export function deleteIssueWatcher(options) {
    const { connectionId: instanceId, headers, issueIdOrKey, accountId } = options;
    const queryParams = { accountId };
    return httpDelete(instanceId, constructUrl(`/rest/api/3/issue/${issueIdOrKey}/watchers`, queryParams), headers, true);
}
