import { Permission } from "../../../types/permission";
/**
* Returns all permission grants for a permission scheme.

**[Permissions](#permissions) required:** Permission to access Jira.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-permission-schemes/#api-rest-api-3-permissionscheme-schemeid-permission-get
* @param options Request options.
*/
export declare function getPermissionSchemeGrants(options: Permission.Scheme.Grant.GetGrants.Options.RawApi): Promise<import("@avst-api/commons").Response<import("../../../definitions/PermissionGrantsAsResponse").PermissionGrantsAsResponse | undefined>>;
/**
* Creates a permission grant in a permission scheme.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-permission-schemes/#api-rest-api-3-permissionscheme-schemeid-permission-post
* @param options Request options.
*/
export declare function createPermissionSchemeGrant(options: Permission.Scheme.Grant.CreateGrant.Options.RawApi): Promise<import("@avst-api/commons").Response<import("../../../definitions/PermissionGrantAsResponse").PermissionGrantAsResponse | undefined>>;
/**
* Returns a permission grant.

**[Permissions](#permissions) required:** Permission to access Jira.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-permission-schemes/#api-rest-api-3-permissionscheme-schemeid-permission-permissionid-get
* @param options Request options.
*/
export declare function getPermissionSchemeGrant(options: Permission.Scheme.Grant.GetGrant.Options.RawApi): Promise<import("@avst-api/commons").Response<import("../../../definitions/PermissionGrantAsResponse").PermissionGrantAsResponse | undefined>>;
/**
* Deletes a permission grant from a permission scheme. See [About permission schemes and grants](../api-group-permission-schemes/#about-permission-schemes-and-grants) for more details.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-permission-schemes/#api-rest-api-3-permissionscheme-schemeid-permission-permissionid-delete
* @param options Request options.
*/
export declare function deletePermissionSchemeGrant(options: Permission.Scheme.Grant.DeleteGrant.Options.RawApi): Promise<import("@avst-api/commons").Response<undefined>>;
//# sourceMappingURL=grant.d.ts.map