import { httpGet } from "../../../raw-api/common";
import { constructUrl } from "@avst-api/commons";
import { httpPost } from "../../../raw-api/common";
import { httpDelete } from "../../../raw-api/common";
/**
* Returns all permission grants for a permission scheme.

**[Permissions](#permissions) required:** Permission to access Jira.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-permission-schemes/#api-rest-api-3-permissionscheme-schemeid-permission-get
* @param options Request options.
*/
export function getPermissionSchemeGrants(options) {
    const { connectionId: instanceId, headers, schemeId, expand } = options;
    const queryParams = { expand };
    return httpGet(instanceId, constructUrl(`/rest/api/3/permissionscheme/${schemeId}/permission`, queryParams), headers);
}
/**
* Creates a permission grant in a permission scheme.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-permission-schemes/#api-rest-api-3-permissionscheme-schemeid-permission-post
* @param options Request options.
*/
export function createPermissionSchemeGrant(options) {
    const { connectionId: instanceId, headers, schemeId, body, expand } = options;
    const queryParams = { expand };
    return httpPost(instanceId, constructUrl(`/rest/api/3/permissionscheme/${schemeId}/permission`, queryParams), body, headers);
}
/**
* Returns a permission grant.

**[Permissions](#permissions) required:** Permission to access Jira.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-permission-schemes/#api-rest-api-3-permissionscheme-schemeid-permission-permissionid-get
* @param options Request options.
*/
export function getPermissionSchemeGrant(options) {
    const { connectionId: instanceId, headers, schemeId, permissionId, expand } = options;
    const queryParams = { expand };
    return httpGet(instanceId, constructUrl(`/rest/api/3/permissionscheme/${schemeId}/permission/${permissionId}`, queryParams), headers);
}
/**
* Deletes a permission grant from a permission scheme. See [About permission schemes and grants](../api-group-permission-schemes/#about-permission-schemes-and-grants) for more details.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-permission-schemes/#api-rest-api-3-permissionscheme-schemeid-permission-permissionid-delete
* @param options Request options.
*/
export function deletePermissionSchemeGrant(options) {
    const { connectionId: instanceId, headers, schemeId, permissionId } = options;
    return httpDelete(instanceId, `/rest/api/3/permissionscheme/${schemeId}/permission/${permissionId}`, headers, true);
}
