import { Project } from "../../types/project";
/**
* Creates a component. Use components to provide containers for issues within a project.

This operation can be accessed anonymously.

**[Permissions](#permissions) required:** *Administer projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project in which the component is created or *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-component-post
* @param options Request options.
*/
export declare function createProjectComponent(options: Project.Component.CreateComponent.Options.RawApi): Promise<import("@avst-api/commons").Response<import("../../definitions/ProjectComponentAsResponse").ProjectComponentAsResponse | undefined>>;
/**
* Returns a component.

This operation can be accessed anonymously.

**[Permissions](#permissions) required:** *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for project containing the component.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-component-id-get
* @param options Request options.
*/
export declare function getProjectComponent(options: Project.Component.GetComponent.Options.RawApi): Promise<import("@avst-api/commons").Response<import("../../definitions/ProjectComponentAsResponse").ProjectComponentAsResponse | undefined>>;
/**
* Updates a component. Any fields included in the request are overwritten. If `leadAccountId` is an empty string ("") the component lead is removed.

This operation can be accessed anonymously.

**[Permissions](#permissions) required:** *Administer projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project containing the component or *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-component-id-put
* @param options Request options.
*/
export declare function updateProjectComponent(options: Project.Component.UpdateComponent.Options.RawApi): Promise<import("@avst-api/commons").Response<import("../../definitions/ComponentAsResponse").ComponentAsResponse | undefined>>;
/**
* Deletes a component.

This operation can be accessed anonymously.

**[Permissions](#permissions) required:** *Administer projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project containing the component or *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-component-id-delete
* @param options Request options.
*/
export declare function deleteProjectComponent(options: Project.Component.DeleteComponent.Options.RawApi): Promise<import("@avst-api/commons").Response<undefined>>;
/**
* Returns the counts of issues assigned to the component.

This operation can be accessed anonymously.

**[Permissions](#permissions) required:** None.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-component-id-relatedIssueCounts-get
* @param options Request options.
*/
export declare function getProjectComponentIssueCount(options: Project.Component.GetIssueCount.Options.RawApi): Promise<import("@avst-api/commons").Response<import("../../definitions/ComponentIssuesCountAsResponse").ComponentIssuesCountAsResponse | undefined>>;
/**
* Returns a [paginated](#pagination) list of all components in a project. See the [Get project components](#api-rest-api-3-project-projectIdOrKey-components-get) resource if you want to get a full list of versions without pagination.

This operation can be accessed anonymously.

**[Permissions](#permissions) required:** *Browse Projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-project-projectIdOrKey-component-get
* @param options Request options.
*/
export declare function getProjectComponentsPaginated(options: Project.Component.GetComponentsPaginated.Options.RawApi): Promise<import("@avst-api/commons").Response<import("../../definitions/PageBeanComponentWithIssueCountAsResponse").PageBeanComponentWithIssueCountAsResponse | undefined>>;
/**
* Returns all components in a project. See the [Get project components paginated](#api-rest-api-3-project-projectIdOrKey-component-get) resource if you want to get a full list of components with pagination.

This operation can be accessed anonymously.

**[Permissions](#permissions) required:** *Browse Projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-project-projectIdOrKey-components-get
* @param options Request options.
*/
export declare function getProjectComponents(options: Project.Component.GetComponents.Options.RawApi): Promise<import("@avst-api/commons").Response<Project.Component.GetComponents.Response.OK | undefined>>;
//# sourceMappingURL=component.d.ts.map