import { httpPut } from "../../../raw-api/common";
import { constructUrl } from "@avst-api/commons";
import { httpGet } from "../../../raw-api/common";
/**
* Assigns a permission scheme with a project. See [Managing project permissions](https://confluence.atlassian.com/x/yodKLg) for more information about permission schemes.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg)
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-project-permission-schemes/#api-rest-api-3-project-projectkeyorid-permissionscheme-put
* @param options Request options.
*/
export function assignProjectPermissionScheme(options) {
    const { connectionId: instanceId, headers, projectKeyOrId, body, expand } = options;
    const queryParams = { expand };
    return httpPut(instanceId, constructUrl(`/rest/api/3/project/${projectKeyOrId}/permissionscheme`, queryParams), body, headers);
}
/**
* Gets the [permission scheme](https://confluence.atlassian.com/x/yodKLg) associated with the project.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg) or *Administer projects* [project permission](https://confluence.atlassian.com/x/yodKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-project-permission-schemes/#api-rest-api-3-project-projectkeyorid-permissionscheme-get
* @param options Request options.
*/
export function getProjectPermissionScheme(options) {
    const { connectionId: instanceId, headers, projectKeyOrId, expand } = options;
    const queryParams = { expand };
    return httpGet(instanceId, constructUrl(`/rest/api/3/project/${projectKeyOrId}/permissionscheme`, queryParams), headers);
}
/**
* Returns all [issue security](https://confluence.atlassian.com/x/J4lKLg) levels for the project that the user has access to.

This operation can be accessed anonymously.

**[Permissions](#permissions) required:** *Browse projects* [global permission](https://confluence.atlassian.com/x/x4dKLg) for the project, however, issue security levels are only returned for authenticated user with *Set Issue Security* [global permission](https://confluence.atlassian.com/x/x4dKLg) for the project.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-project-permission-schemes/#api-rest-api-3-project-projectkeyorid-securitylevel-get
* @param options Request options.
*/
export function getProjectIssueSecurityLevels(options) {
    const { connectionId: instanceId, headers, projectKeyOrId } = options;
    return httpGet(instanceId, `/rest/api/3/project/${projectKeyOrId}/securitylevel`, headers);
}
