import { Project } from "../../types/project";
/**
* Returns all [project property](https://developer.atlassian.com/cloud/jira/platform/storing-data-without-a-database/#a-id-jira-entity-properties-a-jira-entity-properties) keys for the project.

This operation can be accessed anonymously.

**[Permissions](#permissions) required:** *Browse Projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-project-properties/#api-rest-api-3-project-projectidorkey-properties-get
* @param options Request options.
*/
export declare function getProjectPropertyKeys(options: Project.Property.GetPropertyKeys.Options.RawApi): Promise<import("@avst-api/commons").Response<import("../../definitions/PropertyKeysAsResponse").PropertyKeysAsResponse | undefined>>;
/**
* Returns the value of a [project property](https://developer.atlassian.com/cloud/jira/platform/storing-data-without-a-database/#a-id-jira-entity-properties-a-jira-entity-properties).

This operation can be accessed anonymously.

**[Permissions](#permissions) required:** *Browse Projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project containing the property.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-project-properties/#api-rest-api-3-project-projectidorkey-properties-propertykey-get
* @param options Request options.
*/
export declare function getProjectProperty(options: Project.Property.GetProperty.Options.RawApi): Promise<import("@avst-api/commons").Response<import("../../definitions/EntityPropertyAsResponse").EntityPropertyAsResponse | undefined>>;
/**
* Sets the value of the [project property](https://developer.atlassian.com/cloud/jira/platform/storing-data-without-a-database/#a-id-jira-entity-properties-a-jira-entity-properties). You can use project properties to store custom data against the project.

The value of the request body must be a [valid](http://tools.ietf.org/html/rfc4627), non-empty JSON blob. The maximum length is 32768 characters.

This operation can be accessed anonymously.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg) or *Administer Projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project in which the property is created.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-project-properties/#api-rest-api-3-project-projectidorkey-properties-propertykey-put
* @param options Request options.
*/
export declare function setProjectProperty(options: Project.Property.SetProperty.Options.RawApi): Promise<import("@avst-api/commons").Response<any>>;
/**
* Deletes the [property](https://developer.atlassian.com/cloud/jira/platform/storing-data-without-a-database/#a-id-jira-entity-properties-a-jira-entity-properties) from a project.

This operation can be accessed anonymously.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg) or *Administer Projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project containing the property.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-project-properties/#api-rest-api-3-project-projectidorkey-properties-propertykey-delete
* @param options Request options.
*/
export declare function deleteProjectProperty(options: Project.Property.DeleteProperty.Options.RawApi): Promise<import("@avst-api/commons").Response<undefined>>;
//# sourceMappingURL=property.d.ts.map