import { httpGet } from "../../../../raw-api/common";
import { httpPost } from "../../../../raw-api/common";
import { httpDelete } from "../../../../raw-api/common";
import { constructUrl } from "@avst-api/commons";
/**
* Returns the [default actors](#api-rest-api-3-resolution-get) for the project role.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-role-id-actors-get
* @param options Request options.
*/
export function getDefaultActorsForProjectRole(options) {
    const { connectionId: instanceId, headers, id } = options;
    return httpGet(instanceId, `/rest/api/3/role/${id}/actors`, headers);
}
/**
* Adds [default actors](#api-rest-api-3-resolution-get) to a role. You may add groups or users, but you cannot add groups and users in the same request.

Changing a project role's default actors does not affect project role members for projects already created.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-role-id-actors-post
* @param options Request options.
*/
export function addDefaultActorsToProjectRole(options) {
    const { connectionId: instanceId, headers, id, body } = options;
    return httpPost(instanceId, `/rest/api/3/role/${id}/actors`, body, headers);
}
/**
* Deletes the [default actors](#api-rest-api-3-resolution-get) from a project role. You may delete a group or user, but you cannot delete a group and a user in the same request.

Changing a project role's default actors does not affect project role members for projects already created.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-role-id-actors-delete
* @param options Request options.
*/
export function deleteDefaultActorsFromProjectRole(options) {
    const { connectionId: instanceId, headers, id, user, group } = options;
    const queryParams = { user, group };
    return httpDelete(instanceId, constructUrl(`/rest/api/3/role/${id}/actors`, queryParams), headers);
}
