import { httpGet } from "../../raw-api/common";
/**
* Returns all [project types](https://confluence.atlassian.com/x/Var1Nw), whether or not the instance has a valid license for each type.

This operation can be accessed anonymously.

**[Permissions](#permissions) required:** None.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-project-types/#api-rest-api-3-project-type-get
* @param options Request options.
*/
export function getProjectTypes(options) {
    const { connectionId: instanceId, headers } = options;
    return httpGet(instanceId, `/rest/api/3/project/type`, headers);
}
/**
 * Returns all [project types](https://confluence.atlassian.com/x/Var1Nw) with a valid license.
 * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-project-types/#api-rest-api-3-project-type-accessible-get
 * @param options Request options.
 */
export function getLicensedProjectTypes(options) {
    const { connectionId: instanceId, headers } = options;
    return httpGet(instanceId, `/rest/api/3/project/type/accessible`, headers);
}
/**
* Returns a [project type](https://confluence.atlassian.com/x/Var1Nw).

This operation can be accessed anonymously.

**[Permissions](#permissions) required:** None.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-project-types/#api-rest-api-3-project-type-projecttypekey-get
* @param options Request options.
*/
export function getProjectTypeByKey(options) {
    const { connectionId: instanceId, headers, projectTypeKey } = options;
    return httpGet(instanceId, `/rest/api/3/project/type/${projectTypeKey}`, headers);
}
/**
* Returns a [project type](https://confluence.atlassian.com/x/Var1Nw) if it is accessible to the user.

**[Permissions](#permissions) required:** Permission to access Jira.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-project-types/#api-rest-api-3-project-type-projecttypekey-accessible-get
* @param options Request options.
*/
export function getAccessibleProjectTypeByKey(options) {
    const { connectionId: instanceId, headers, projectTypeKey } = options;
    return httpGet(instanceId, `/rest/api/3/project/type/${projectTypeKey}/accessible`, headers);
}
