import { Project } from "../../types/project";
/**
* Returns a [paginated](#pagination) list of all versions in a project. See the [Get project versions](#api-rest-api-3-project-projectIdOrKey-versions-get) resource if you want to get a full list of versions without pagination.

This operation can be accessed anonymously.

**[Permissions](#permissions) required:** *Browse Projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-project-projectIdOrKey-version-get
* @param options Request options.
*/
export declare function getProjectVersionsPaginated(options: Project.Version.GetVersionsPaginated.Options.RawApi): Promise<import("@avst-api/commons").Response<import("../../definitions/PageBeanVersionAsResponse").PageBeanVersionAsResponse | undefined>>;
/**
* Returns all versions in a project. The response is not paginated. Use [Get project versions paginated](#api-rest-api-3-project-projectIdOrKey-version-get) if you want to get the versions in a project with pagination.

This operation can be accessed anonymously.

**[Permissions](#permissions) required:** *Browse Projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-project-projectIdOrKey-versions-get
* @param options Request options.
*/
export declare function getProjectVersions(options: Project.Version.GetVersions.Options.RawApi): Promise<import("@avst-api/commons").Response<Project.Version.GetVersions.Response.OK | undefined>>;
/**
* Creates a project version.

This operation can be accessed anonymously.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg) or *Administer Projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project the version is added to.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-version-post
* @param options Request options.
*/
export declare function createProjectVersion(options: Project.Version.CreateVersion.Options.RawApi): Promise<import("@avst-api/commons").Response<import("../../definitions/VersionAsResponse").VersionAsResponse | undefined>>;
/**
* Returns a project version.

This operation can be accessed anonymously.

**[Permissions](#permissions) required:** *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project containing the version.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-version-id-get
* @param options Request options.
*/
export declare function getProjectVersion(options: Project.Version.GetVersion.Options.RawApi): Promise<import("@avst-api/commons").Response<import("../../definitions/VersionAsResponse").VersionAsResponse | undefined>>;
/**
* Updates a project version.

This operation can be accessed anonymously.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg) or *Administer Projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that contains the version.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-version-id-put
* @param options Request options.
*/
export declare function updateProjectVersion(options: Project.Version.UpdateVersion.Options.RawApi): Promise<import("@avst-api/commons").Response<import("../../definitions/VersionAsResponse").VersionAsResponse | undefined>>;
/**
* Merges two project versions. The merge is completed by deleting the version specified in `id` and replacing any occurrences of its ID in `fixVersion` with the version ID specified in `moveIssuesTo`.

Consider using [ Delete and replace version](#api-rest-api-3-version-id-removeAndSwap-post) instead. This resource supports swapping version values in `fixVersion`, `affectedVersion`, and custom fields.

This operation can be accessed anonymously.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg) or *Administer Projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that contains the version.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-version-id-mergeto-moveIssuesTo-put
* @param options Request options.
*/
export declare function mergeProjectVersions(options: Project.Version.MergeVersions.Options.RawApi): Promise<import("@avst-api/commons").Response<any>>;
/**
* Modifies the version's sequence within the project, which affects the display order of the versions in Jira.

This operation can be accessed anonymously.

**[Permissions](#permissions) required:** *Browse projects* project permission for the project that contains the version.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-version-id-move-post
* @param options Request options.
*/
export declare function moveProjectVersion(options: Project.Version.MoveVersion.Options.RawApi): Promise<import("@avst-api/commons").Response<import("../../definitions/VersionAsResponse").VersionAsResponse | undefined>>;
/**
* Deletes a project version.

Alternative versions can be provided to update issues that use the deleted version in `fixVersion`, `affectedVersion`, or any version picker custom fields. If alternatives are not provided, occurrences of `fixVersion`, `affectedVersion`, and any version picker custom field, that contain the deleted version, are cleared. Any replacement version must be in the same project as the version being deleted and cannot be the version being deleted.

This operation can be accessed anonymously.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg) or *Administer Projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that contains the version.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-version-id-removeAndSwap-post
* @param options Request options.
*/
export declare function deleteAndReplaceProjectVersion(options: Project.Version.DeleteAndReplaceVersion.Options.RawApi): Promise<import("@avst-api/commons").Response<any>>;
//# sourceMappingURL=version.d.ts.map