import { Screen } from "../types/screen";
/**
* Returns a [paginated](#pagination) list of the screens a field is used in.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-screens/#api-rest-api-3-field-fieldid-screens-get
* @param options Request options.
*/
export declare function getScreensForField(options: Screen.GetScreensForField.Options.RawApi): Promise<import("@avst-api/commons").Response<import("../definitions/PageBeanScreenWithTabAsResponse").PageBeanScreenWithTabAsResponse | undefined>>;
/**
* Returns a [paginated](#pagination) list of all screens or those specified by one or more screen IDs.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-screens/#api-rest-api-3-screens-get
* @param options Request options.
*/
export declare function getScreens(options: Screen.GetScreens.Options.RawApi): Promise<import("@avst-api/commons").Response<import("../definitions/PageBeanScreenAsResponse").PageBeanScreenAsResponse | undefined>>;
/**
* Creates a screen with a default field tab.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-screens/#api-rest-api-3-screens-post
* @param options Request options.
*/
export declare function createScreen(options: Screen.CreateScreen.Options.RawApi): Promise<import("@avst-api/commons").Response<import("../definitions/ScreenAsResponse").ScreenAsResponse | undefined>>;
/**
* Adds a field to the default tab of the default screen.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-screens/#api-rest-api-3-screens-addtodefault-fieldid-post
* @param options Request options.
*/
export declare function addFieldToDefaultScreen(options: Screen.AddFieldToDefaultScreen.Options.RawApi): Promise<import("@avst-api/commons").Response<"CREATED" | undefined>>;
/**
* Returns the fields that can be added to a tab on a screen.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-screens/#api-rest-api-3-screens-screenid-availablefields-get
* @param options Request options.
*/
export declare function getAvailableScreenFields(options: Screen.GetAvailableScreenFields.Options.RawApi): Promise<import("@avst-api/commons").Response<Screen.GetAvailableScreenFields.Response.OK | undefined>>;
/**
* Updates a screen. Only screens used in classic projects can be updated.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-screens/#api-rest-api-3-screens-screenid-put
* @param options Request options.
*/
export declare function updateScreen(options: Screen.UpdateScreen.Options.RawApi): Promise<import("@avst-api/commons").Response<import("../definitions/ScreenAsResponse").ScreenAsResponse | undefined>>;
/**
* Deletes a screen. A screen cannot be deleted if it is used in a screen scheme, workflow, or workflow draft.

Only screens used in classic projects can be deleted.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-screens/#api-rest-api-3-screens-screenid-delete
* @param options Request options.
*/
export declare function deleteScreen(options: Screen.DeleteScreen.Options.RawApi): Promise<import("@avst-api/commons").Response<undefined>>;
//# sourceMappingURL=screen.d.ts.map