import { httpGet } from "../../raw-api/common";
import { constructUrl } from "@avst-api/commons";
import { httpPost } from "../../raw-api/common";
import { httpPut } from "../../raw-api/common";
import { httpDelete } from "../../raw-api/common";
/**
* Returns a [paginated](#pagination) list of screen schemes.

Only screen schemes used in classic projects are returned.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-screenscheme-get
* @param options Request options.
*/
export function getScreenSchemes(options) {
    const { connectionId: instanceId, headers, startAt, maxResults, id } = options;
    const queryParams = { startAt, maxResults, id };
    return httpGet(instanceId, constructUrl(`/rest/api/3/screenscheme`, queryParams, true), headers);
}
/**
* Creates a screen scheme.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-screen-schemes/#api-rest-api-3-screenscheme-post
* @param options Request options.
*/
export function createScreenScheme(options) {
    const { connectionId: instanceId, headers, body } = options;
    return httpPost(instanceId, `/rest/api/3/screenscheme`, body, headers);
}
/**
* Updates a screen scheme. Only screen schemes used in classic projects can be updated.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-screen-schemes/#api-rest-api-3-screenscheme-screenschemeid-put
* @param options Request options.
*/
export function updateScreenScheme(options) {
    const { connectionId: instanceId, headers, screenSchemeId, body } = options;
    return httpPut(instanceId, `/rest/api/3/screenscheme/${screenSchemeId}`, body, headers);
}
/**
* Deletes a screen scheme. A screen scheme cannot be deleted if it is used in an issue type screen scheme.

Only screens schemes used in classic projects can be deleted.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-screen-schemes/#api-rest-api-3-screenscheme-screenschemeid-delete
* @param options Request options.
*/
export function deleteScreenScheme(options) {
    const { connectionId: instanceId, headers, screenSchemeId } = options;
    return httpDelete(instanceId, `/rest/api/3/screenscheme/${screenSchemeId}`, headers, true);
}
