import { Screen } from "../../types/screen";
/**
* Returns the list of tabs for a screen.

**[Permissions](#permissions) required:**

 *  *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
 *  *Administer projects* [project permission](https://confluence.atlassian.com/x/yodKLg) when the project key is specified, providing that the screen is associated with the project through a Screen Scheme and Issue Type Screen Scheme.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-screens/#api-rest-api-3-screens-screenid-tabs-get
* @param options Request options.
*/
export declare function getScreenTabs(options: Screen.Tab.GetTabs.Options.RawApi): Promise<import("@avst-api/commons").Response<Screen.Tab.GetTabs.Response.OK | undefined>>;
/**
* Creates a tab for a screen.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-screens/#api-rest-api-3-screens-screenid-tabs-post
* @param options Request options.
*/
export declare function createScreenTab(options: Screen.Tab.CreateTab.Options.RawApi): Promise<import("@avst-api/commons").Response<import("../../definitions/ScreenableTabAsResponse").ScreenableTabAsResponse | undefined>>;
/**
* Updates the name of a screen tab.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-screens/#api-rest-api-3-screens-screenid-tabs-tabid-put
* @param options Request options.
*/
export declare function updateScreenTab(options: Screen.Tab.UpdateTab.Options.RawApi): Promise<import("@avst-api/commons").Response<import("../../definitions/ScreenableTabAsResponse").ScreenableTabAsResponse | undefined>>;
/**
* Deletes a screen tab.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-screens/#api-rest-api-3-screens-screenid-tabs-tabid-delete
* @param options Request options.
*/
export declare function deleteScreenTab(options: Screen.Tab.DeleteTab.Options.RawApi): Promise<import("@avst-api/commons").Response<undefined>>;
/**
* Moves a screen tab.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-screens/#api-rest-api-3-screens-screenid-tabs-tabid-move-pos-post
* @param options Request options.
*/
export declare function moveScreenTab(options: Screen.Tab.MoveTab.Options.RawApi): Promise<import("@avst-api/commons").Response<any>>;
//# sourceMappingURL=tab.d.ts.map