import { httpGet } from "../../raw-api/common";
import { constructUrl } from "@avst-api/commons";
import { httpPost } from "../../raw-api/common";
import { httpPut } from "../../raw-api/common";
import { httpDelete } from "../../raw-api/common";
/**
* Returns the list of tabs for a screen.

**[Permissions](#permissions) required:**

 *  *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
 *  *Administer projects* [project permission](https://confluence.atlassian.com/x/yodKLg) when the project key is specified, providing that the screen is associated with the project through a Screen Scheme and Issue Type Screen Scheme.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-screens/#api-rest-api-3-screens-screenid-tabs-get
* @param options Request options.
*/
export function getScreenTabs(options) {
    const { connectionId: instanceId, headers, screenId, projectKey } = options;
    const queryParams = { projectKey };
    return httpGet(instanceId, constructUrl(`/rest/api/3/screens/${screenId}/tabs`, queryParams), headers);
}
/**
* Creates a tab for a screen.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-screens/#api-rest-api-3-screens-screenid-tabs-post
* @param options Request options.
*/
export function createScreenTab(options) {
    const { connectionId: instanceId, headers, screenId, body } = options;
    return httpPost(instanceId, `/rest/api/3/screens/${screenId}/tabs`, body, headers);
}
/**
* Updates the name of a screen tab.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-screens/#api-rest-api-3-screens-screenid-tabs-tabid-put
* @param options Request options.
*/
export function updateScreenTab(options) {
    const { connectionId: instanceId, headers, screenId, tabId, body } = options;
    return httpPut(instanceId, `/rest/api/3/screens/${screenId}/tabs/${tabId}`, body, headers);
}
/**
* Deletes a screen tab.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-screens/#api-rest-api-3-screens-screenid-tabs-tabid-delete
* @param options Request options.
*/
export function deleteScreenTab(options) {
    const { connectionId: instanceId, headers, screenId, tabId } = options;
    return httpDelete(instanceId, `/rest/api/3/screens/${screenId}/tabs/${tabId}`, headers, true);
}
/**
* Moves a screen tab.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-screens/#api-rest-api-3-screens-screenid-tabs-tabid-move-pos-post
* @param options Request options.
*/
export function moveScreenTab(options) {
    const { connectionId: instanceId, headers, screenId, tabId, pos } = options;
    return httpPost(instanceId, `/rest/api/3/screens/${screenId}/tabs/${tabId}/move/${pos}`, undefined, headers);
}
