import { Screen } from "../../../types/screen";
/**
* Returns all fields for a screen tab.

**[Permissions](#permissions) required:**

 *  *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
 *  *Administer projects* [project permission](https://confluence.atlassian.com/x/yodKLg) when the project key is specified, providing that the screen is associated with the project through a Screen Scheme and Issue Type Screen Scheme.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-screens/#api-rest-api-3-screens-screenid-tabs-tabid-fields-get
* @param options Request options.
*/
export declare function getScreenTabFields(options: Screen.Tab.Field.GetFields.Options.RawApi): Promise<import("@avst-api/commons").Response<Screen.Tab.Field.GetFields.Response.OK | undefined>>;
/**
* Adds a field to a screen tab.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-screens/#api-rest-api-3-screens-screenid-tabs-tabid-fields-post
* @param options Request options.
*/
export declare function addScreenTabField(options: Screen.Tab.Field.AddField.Options.RawApi): Promise<import("@avst-api/commons").Response<import("../../../definitions/ScreenableFieldAsResponse").ScreenableFieldAsResponse | undefined>>;
/**
* Removes a field from a screen tab.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-screens/#api-rest-api-3-screens-screenid-tabs-tabid-fields-id-delete
* @param options Request options.
*/
export declare function removeScreenTabField(options: Screen.Tab.Field.RemoveField.Options.RawApi): Promise<import("@avst-api/commons").Response<undefined>>;
/**
* Moves a screen tab field.

If `after` and `position` are provided in the request, `position` is ignored.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-screens/#api-rest-api-3-screens-screenid-tabs-tabid-fields-id-move-post
* @param options Request options.
*/
export declare function moveScreenTabField(options: Screen.Tab.Field.MoveField.Options.RawApi): Promise<import("@avst-api/commons").Response<any>>;
//# sourceMappingURL=field.d.ts.map