import { httpGet } from "../../../raw-api/common";
import { constructUrl } from "@avst-api/commons";
import { httpPost } from "../../../raw-api/common";
import { httpDelete } from "../../../raw-api/common";
/**
* Returns all fields for a screen tab.

**[Permissions](#permissions) required:**

 *  *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
 *  *Administer projects* [project permission](https://confluence.atlassian.com/x/yodKLg) when the project key is specified, providing that the screen is associated with the project through a Screen Scheme and Issue Type Screen Scheme.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-screens/#api-rest-api-3-screens-screenid-tabs-tabid-fields-get
* @param options Request options.
*/
export function getScreenTabFields(options) {
    const { connectionId: instanceId, headers, screenId, tabId, projectKey } = options;
    const queryParams = { projectKey };
    return httpGet(instanceId, constructUrl(`/rest/api/3/screens/${screenId}/tabs/${tabId}/fields`, queryParams), headers);
}
/**
* Adds a field to a screen tab.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-screens/#api-rest-api-3-screens-screenid-tabs-tabid-fields-post
* @param options Request options.
*/
export function addScreenTabField(options) {
    const { connectionId: instanceId, headers, screenId, tabId, body } = options;
    return httpPost(instanceId, `/rest/api/3/screens/${screenId}/tabs/${tabId}/fields`, body, headers);
}
/**
* Removes a field from a screen tab.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-screens/#api-rest-api-3-screens-screenid-tabs-tabid-fields-id-delete
* @param options Request options.
*/
export function removeScreenTabField(options) {
    const { connectionId: instanceId, headers, screenId, tabId, id } = options;
    return httpDelete(instanceId, `/rest/api/3/screens/${screenId}/tabs/${tabId}/fields/${id}`, headers, true);
}
/**
* Moves a screen tab field.

If `after` and `position` are provided in the request, `position` is ignored.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-screens/#api-rest-api-3-screens-screenid-tabs-tabid-fields-id-move-post
* @param options Request options.
*/
export function moveScreenTabField(options) {
    const { connectionId: instanceId, headers, screenId, tabId, id, body } = options;
    return httpPost(instanceId, `/rest/api/3/screens/${screenId}/tabs/${tabId}/fields/${id}/move`, body, headers);
}
