import { User } from "../types/user";
/**
* Returns the default [issue table columns](https://confluence.atlassian.com/x/XYdKLg) for the user. If `accountId` is not passed in the request, the calling user's details are returned.

**[Permissions](#permissions) required:**

 *  *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLgl), to get the column details for any user.
 *  Permission to access Jira, to get the calling user's column details.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-users/#api-rest-api-3-user-columns-get
* @param options Request options.
*/
export declare function getUserDefaultColumns(options: User.GetDefaultColumns.Options.RawApi): Promise<import("@avst-api/commons").Response<User.GetDefaultColumns.Response.OK | undefined>>;
/**
* Sets the default [ issue table columns](https://confluence.atlassian.com/x/XYdKLg) for the user. If an account ID is not passed, the calling user's default columns are set. If no column details are sent, then all default columns are removed.

The parameters for this resource are expressed as HTML form data. For example, in curl:

`curl -X PUT -d columns=summary -d columns=description https://your-domain.atlassian.net/rest/api/3/user/columns?accountId=5b10ac8d82e05b22cc7d4ef5'`

**[Permissions](#permissions) required:**

 *  *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg), to set the columns on any user.
 *  Permission to access Jira, to set the calling user's columns.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-users/#api-rest-api-3-user-columns-put
* @param options Request options.
*/
export declare function setUserDefaultColumns(options: User.SetDefaultColumns.Options.RawApi): Promise<import("@avst-api/commons").Response<any>>;
/**
* Resets the default [ issue table columns](https://confluence.atlassian.com/x/XYdKLg) for the user to the system default. If `accountId` is not passed, the calling user's default columns are reset.

**[Permissions](#permissions) required:**

 *  *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg), to set the columns on any user.
 *  Permission to access Jira, to set the calling user's columns.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-users/#api-rest-api-3-user-columns-delete
* @param options Request options.
*/
export declare function resetUserDefaultColumns(options: User.ResetDefaultColumns.Options.RawApi): Promise<import("@avst-api/commons").Response<undefined>>;
/**
* Returns a user.

**[Permissions](#permissions) required:** *Browse users and groups* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-user-get
* @param options Request options.
*/
export declare function getUser(options: User.GetUser.Options.RawApi): Promise<import("@avst-api/commons").Response<import("../definitions/UserAsResponse").UserAsResponse | undefined>>;
/**
* Creates a user. This resource is retained for legacy compatibility. As soon as a more suitable alternative is available this resource will be deprecated.

If the user exists and has access to Jira, the operation returns a 201 status. If the user exists but does not have access to Jira, the operation returns a 400 status.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-user-post
* @param options Request options.
*/
export declare function createUser(options: User.CreateUser.Options.RawApi): Promise<import("@avst-api/commons").Response<import("../definitions/UserAsResponse").UserAsResponse | undefined>>;
/**
* Deletes a user.

**[Permissions](#permissions) required:** Site administration (that is, membership of the *site-admin* [group](https://confluence.atlassian.com/x/24xjL)).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-user-delete
* @param options Request options.
*/
export declare function deleteUser(options: User.DeleteUser.Options.RawApi): Promise<import("@avst-api/commons").Response<undefined>>;
/**
* Returns the account IDs for the users specified in the `key` or `username` parameters. Note that multiple `key` or `username` parameters can be specified.

**[Permissions](#permissions) required:** Permission to access Jira.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-user-bulk-migration-get
* @param options Request options.
*/
export declare function getAccountIdsForUsers(options: User.GetAccountIdsForUsers.Options.RawApi): Promise<import("@avst-api/commons").Response<User.GetAccountIdsForUsers.Response.OK | undefined>>;
/**
 * Returns a user's email address. This API is only available to apps approved by Atlassian, according to these [guidelines](https://community.developer.atlassian.com/t/guidelines-for-requesting-access-to-email-address/27603).
 * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-user-email-get
 * @param options Request options.
 */
export declare function getUserEmail(options: User.GetEmail.Options.RawApi): Promise<import("@avst-api/commons").Response<import("../definitions/UnrestrictedUserEmailAsResponse").UnrestrictedUserEmailAsResponse | undefined>>;
/**
* Returns the groups to which a user belongs.

**[Permissions](#permissions) required:** *Browse users and groups* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-user-groups-get
* @param options Request options.
*/
export declare function getUserGroups(options: User.GetGroups.Options.RawApi): Promise<import("@avst-api/commons").Response<User.GetGroups.Response.OK | undefined>>;
/**
* Returns a list of all (active and inactive) users.

**[Permissions](#permissions) required:** *Browse users and groups* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-users-search-get
* @param options Request options.
*/
export declare function getUsers(options: User.GetUsers.Options.RawApi): Promise<import("@avst-api/commons").Response<User.GetUsers.Response.OK | undefined>>;
//# sourceMappingURL=user.d.ts.map