import { User } from "../../types/user";
/**
* Returns the keys of all properties for a user.

Note: This operation does not access the [user properties](https://confluence.atlassian.com/x/8YxjL) created and maintained in Jira.

**[Permissions](#permissions) required:**

 *  *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg), to access the property keys on any user.
 *  Access to Jira, to access the calling user's property keys.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-user-properties/#api-rest-api-3-user-properties-get
* @param options Request options.
*/
export declare function getUserPropertyKeys(options: User.Property.GetPropertyKeys.Options.RawApi): Promise<import("@avst-api/commons").Response<import("../../definitions/PropertyKeysAsResponse").PropertyKeysAsResponse | undefined>>;
/**
* Returns the value of a user's property.

Note: This operation does not access the [user properties](https://confluence.atlassian.com/x/8YxjL) created and maintained in Jira.

**[Permissions](#permissions) required:**

 *  *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg), to get a property from any user.
 *  Access to Jira, to get a property from the calling user's record.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-user-properties/#api-rest-api-3-user-properties-propertykey-get
* @param options Request options.
*/
export declare function getUserProperty(options: User.Property.GetProperty.Options.RawApi): Promise<import("@avst-api/commons").Response<import("../../definitions/EntityPropertyAsResponse").EntityPropertyAsResponse | undefined>>;
/**
* Sets the value of a user's property. Use this resource to store custom data against a user.

Note: This operation does not access the [user properties](https://confluence.atlassian.com/x/8YxjL) created and maintained in Jira.

**[Permissions](#permissions) required:**

 *  *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg), to set a property on any user.
 *  Access to Jira, to set a property on the calling user's record.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-user-properties/#api-rest-api-3-user-properties-propertykey-put
* @param options Request options.
*/
export declare function setUserProperty(options: User.Property.SetProperty.Options.RawApi): Promise<import("@avst-api/commons").Response<any>>;
/**
* Deletes a property from a user.

Note: This operation does not access the [user properties](https://confluence.atlassian.com/x/8YxjL) created and maintained in Jira.

**[Permissions](#permissions) required:**

 *  *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg), to delete a property from any user.
 *  Access to Jira, to delete a property from the calling user's record.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-user-properties/#api-rest-api-3-user-properties-propertykey-delete
* @param options Request options.
*/
export declare function deleteUserProperty(options: User.Property.DeleteProperty.Options.RawApi): Promise<import("@avst-api/commons").Response<undefined>>;
//# sourceMappingURL=property.d.ts.map