import { Workflow } from "../../types/workflow";
/**
* Returns a [paginated](#pagination) list of all workflow schemes, not including draft workflow schemes.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-workflowscheme-get
* @param options Request options.
*/
export declare function getWorkflowSchemes(options: Workflow.Scheme.GetSchemes.Options.RawApi): Promise<import("@avst-api/commons").Response<import("../../definitions/PageBeanWorkflowSchemeAsResponse").PageBeanWorkflowSchemeAsResponse | undefined>>;
/**
* Creates a workflow scheme.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-workflow-schemes/#api-rest-api-3-workflowscheme-post
* @param options Request options.
*/
export declare function createWorkflowScheme(options: Workflow.Scheme.CreateScheme.Options.RawApi): Promise<import("@avst-api/commons").Response<import("../../definitions/WorkflowSchemeAsResponse").WorkflowSchemeAsResponse | undefined>>;
/**
* Returns a workflow scheme.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-workflow-schemes/#api-rest-api-3-workflowscheme-id-get
* @param options Request options.
*/
export declare function getWorkflowScheme(options: Workflow.Scheme.GetScheme.Options.RawApi): Promise<import("@avst-api/commons").Response<import("../../definitions/WorkflowSchemeAsResponse").WorkflowSchemeAsResponse | undefined>>;
/**
* Updates a workflow scheme, including the name, default workflow, issue type to project mappings, and more. If the workflow scheme is active (that is, being used by at least one project), then a draft workflow scheme is created or updated instead, provided that `updateDraftIfNeeded` is set to `true`.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-workflow-schemes/#api-rest-api-3-workflowscheme-id-put
* @param options Request options.
*/
export declare function updateWorkflowScheme(options: Workflow.Scheme.UpdateScheme.Options.RawApi): Promise<import("@avst-api/commons").Response<import("../../definitions/WorkflowSchemeAsResponse").WorkflowSchemeAsResponse | undefined>>;
/**
* Deletes a workflow scheme. Note that a workflow scheme cannot be deleted if it is active (that is, being used by at least one project).

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-workflow-schemes/#api-rest-api-3-workflowscheme-id-delete
* @param options Request options.
*/
export declare function deleteWorkflowScheme(options: Workflow.Scheme.DeleteScheme.Options.RawApi): Promise<import("@avst-api/commons").Response<undefined>>;
/**
* Returns the issue type-workflow mapping for an issue type in a workflow scheme.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-workflow-schemes/#api-rest-api-3-workflowscheme-id-issuetype-issuetype-get
* @param options Request options.
*/
export declare function getWorkflowForIssueTypeInWorkflowScheme(options: Workflow.Scheme.GetWorkflowForIssueType.Options.RawApi): Promise<import("@avst-api/commons").Response<import("../../definitions/IssueTypeWorkflowMappingAsResponse").IssueTypeWorkflowMappingAsResponse | undefined>>;
/**
* Sets the workflow for an issue type in a workflow scheme.

Note that active workflow schemes cannot be edited. If the workflow scheme is active, set `updateDraftIfNeeded` to `true` in the request body and a draft workflow scheme is created or updated with the new issue type-workflow mapping. The draft workflow scheme can be published in Jira.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-workflow-schemes/#api-rest-api-3-workflowscheme-id-issuetype-issuetype-put
* @param options Request options.
*/
export declare function setWorkflowForIssueTypeInWorkflowScheme(options: Workflow.Scheme.SetWorkflowForIssueType.Options.RawApi): Promise<import("@avst-api/commons").Response<import("../../definitions/WorkflowSchemeAsResponse").WorkflowSchemeAsResponse | undefined>>;
/**
* Deletes the issue type-workflow mapping for an issue type in a workflow scheme.

Note that active workflow schemes cannot be edited. If the workflow scheme is active, set `updateDraftIfNeeded` to `true` and a draft workflow scheme is created or updated with the issue type-workflow mapping deleted. The draft workflow scheme can be published in Jira.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-workflow-schemes/#api-rest-api-3-workflowscheme-id-issuetype-issuetype-delete
* @param options Request options.
*/
export declare function deleteWorkflowForIssueTypeInWorkflowScheme(options: Workflow.Scheme.DeleteWorkflowForIssueType.Options.RawApi): Promise<import("@avst-api/commons").Response<import("../../definitions/WorkflowSchemeAsResponse").WorkflowSchemeAsResponse | undefined>>;
/**
* Returns the workflow-issue type mappings for a workflow scheme.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-workflow-schemes/#api-rest-api-3-workflowscheme-id-workflow-get
* @param options Request options.
*/
export declare function getIssueTypesForWorkflowInWorkflowScheme(options: Workflow.Scheme.GetIssueTypesForWorkflow.Options.RawApi): Promise<import("@avst-api/commons").Response<Workflow.Scheme.GetIssueTypesForWorkflow.Response.OK | undefined>>;
/**
* Sets the issue types for a workflow in a workflow scheme. The workflow can also be set as the default workflow for the workflow scheme. Unmapped issues types are mapped to the default workflow.

Note that active workflow schemes cannot be edited. If the workflow scheme is active, set `updateDraftIfNeeded` to `true` in the request body and a draft workflow scheme is created or updated with the new workflow-issue types mappings. The draft workflow scheme can be published in Jira.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-workflow-schemes/#api-rest-api-3-workflowscheme-id-workflow-put
* @param options Request options.
*/
export declare function setIssueTypesForWorkflowInWorkflowScheme(options: Workflow.Scheme.SetIssueTypesForWorkflow.Options.RawApi): Promise<import("@avst-api/commons").Response<import("../../definitions/WorkflowSchemeAsResponse").WorkflowSchemeAsResponse | undefined>>;
/**
* Deletes the workflow-issue type mapping for a workflow in a workflow scheme.

Note that active workflow schemes cannot be edited. If the workflow scheme is active, set `updateDraftIfNeeded` to `true` and a draft workflow scheme is created or updated with the workflow-issue type mapping deleted. The draft workflow scheme can be published in Jira.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-workflow-schemes/#api-rest-api-3-workflowscheme-id-workflow-delete
* @param options Request options.
*/
export declare function deleteIssueTypesForWorkflowInWorkflowScheme(options: Workflow.Scheme.DeleteIssueTypesForWorkflow.Options.RawApi): Promise<import("@avst-api/commons").Response<undefined>>;
/**
* Returns the default workflow for a workflow scheme. The default workflow is the workflow that is assigned any issue types that have not been mapped to any other workflow. The default workflow has *All Unassigned Issue Types* listed in its issue types for the workflow scheme in Jira.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-workflow-schemes/#api-rest-api-3-workflowscheme-id-default-get
* @param options Request options.
*/
export declare function getDefaultWorkflowForWorkflowScheme(options: Workflow.Scheme.GetDefaultWorkflow.Options.RawApi): Promise<import("@avst-api/commons").Response<import("../../definitions/DefaultWorkflowAsResponse").DefaultWorkflowAsResponse | undefined>>;
/**
* Sets the default workflow for a workflow scheme.

Note that active workflow schemes cannot be edited. If the workflow scheme is active, set `updateDraftIfNeeded` to `true` in the request object and a draft workflow scheme is created or updated with the new default workflow. The draft workflow scheme can be published in Jira.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-workflow-schemes/#api-rest-api-3-workflowscheme-id-default-put
* @param options Request options.
*/
export declare function updateDefaultWorkflowForWorkflowScheme(options: Workflow.Scheme.UpdateDefaultWorkflow.Options.RawApi): Promise<import("@avst-api/commons").Response<import("../../definitions/WorkflowSchemeAsResponse").WorkflowSchemeAsResponse | undefined>>;
/**
* Resets the default workflow for a workflow scheme. That is, the default workflow is set to Jira's system workflow (the *jira* workflow).

Note that active workflow schemes cannot be edited. If the workflow scheme is active, set `updateDraftIfNeeded` to `true` and a draft workflow scheme is created or updated with the default workflow reset. The draft workflow scheme can be published in Jira.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-workflow-schemes/#api-rest-api-3-workflowscheme-id-default-delete
* @param options Request options.
*/
export declare function deleteDefaultWorkflowForWorkflowScheme(options: Workflow.Scheme.DeleteDefaultWorkflow.Options.RawApi): Promise<import("@avst-api/commons").Response<import("../../definitions/WorkflowSchemeAsResponse").WorkflowSchemeAsResponse | undefined>>;
//# sourceMappingURL=scheme.d.ts.map