import { httpGet } from "../../../raw-api/common";
import { constructUrl } from "@avst-api/commons";
import { httpPut } from "../../../raw-api/common";
/**
* Returns a list of the workflow schemes associated with a list of projects. Each returned workflow scheme includes a list of the requested projects associated with it. Any team-managed or non-existent projects in the request are ignored and no errors are returned.

If the project is associated with the `Default Workflow Scheme` no ID is returned. This is because the way the `Default Workflow Scheme` is stored means it has no ID.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-workflow-scheme-project-associations/#api-rest-api-3-workflowscheme-project-get
* @param options Request options.
*/
export function getWorkflowSchemeProjectAssociations(options) {
    const { connectionId: instanceId, headers, projectId } = options;
    const queryParams = { projectId };
    return httpGet(instanceId, constructUrl(`/rest/api/3/workflowscheme/project`, queryParams, true), headers);
}
/**
* Assigns a workflow scheme to a project. This operation is performed only when there are no issues in the project.

Workflow schemes can only be assigned to classic projects.

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-workflow-scheme-project-associations/#api-rest-api-3-workflowscheme-project-put
* @param options Request options.
*/
export function assignWorkflowSchemeToProject(options) {
    const { connectionId: instanceId, headers, body } = options;
    return httpPut(instanceId, `/rest/api/3/workflowscheme/project`, body, headers);
}
