import { httpGet } from "../../raw-api/common";
/**
* Returns a list of all statuses associated with workflows.

This operation can be accessed anonymously.

**[Permissions](#permissions) required:** None.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-status-get
* @param options Request options.
*/
export function getWorkflowStatuses(options) {
    const { connectionId: instanceId, headers } = options;
    return httpGet(instanceId, `/rest/api/3/status`, headers);
}
/**
* Returns a status. The status must be associated with a workflow to be returned.

If a name is used on more than one status, only the status found first is returned. Therefore, identifying the status by its ID may be preferable.

This operation can be accessed anonymously.

[Permissions](#permissions) required: None.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-status-idOrName-get
* @param options Request options.
*/
export function getWorkflowStatus(options) {
    const { connectionId: instanceId, headers, idOrName } = options;
    return httpGet(instanceId, `/rest/api/3/status/${idOrName}`, headers);
}
