import { httpGet } from "../../../raw-api/common";
/**
* Returns a list of all status categories.

**[Permissions](#permissions) required:** Permission to access Jira.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-workflow-status-categories/#api-rest-api-3-statuscategory-get
* @param options Request options.
*/
export function getWorkflowStatusCategories(options) {
    const { connectionId: instanceId, headers } = options;
    return httpGet(instanceId, `/rest/api/3/statuscategory`, headers);
}
/**
* Returns a status category. Status categories provided a mechanism for categorizing [statuses](#api-rest-api-3-status-idOrName-get).

**[Permissions](#permissions) required:** Permission to access Jira.
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-workflow-status-categories/#api-rest-api-3-statuscategory-idorkey-get
* @param options Request options.
*/
export function getWorkflowStatusCategory(options) {
    const { connectionId: instanceId, headers, idOrKey } = options;
    return httpGet(instanceId, `/rest/api/3/statuscategory/${idOrKey}`, headers);
}
