import { httpPut } from "../../../raw-api/common";
import { constructUrl } from "@avst-api/commons";
import { httpPost } from "../../../raw-api/common";
import { httpDelete } from "../../../raw-api/common";
/**
* Updates a workflow transition by changing the property value. Trying to update a property that does not exist results in a new property being added to the transition. Transition properties are used to change the behavior of a transition. For more information, see [Transition properties](https://confluence.atlassian.com/x/zIhKLg#Advancedworkflowconfiguration-transitionproperties) and [Workflow properties](https://confluence.atlassian.com/x/JYlKLg).

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-workflow-transition-properties/#api-rest-api-3-workflow-transitions-transitionid-properties-put
* @param options Request options.
*/
export function updateWorkflowTransitionProperty(options) {
    const { connectionId: instanceId, headers, transitionId, body, key, workflowName, workflowMode } = options;
    const queryParams = { key, workflowName, workflowMode };
    return httpPut(instanceId, constructUrl(`/rest/api/3/workflow/transitions/${transitionId}/properties`, queryParams), body, headers);
}
/**
* Adds a property to a workflow transition. Transition properties are used to change the behavior of a transition. For more information, see [Transition properties](https://confluence.atlassian.com/x/zIhKLg#Advancedworkflowconfiguration-transitionproperties) and [Workflow properties](https://confluence.atlassian.com/x/JYlKLg).

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-workflow-transition-properties/#api-rest-api-3-workflow-transitions-transitionid-properties-post
* @param options Request options.
*/
export function createWorkflowTransitionProperty(options) {
    const { connectionId: instanceId, headers, transitionId, body, key, workflowName, workflowMode } = options;
    const queryParams = { key, workflowName, workflowMode };
    return httpPost(instanceId, constructUrl(`/rest/api/3/workflow/transitions/${transitionId}/properties`, queryParams), body, headers);
}
/**
* Deletes a property from a workflow transition. Transition properties are used to change the behavior of a transition. For more information, see [Transition properties](https://confluence.atlassian.com/x/zIhKLg#Advancedworkflowconfiguration-transitionproperties) and [Workflow properties](https://confluence.atlassian.com/x/JYlKLg).

**[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
* Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-workflow-transition-properties/#api-rest-api-3-workflow-transitions-transitionid-properties-delete
* @param options Request options.
*/
export function deleteWorkflowTransitionProperty(options) {
    const { connectionId: instanceId, headers, transitionId, key, workflowName, workflowMode } = options;
    const queryParams = { key, workflowName, workflowMode };
    return httpDelete(instanceId, constructUrl(`/rest/api/3/workflow/transitions/${transitionId}/properties`, queryParams), headers, true);
}
