import { CustomFieldSelectOption } from '../raw-api/common';
import { Issue } from '../types/issue';
import { AtlassianDocumentFormat } from '@avst-lib/jira-cloud/types/adf';
import { User } from '../types/user';
import { Group } from '../types/group';
import { Project } from '../types/project';
import { ServiceLevelAgreement } from '../rest/codices/serviceLevelAgreement';
import { PagedApproval } from '../rest/codices/approval';
import { PagedOrganization } from '../rest/codices/organization';
import { RequestType } from '../rest/codices/requestType';
import { RequestParticipant } from '../rest/codices/requestParticipant';
export interface CustomFieldsCollection {
    textFields: CustomFieldCollection<string>;
    numberFields: CustomFieldCollection<number>;
    multiSelectFields: CustomFieldCollection<CustomFieldSelectOption[]>;
    datePickerFields: CustomFieldCollection<string>;
    selectFields: CustomFieldCollection<CustomFieldSelectOption>;
    multiCheckboxesFields: CustomFieldCollection<CustomFieldSelectOption[]>;
    dateTimePickerFields: CustomFieldCollection<string>;
    labelsFields: CustomFieldCollection<string[]>;
    radioButtonsFields: CustomFieldCollection<CustomFieldSelectOption>;
    multiLineTextFields: CustomFieldCollection<AtlassianDocumentFormat>;
    urlFields: CustomFieldCollection<string>;
    userPickerFields: CustomFieldCollection<User.GetUser.Response.OK>;
    dateOfFirstResponseFields: CustomFieldCollection<string>;
    daysSinceLastCommentFields: CustomFieldCollection<string>;
    domainOfAssigneeFields: CustomFieldCollection<string>;
    domainOfReporterFields: CustomFieldCollection<string>;
    globalRankFields: CustomFieldCollection<string>;
    multiGroupPickerFields: CustomFieldCollection<Group.CreateGroup.Response.OK[]>;
    groupPickerFields: CustomFieldCollection<Group.CreateGroup.Response.OK>;
    lastCommentByUserFlagFields: CustomFieldCollection<string>;
    lastPublicCommentDateFields: CustomFieldCollection<string>;
    messageForEditFields: CustomFieldCollection<string>;
    messageForViewFields: CustomFieldCollection<string>;
    numberOfAttachmentsFields: CustomFieldCollection<string>;
    numberOfCommentsFields: CustomFieldCollection<string>;
    parentLinkFields: CustomFieldCollection<any>;
    participantsOfAnIssueFields: CustomFieldCollection<string[]>;
    projectPickerFields: CustomFieldCollection<Project.GetProject.Response.OK>;
    teamFields: CustomFieldCollection<any>;
    readOnlyTextFields: CustomFieldCollection<string>;
    timeInStatusFields: CustomFieldCollection<any>;
    multiUserPickerFields: CustomFieldCollection<User.GetUser.Response.OK[]>;
    userPropertyFields: CustomFieldCollection<string>;
    usernameOfLastUpdaterOrCommenterFields: CustomFieldCollection<string>;
    multiVersionPickerFields: CustomFieldCollection<Project.Version.GetVersion.Response.OK[]>;
    versionPickerFields: CustomFieldCollection<Project.Version.GetVersion.Response.OK>;
    issueColorFields: CustomFieldCollection<string>;
    uuidFields: CustomFieldCollection<string>;
    epicColorFields: CustomFieldCollection<string>;
    epicStatusFields: CustomFieldCollection<Issue.Field.Custom.Option.GetOption.Response.OK>;
    epicLinkFields: CustomFieldCollection<string>;
    slaFields: CustomFieldCollection<ServiceLevelAgreement>;
    approvalsFields: CustomFieldCollection<PagedApproval>;
    organizationsFields: CustomFieldCollection<PagedOrganization>;
    requestTypeFields: CustomFieldCollection<RequestType>;
    requestParticipantsFields: CustomFieldCollection<RequestParticipant>;
    satisfactionDateFields: CustomFieldCollection<string>;
    satisfactionFields: CustomFieldCollection<any>;
    requestLanguageFields: CustomFieldCollection<any>;
    sprintFields: CustomFieldCollection<any>;
    locationFields: CustomFieldCollection<any>;
    assetsFields: CustomFieldCollection<any>;
    epicNameFields: CustomFieldCollection<string>;
    developmentFields: CustomFieldCollection<any>;
    cascadingSelectFields: CustomFieldCollection<any>;
}
export interface CustomField<T = any> {
    id: string;
    name: string;
    value: T;
}
export declare class CustomFieldReader implements CustomFieldsCollection {
    textFields: CustomFieldCollection<string>;
    numberFields: CustomFieldCollection<number>;
    multiSelectFields: CustomFieldCollection<CustomFieldSelectOption[]>;
    datePickerFields: CustomFieldCollection<string>;
    selectFields: CustomFieldCollection<CustomFieldSelectOption>;
    multiCheckboxesFields: CustomFieldCollection<CustomFieldSelectOption[]>;
    dateTimePickerFields: CustomFieldCollection<string>;
    labelsFields: CustomFieldCollection<string[]>;
    radioButtonsFields: CustomFieldCollection<CustomFieldSelectOption>;
    multiLineTextFields: CustomFieldCollection<import("@avst-lib/jira-cloud/types/adf/doc_node").doc_node>;
    urlFields: CustomFieldCollection<string>;
    userPickerFields: CustomFieldCollection<import("../definitions/UserAsResponse").UserAsResponse>;
    dateOfFirstResponseFields: CustomFieldCollection<string>;
    daysSinceLastCommentFields: CustomFieldCollection<string>;
    domainOfAssigneeFields: CustomFieldCollection<string>;
    domainOfReporterFields: CustomFieldCollection<string>;
    globalRankFields: CustomFieldCollection<string>;
    multiGroupPickerFields: CustomFieldCollection<import("../definitions/GroupAsResponse").GroupAsResponse[]>;
    groupPickerFields: CustomFieldCollection<import("../definitions/GroupAsResponse").GroupAsResponse>;
    lastCommentByUserFlagFields: CustomFieldCollection<string>;
    lastPublicCommentDateFields: CustomFieldCollection<string>;
    messageForEditFields: CustomFieldCollection<string>;
    messageForViewFields: CustomFieldCollection<string>;
    numberOfAttachmentsFields: CustomFieldCollection<string>;
    numberOfCommentsFields: CustomFieldCollection<string>;
    parentLinkFields: CustomFieldCollection<any>;
    participantsOfAnIssueFields: CustomFieldCollection<string[]>;
    projectPickerFields: CustomFieldCollection<import("../definitions/ProjectAsResponse").ProjectAsResponse>;
    teamFields: CustomFieldCollection<any>;
    readOnlyTextFields: CustomFieldCollection<string>;
    timeInStatusFields: CustomFieldCollection<any>;
    multiUserPickerFields: CustomFieldCollection<import("../definitions/UserAsResponse").UserAsResponse[]>;
    userPropertyFields: CustomFieldCollection<string>;
    usernameOfLastUpdaterOrCommenterFields: CustomFieldCollection<string>;
    multiVersionPickerFields: CustomFieldCollection<import("../definitions/VersionAsResponse").VersionAsResponse[]>;
    versionPickerFields: CustomFieldCollection<import("../definitions/VersionAsResponse").VersionAsResponse>;
    issueColorFields: CustomFieldCollection<string>;
    uuidFields: CustomFieldCollection<string>;
    epicColorFields: CustomFieldCollection<string>;
    epicStatusFields: CustomFieldCollection<import("../definitions/CustomFieldOptionAsResponse").CustomFieldOptionAsResponse>;
    epicLinkFields: CustomFieldCollection<string>;
    slaFields: CustomFieldCollection<ServiceLevelAgreement>;
    approvalsFields: CustomFieldCollection<PagedApproval>;
    organizationsFields: CustomFieldCollection<PagedOrganization>;
    requestTypeFields: CustomFieldCollection<RequestType>;
    requestParticipantsFields: CustomFieldCollection<RequestParticipant>;
    satisfactionDateFields: CustomFieldCollection<string>;
    satisfactionFields: CustomFieldCollection<any>;
    requestLanguageFields: CustomFieldCollection<any>;
    sprintFields: CustomFieldCollection<any>;
    locationFields: CustomFieldCollection<any>;
    assetsFields: CustomFieldCollection<any>;
    epicNameFields: CustomFieldCollection<string>;
    developmentFields: CustomFieldCollection<any>;
    cascadingSelectFields: CustomFieldCollection<any>;
    constructor(fields: Issue.Field.Custom.CreateField.Response.OK[], issue: Issue.GetIssue.Response.OK);
    private extractFields;
    private processField;
    private getField;
}
export declare class CustomFieldCollection<T> {
    fields: CustomField<T>[];
    hasValue(customFieldIdOrName: number | string): boolean;
    /**
     * Returns custom field value by field ID or name, or undefined when value is not set
     */
    getValue(customFieldIdOrName: number | string): T | undefined;
    getFields(customFieldIdOrName: number | string): CustomField<T>[];
}
export declare class CustomFieldNotFound extends Error {
    message: string;
    name: string;
    constructor(message: string);
}
export declare class CustomFieldMultipleMatches extends Error {
    message: string;
    name: string;
    constructor(message: string);
}
//# sourceMappingURL=customField.d.ts.map