import { AvatarsAsResponse } from "../definitions/AvatarsAsResponse";
import { HeadersOption, ConnectionOption } from "@avst-api/commons";
import { AssistedErrorStrategyOption } from "../handled-api/common";
import { ErrorStrategyOption } from "../handled-api/common";
import { AvatarAsResponse } from "../definitions/AvatarAsResponse";
export declare namespace Avatar {
    namespace GetAvatars {
        interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
        }
        namespace Response {
            type OK = AvatarsAsResponse;
            type Error = undefined;
        }
        namespace Options {
            interface Base {
                /**
                 * The avatar type.
                 */
                type: "project" | "issuetype";
                /**
                 * The ID of the item the avatar is associated with.
                 */
                entityId: string;
            }
            interface RawApi extends Base, ConnectionOption, HeadersOption {
            }
            interface HandledApi extends RawApi, ErrorStrategyOption {
            }
        }
    }
    namespace LoadAvatar {
        interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
        }
        type Body = {
            /**
             * Valid image types are JPEG, GIF, or PNG.
             */
            filetype: string;
            /**
             * File's content.
             */
            content: ArrayBuffer;
        };
        namespace Response {
            type OK = AvatarAsResponse;
            type Error = undefined;
        }
        namespace Options {
            interface Base {
                /**
                 * The avatar type.
                 */
                type: "project" | "issuetype";
                /**
                 * The ID of the item the avatar is associated with.
                 */
                entityId: string;
                /**
                 * The X coordinate of the top-left corner of the crop region.
                 */
                x?: number;
                /**
                 * The Y coordinate of the top-left corner of the crop region.
                 */
                y?: number;
                /**
                 * The length of each side of the crop region.
                 */
                size: number;
                body: Avatar.LoadAvatar.Body;
            }
            interface RawApi extends Base, ConnectionOption, HeadersOption {
            }
            interface HandledApi extends RawApi, ErrorStrategyOption {
            }
        }
    }
    namespace DeleteAvatar {
        interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
        }
        namespace Response {
            type OK = undefined;
            type Error = undefined;
        }
        namespace Options {
            interface Base {
                /**
                 * The avatar type.
                 */
                type: "project" | "issuetype";
                /**
                 * The ID of the item the avatar is associated with.
                 */
                owningObjectId: string;
                /**
                 * The ID of the avatar.
                 */
                id: number;
            }
            interface RawApi extends Base, ConnectionOption, HeadersOption {
            }
            interface HandledApi extends RawApi, ErrorStrategyOption {
            }
        }
    }
}
//# sourceMappingURL=avatar.d.ts.map