import { AddGroupBean } from "../definitions/AddGroupBean";
import { GroupAsResponse } from "../definitions/GroupAsResponse";
import { HeadersOption, ConnectionOption } from "@avst-api/commons";
import { AssistedErrorStrategyOption } from "../handled-api/common";
import { ErrorStrategyOption } from "../handled-api/common";
import { PageBeanUserDetailsAsResponse } from "../definitions/PageBeanUserDetailsAsResponse";
import { UpdateUserToGroupBean } from "../definitions/UpdateUserToGroupBean";
import { FoundGroupsAsResponse } from "../definitions/FoundGroupsAsResponse";
export declare namespace Group {
    namespace CreateGroup {
        interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
        }
        type Body = AddGroupBean;
        namespace Response {
            type OK = GroupAsResponse;
            type Error = undefined;
        }
        namespace Options {
            interface Base {
                body: Group.CreateGroup.Body;
            }
            interface RawApi extends Base, ConnectionOption, HeadersOption {
            }
            interface HandledApi extends RawApi, ErrorStrategyOption {
            }
        }
    }
    namespace RemoveGroup {
        interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
        }
        namespace Response {
            type OK = undefined;
            type Error = undefined;
        }
        namespace Options {
            interface Base {
                /**
                 * The name of the group.
                 */
                groupname: string;
                /**
                 * The group to transfer restrictions to. Only comments and worklogs are transferred. If restrictions are not transferred, comments and worklogs are inaccessible after the deletion.
                 */
                swapGroup?: string;
            }
            interface RawApi extends Base, ConnectionOption, HeadersOption {
            }
            interface HandledApi extends RawApi, ErrorStrategyOption {
            }
        }
    }
    namespace User {
        namespace GetUsers {
            interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
            }
            namespace Response {
                type OK = PageBeanUserDetailsAsResponse;
                type Error = undefined;
            }
            namespace Options {
                interface Base {
                    /**
                     * The name of the group.
                     */
                    groupname: string;
                    /**
                     * Include inactive users.
                     */
                    includeInactiveUsers?: boolean;
                    /**
                     * The index of the first item to return in a page of results (page offset).
                     */
                    startAt?: number;
                    /**
                     * The maximum number of items to return per page.
                     */
                    maxResults?: number;
                }
                interface RawApi extends Base, ConnectionOption, HeadersOption {
                }
                interface HandledApi extends RawApi, ErrorStrategyOption {
                }
            }
        }
        namespace AddUser {
            interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
            }
            type Body = UpdateUserToGroupBean;
            namespace Response {
                type OK = GroupAsResponse;
                type Error = undefined;
            }
            namespace Options {
                interface Base {
                    /**
                     * The name of the group (case sensitive).
                     */
                    groupname: string;
                    body: Group.User.AddUser.Body;
                }
                interface RawApi extends Base, ConnectionOption, HeadersOption {
                }
                interface HandledApi extends RawApi, ErrorStrategyOption {
                }
            }
        }
        namespace RemoveUser {
            interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
            }
            namespace Response {
                type OK = undefined;
                type Error = undefined;
            }
            namespace Options {
                interface Base {
                    /**
                     * The name of the group.
                     */
                    groupname: string;
                    /**
                     * This parameter is no longer available. See the [deprecation notice](https://developer.atlassian.com/cloud/jira/platform/deprecation-notice-user-privacy-api-migration-guide/) for details.
                     */
                    username?: string;
                    /**
                     * The account ID of the user, which uniquely identifies the user across all Atlassian products. For example, *5b10ac8d82e05b22cc7d4ef5*.
                     */
                    accountId: string;
                }
                interface RawApi extends Base, ConnectionOption, HeadersOption {
                }
                interface HandledApi extends RawApi, ErrorStrategyOption {
                }
            }
        }
    }
    namespace FindGroups {
        interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
        }
        namespace Response {
            type OK = FoundGroupsAsResponse;
            type Error = undefined;
        }
        namespace Options {
            interface Base {
                /**
                 * This parameter is deprecated, setting it does not affect the results. To find groups containing a particular user, use [Get user groups](#api-rest-api-3-user-groups-get).
                 */
                accountId?: string;
                /**
                 * The string to find in group names.
                 */
                query?: string;
                /**
                 * A group to exclude from the result. To exclude multiple groups, provide an ampersand-separated list. For example, `exclude=group1&exclude=group2`.
                 */
                exclude?: Array<string>;
                /**
                 * The maximum number of groups to return. The maximum number of groups that can be returned is limited by the system property `jira.ajax.autocomplete.limit`.
                 */
                maxResults?: number;
                /**
                 * This parameter is no longer available. See the [deprecation notice](https://developer.atlassian.com/cloud/jira/platform/deprecation-notice-user-privacy-api-migration-guide/) for details.
                 */
                userName?: string;
            }
            interface RawApi extends Base, ConnectionOption, HeadersOption {
            }
            interface HandledApi extends RawApi, ErrorStrategyOption {
            }
        }
    }
}
//# sourceMappingURL=group.d.ts.map