import { SimpleApplicationPropertyBean } from "../definitions/SimpleApplicationPropertyBean";
import { ApplicationPropertyAsResponse } from "../definitions/ApplicationPropertyAsResponse";
import { HeadersOption, ConnectionOption } from "@avst-api/commons";
import { AssistedErrorStrategyOption } from "../handled-api/common";
import { ErrorStrategyOption } from "../handled-api/common";
import { AttachmentSettingsAsResponse } from "../definitions/AttachmentSettingsAsResponse";
import { ConfigurationAsResponse } from "../definitions/ConfigurationAsResponse";
import { ServerInformationAsResponse } from "../definitions/ServerInformationAsResponse";
import { LicenseAsResponse } from "../definitions/LicenseAsResponse";
export declare namespace Instance {
    namespace SetApplicationProperty {
        interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
        }
        type Body = SimpleApplicationPropertyBean;
        namespace Response {
            type OK = ApplicationPropertyAsResponse;
            type Error = undefined;
        }
        namespace Options {
            interface Base {
                /**
                 * The key of the application property to update.
                 */
                id: string;
                body: Instance.SetApplicationProperty.Body;
            }
            interface RawApi extends Base, ConnectionOption, HeadersOption {
            }
            interface HandledApi extends RawApi, ErrorStrategyOption {
            }
        }
    }
    namespace GetApplicationProperty {
        interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
        }
        namespace Response {
            type OK = Array<ApplicationPropertyAsResponse>;
            type Error = undefined;
        }
        namespace Options {
            interface Base {
                /**
                 * The key of the application property.
                 */
                key?: string;
                /**
                 * The permission level of all items being returned in the list.
                 */
                permissionLevel?: string;
                /**
                 * When a `key` isn't provided, this filters the list of results by the application property `key` using a regular expression. For example, using `jira.lf.*` will return all application properties with keys that start with *jira.lf.*.
                 */
                keyFilter?: string;
            }
            interface RawApi extends Base, ConnectionOption, HeadersOption {
            }
            interface HandledApi extends RawApi, ErrorStrategyOption {
            }
        }
    }
    namespace GetAdvancedSettings {
        interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
        }
        namespace Response {
            type OK = Array<ApplicationPropertyAsResponse>;
            type Error = undefined;
        }
        namespace Options {
            interface Base {
            }
            interface RawApi extends Base, ConnectionOption, HeadersOption {
            }
            interface HandledApi extends RawApi, ErrorStrategyOption {
            }
        }
    }
    namespace GetAttachmentSettings {
        interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
        }
        namespace Response {
            type OK = AttachmentSettingsAsResponse;
            type Error = undefined;
        }
        namespace Options {
            interface Base {
            }
            interface RawApi extends Base, ConnectionOption, HeadersOption {
            }
            interface HandledApi extends RawApi, ErrorStrategyOption {
            }
        }
    }
    namespace GetGlobalSettings {
        interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
        }
        namespace Response {
            type OK = ConfigurationAsResponse;
            type Error = undefined;
        }
        namespace Options {
            interface Base {
            }
            interface RawApi extends Base, ConnectionOption, HeadersOption {
            }
            interface HandledApi extends RawApi, ErrorStrategyOption {
            }
        }
    }
    namespace GetInfo {
        interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
        }
        namespace Response {
            type OK = ServerInformationAsResponse;
            type Error = undefined;
        }
        namespace Options {
            interface Base {
            }
            interface RawApi extends Base, ConnectionOption, HeadersOption {
            }
            interface HandledApi extends RawApi, ErrorStrategyOption {
            }
        }
    }
    namespace GetLicense {
        interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
        }
        namespace Response {
            type OK = LicenseAsResponse;
            type Error = undefined;
        }
        namespace Options {
            interface Base {
            }
            interface RawApi extends Base, ConnectionOption, HeadersOption {
            }
            interface HandledApi extends RawApi, ErrorStrategyOption {
            }
        }
    }
}
//# sourceMappingURL=instance.d.ts.map