import { HeadersOption, ConnectionOption } from "@avst-api/commons";
import { AssistedErrorStrategyOption } from "../handled-api/common";
import { ErrorStrategyOption } from "../handled-api/common";
import { LocaleAsResponse } from "../definitions/LocaleAsResponse";
import { UserAsResponse } from "../definitions/UserAsResponse";
export declare namespace Myself {
    namespace GetPreference {
        interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
        }
        namespace Response {
            type OK = string;
            type Error = undefined;
        }
        namespace Options {
            interface Base {
                /**
                 * The key of the preference.
                 */
                key: string;
            }
            interface RawApi extends Base, ConnectionOption, HeadersOption {
            }
            interface HandledApi extends RawApi, ErrorStrategyOption {
            }
        }
    }
    namespace SetPreference {
        interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
        }
        type Body = string;
        namespace Response {
            type OK = any;
            type Error = undefined;
        }
        namespace Options {
            interface Base {
                /**
                 * The key of the preference. The maximum length is 255 characters.
                 */
                key: string;
                body: Myself.SetPreference.Body;
            }
            interface RawApi extends Base, ConnectionOption, HeadersOption {
            }
            interface HandledApi extends RawApi, ErrorStrategyOption {
            }
        }
    }
    namespace DeletePreference {
        interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
        }
        namespace Response {
            type OK = undefined;
            type Error = undefined;
        }
        namespace Options {
            interface Base {
                /**
                 * The key of the preference.
                 */
                key: string;
            }
            interface RawApi extends Base, ConnectionOption, HeadersOption {
            }
            interface HandledApi extends RawApi, ErrorStrategyOption {
            }
        }
    }
    namespace GetLocale {
        interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
        }
        namespace Response {
            type OK = LocaleAsResponse;
            type Error = undefined;
        }
        namespace Options {
            interface Base {
            }
            interface RawApi extends Base, ConnectionOption, HeadersOption {
            }
            interface HandledApi extends RawApi, ErrorStrategyOption {
            }
        }
    }
    namespace GetCurrentUser {
        interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
        }
        namespace Response {
            type OK = UserAsResponse;
            type Error = undefined;
        }
        namespace Options {
            interface Base {
                /**
        * Use [expand](#expansion) to include additional information about user in the response. This parameter accepts a comma-separated list. Expand options include:
        
         *  `groups` Returns all groups, including nested groups, the user belongs to.
         *  `applicationRoles` Returns the application roles the user is assigned to.
        */
                expand?: string;
            }
            interface RawApi extends Base, ConnectionOption, HeadersOption {
            }
            interface HandledApi extends RawApi, ErrorStrategyOption {
            }
        }
    }
}
//# sourceMappingURL=myself.d.ts.map