import { PermissionsAsResponse } from "../definitions/PermissionsAsResponse";
import { ErrorCollectionAsResponse } from "../definitions/ErrorCollectionAsResponse";
import { HeadersOption, ConnectionOption } from "@avst-api/commons";
import { AssistedErrorStrategyOption } from "../handled-api/common";
import { ErrorStrategyOption } from "../handled-api/common";
import { BulkPermissionsRequestBean } from "../definitions/BulkPermissionsRequestBean";
import { BulkPermissionGrantsAsResponse } from "../definitions/BulkPermissionGrantsAsResponse";
import { PermissionsKeysBean } from "../definitions/PermissionsKeysBean";
import { PermittedProjectsAsResponse } from "../definitions/PermittedProjectsAsResponse";
import { PermissionSchemesAsResponse } from "../definitions/PermissionSchemesAsResponse";
import { PermissionScheme } from "../definitions/PermissionScheme";
import { PermissionSchemeAsResponse } from "../definitions/PermissionSchemeAsResponse";
import { Scope } from "../definitions/Scope";
import { PermissionGrant } from "../definitions/PermissionGrant";
import { PermissionGrantsAsResponse } from "../definitions/PermissionGrantsAsResponse";
import { PermissionGrantAsResponse } from "../definitions/PermissionGrantAsResponse";
export declare namespace Permission {
    namespace GetMyPermissions {
        interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
        }
        namespace Response {
            type OK = PermissionsAsResponse;
            type Error = ErrorCollectionAsResponse;
        }
        namespace Options {
            interface Base {
                /**
                 * The key of project. Ignored if `projectId` is provided.
                 */
                projectKey?: string;
                /**
                 * The ID of project.
                 */
                projectId?: string;
                /**
                 * The key of the issue. Ignored if `issueId` is provided.
                 */
                issueKey?: string;
                /**
                 * The ID of the issue.
                 */
                issueId?: string;
                /**
                 * A list of permission keys. (Required) This parameter accepts a comma-separated list. To get the list of available permissions, use [Get all permissions](#api-rest-api-3-permissions-get).
                 */
                permissions: string;
                projectUuid?: string;
                projectConfigurationUuid?: string;
            }
            interface RawApi extends Base, ConnectionOption, HeadersOption {
            }
            interface HandledApi extends RawApi, ErrorStrategyOption {
            }
        }
    }
    namespace GetPermissions {
        interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
        }
        namespace Response {
            type OK = PermissionsAsResponse;
            type Error = undefined;
        }
        namespace Options {
            interface Base {
            }
            interface RawApi extends Base, ConnectionOption, HeadersOption {
            }
            interface HandledApi extends RawApi, ErrorStrategyOption {
            }
        }
    }
    namespace GetBulkPermissions {
        interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
        }
        type Body = BulkPermissionsRequestBean;
        namespace Response {
            type OK = BulkPermissionGrantsAsResponse;
            type Error = ErrorCollectionAsResponse;
        }
        namespace Options {
            interface Base {
                body: Permission.GetBulkPermissions.Body;
            }
            interface RawApi extends Base, ConnectionOption, HeadersOption {
            }
            interface HandledApi extends RawApi, ErrorStrategyOption {
            }
        }
    }
    namespace GetPermittedProjects {
        interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
        }
        type Body = PermissionsKeysBean;
        namespace Response {
            type OK = PermittedProjectsAsResponse;
            type Error = undefined;
        }
        namespace Options {
            interface Base {
                body: Permission.GetPermittedProjects.Body;
            }
            interface RawApi extends Base, ConnectionOption, HeadersOption {
            }
            interface HandledApi extends RawApi, ErrorStrategyOption {
            }
        }
    }
    namespace Scheme {
        namespace GetSchemes {
            interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
            }
            namespace Response {
                type OK = PermissionSchemesAsResponse;
                type Error = undefined;
            }
            namespace Options {
                interface Base {
                    /**
          * Use expand to include additional information in the response. This parameter accepts a comma-separated list. Note that permissions are included when you specify any value. Expand options include:
          
           *  `all` Returns all expandable information.
           *  `field` Returns information about the custom field granted the permission.
           *  `group` Returns information about the group that is granted the permission.
           *  `permissions` Returns all permission grants for each permission scheme.
           *  `projectRole` Returns information about the project role granted the permission.
           *  `user` Returns information about the user who is granted the permission.
          */
                    expand?: string;
                }
                interface RawApi extends Base, ConnectionOption, HeadersOption {
                }
                interface HandledApi extends RawApi, ErrorStrategyOption {
                }
            }
        }
        namespace CreateScheme {
            interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
            }
            type Body = PermissionScheme;
            namespace Response {
                type OK = PermissionSchemeAsResponse;
                type Error = undefined;
            }
            namespace Options {
                interface Base {
                    /**
          * Use expand to include additional information in the response. This parameter accepts a comma-separated list. Note that permissions are always included when you specify any value. Expand options include:
          
           *  `all` Returns all expandable information.
           *  `field` Returns information about the custom field granted the permission.
           *  `group` Returns information about the group that is granted the permission.
           *  `permissions` Returns all permission grants for each permission scheme.
           *  `projectRole` Returns information about the project role granted the permission.
           *  `user` Returns information about the user who is granted the permission.
          */
                    expand?: string;
                    body: Permission.Scheme.CreateScheme.Body;
                }
                interface RawApi extends Base, ConnectionOption, HeadersOption {
                }
                interface HandledApi extends RawApi, ErrorStrategyOption {
                }
            }
        }
        namespace GetScheme {
            interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
            }
            namespace Response {
                type OK = PermissionSchemeAsResponse;
                type Error = undefined;
            }
            namespace Options {
                interface Base {
                    /**
                     * The ID of the permission scheme to return.
                     */
                    schemeId: number;
                    /**
          * Use expand to include additional information in the response. This parameter accepts a comma-separated list. Note that permissions are included when you specify any value. Expand options include:
          
           *  `all` Returns all expandable information.
           *  `field` Returns information about the custom field granted the permission.
           *  `group` Returns information about the group that is granted the permission.
           *  `permissions` Returns all permission grants for each permission scheme.
           *  `projectRole` Returns information about the project role granted the permission.
           *  `user` Returns information about the user who is granted the permission.
          */
                    expand?: string;
                }
                interface RawApi extends Base, ConnectionOption, HeadersOption {
                }
                interface HandledApi extends RawApi, ErrorStrategyOption {
                }
            }
        }
        namespace UpdateScheme {
            interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
            }
            type Body = {
                /**
                 * The name of the permission scheme. Must be unique.
                 */
                name?: string;
                /**
                 * A description for the permission scheme.
                 */
                description?: string;
                /**
                 * The scope of the permission scheme.
                 */
                scope?: Scope;
                /**
                 * The permission scheme to create or update. See [About permission schemes and grants](#about-permission-schemes-and-grants) for more information.
                 */
                permissions?: Array<PermissionGrant>;
                [x: string]: any;
            };
            namespace Response {
                type OK = PermissionSchemeAsResponse;
                type Error = undefined;
            }
            namespace Options {
                interface Base {
                    /**
                     * The ID of the permission scheme to update.
                     */
                    schemeId: number;
                    /**
          * Use expand to include additional information in the response. This parameter accepts a comma-separated list. Note that permissions are always included when you specify any value. Expand options include:
          
           *  `all` Returns all expandable information.
           *  `field` Returns information about the custom field granted the permission.
           *  `group` Returns information about the group that is granted the permission.
           *  `permissions` Returns all permission grants for each permission scheme.
           *  `projectRole` Returns information about the project role granted the permission.
           *  `user` Returns information about the user who is granted the permission.
          */
                    expand?: string;
                    body: Permission.Scheme.UpdateScheme.Body;
                }
                interface RawApi extends Base, ConnectionOption, HeadersOption {
                }
                interface HandledApi extends RawApi, ErrorStrategyOption {
                }
            }
        }
        namespace DeleteScheme {
            interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
            }
            namespace Response {
                type OK = undefined;
                type Error = undefined;
            }
            namespace Options {
                interface Base {
                    /**
                     * The ID of the permission scheme being deleted.
                     */
                    schemeId: number;
                }
                interface RawApi extends Base, ConnectionOption, HeadersOption {
                }
                interface HandledApi extends RawApi, ErrorStrategyOption {
                }
            }
        }
        namespace Grant {
            namespace GetGrants {
                interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
                }
                namespace Response {
                    type OK = PermissionGrantsAsResponse;
                    type Error = undefined;
                }
                namespace Options {
                    interface Base {
                        /**
                         * The ID of the permission scheme.
                         */
                        schemeId: number;
                        /**
            * Use expand to include additional information in the response. This parameter accepts a comma-separated list. Note that permissions are always included when you specify any value. Expand options include:
            
             *  `permissions` Returns all permission grants for each permission scheme.
             *  `user` Returns information about the user who is granted the permission.
             *  `group` Returns information about the group that is granted the permission.
             *  `projectRole` Returns information about the project role granted the permission.
             *  `field` Returns information about the custom field granted the permission.
             *  `all` Returns all expandable information.
            */
                        expand?: string;
                    }
                    interface RawApi extends Base, ConnectionOption, HeadersOption {
                    }
                    interface HandledApi extends RawApi, ErrorStrategyOption {
                    }
                }
            }
            namespace CreateGrant {
                interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
                }
                type Body = PermissionGrant;
                namespace Response {
                    type OK = PermissionGrantAsResponse;
                    type Error = undefined;
                }
                namespace Options {
                    interface Base {
                        /**
                         * The ID of the permission scheme in which to create a new permission grant.
                         */
                        schemeId: number;
                        /**
            * Use expand to include additional information in the response. This parameter accepts a comma-separated list. Note that permissions are always included when you specify any value. Expand options include:
            
             *  `permissions` Returns all permission grants for each permission scheme.
             *  `user` Returns information about the user who is granted the permission.
             *  `group` Returns information about the group that is granted the permission.
             *  `projectRole` Returns information about the project role granted the permission.
             *  `field` Returns information about the custom field granted the permission.
             *  `all` Returns all expandable information.
            */
                        expand?: string;
                        body: Permission.Scheme.Grant.CreateGrant.Body;
                    }
                    interface RawApi extends Base, ConnectionOption, HeadersOption {
                    }
                    interface HandledApi extends RawApi, ErrorStrategyOption {
                    }
                }
            }
            namespace GetGrant {
                interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
                }
                namespace Response {
                    type OK = PermissionGrantAsResponse;
                    type Error = undefined;
                }
                namespace Options {
                    interface Base {
                        /**
                         * The ID of the permission scheme.
                         */
                        schemeId: number;
                        /**
                         * The ID of the permission grant.
                         */
                        permissionId: number;
                        /**
            * Use expand to include additional information in the response. This parameter accepts a comma-separated list. Note that permissions are always included when you specify any value. Expand options include:
            
             *  `all` Returns all expandable information.
             *  `field` Returns information about the custom field granted the permission.
             *  `group` Returns information about the group that is granted the permission.
             *  `permissions` Returns all permission grants for each permission scheme.
             *  `projectRole` Returns information about the project role granted the permission.
             *  `user` Returns information about the user who is granted the permission.
            */
                        expand?: string;
                    }
                    interface RawApi extends Base, ConnectionOption, HeadersOption {
                    }
                    interface HandledApi extends RawApi, ErrorStrategyOption {
                    }
                }
            }
            namespace DeleteGrant {
                interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
                }
                namespace Response {
                    type OK = undefined;
                    type Error = undefined;
                }
                namespace Options {
                    interface Base {
                        /**
                         * The ID of the permission scheme to delete the permission grant from.
                         */
                        schemeId: number;
                        /**
                         * The ID of the permission grant to delete.
                         */
                        permissionId: number;
                    }
                    interface RawApi extends Base, ConnectionOption, HeadersOption {
                    }
                    interface HandledApi extends RawApi, ErrorStrategyOption {
                    }
                }
            }
        }
    }
}
//# sourceMappingURL=permission.d.ts.map