import { ProjectComponentAsResponse } from "../definitions/ProjectComponentAsResponse";
import { HeadersOption, ConnectionOption } from "@avst-api/commons";
import { AssistedErrorStrategyOption } from "../handled-api/common";
import { ErrorStrategyOption } from "../handled-api/common";
import { ComponentAsResponse } from "../definitions/ComponentAsResponse";
import { ComponentIssuesCountAsResponse } from "../definitions/ComponentIssuesCountAsResponse";
import { PageBeanComponentWithIssueCountAsResponse } from "../definitions/PageBeanComponentWithIssueCountAsResponse";
import { ProjectIdentifiersAsResponse } from "../definitions/ProjectIdentifiersAsResponse";
import { PageBeanProjectAsResponse } from "../definitions/PageBeanProjectAsResponse";
import { StringList } from "../definitions/StringList";
import { ProjectAsResponse } from "../definitions/ProjectAsResponse";
import { ProjectRoleAsResponse } from "../definitions/ProjectRoleAsResponse";
import { ProjectRoleActorsUpdateBean } from "../definitions/ProjectRoleActorsUpdateBean";
import { ActorsMap } from "../definitions/ActorsMap";
import { ActorInputBean } from "../definitions/ActorInputBean";
import { ProjectRoleDetailsAsResponse } from "../definitions/ProjectRoleDetailsAsResponse";
import { CreateUpdateRoleRequestBean } from "../definitions/CreateUpdateRoleRequestBean";
import { IssueTypeWithStatusAsResponse } from "../definitions/IssueTypeWithStatusAsResponse";
import { PageBeanVersionAsResponse } from "../definitions/PageBeanVersionAsResponse";
import { VersionAsResponse } from "../definitions/VersionAsResponse";
import { VersionMoveBean } from "../definitions/VersionMoveBean";
import { VersionIssueCountsAsResponse } from "../definitions/VersionIssueCountsAsResponse";
import { VersionUnresolvedIssuesCountAsResponse } from "../definitions/VersionUnresolvedIssuesCountAsResponse";
import { DeleteAndReplaceVersionBean } from "../definitions/DeleteAndReplaceVersionBean";
import { ProjectIssueTypeHierarchyAsResponse } from "../definitions/ProjectIssueTypeHierarchyAsResponse";
import { ErrorCollectionAsResponse } from "../definitions/ErrorCollectionAsResponse";
import { ProjectTypeAsResponse } from "../definitions/ProjectTypeAsResponse";
import { ProjectCategoryAsResponse } from "../definitions/ProjectCategoryAsResponse";
import { ProjectCategory } from "../definitions/ProjectCategory";
import { UpdatedProjectCategoryAsResponse } from "../definitions/UpdatedProjectCategoryAsResponse";
import { NotificationSchemeAsResponse } from "../definitions/NotificationSchemeAsResponse";
import { IdBean } from "../definitions/IdBean";
import { PermissionSchemeAsResponse } from "../definitions/PermissionSchemeAsResponse";
import { ProjectIssueSecurityLevelsAsResponse } from "../definitions/ProjectIssueSecurityLevelsAsResponse";
import { SecuritySchemeAsResponse } from "../definitions/SecuritySchemeAsResponse";
import { PropertyKeysAsResponse } from "../definitions/PropertyKeysAsResponse";
import { EntityPropertyAsResponse } from "../definitions/EntityPropertyAsResponse";
export declare namespace Project {
    namespace Component {
        namespace CreateComponent {
            interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
            }
            type Body = {
                /**
                 * The unique name for the component in the project. Required when creating a component. Optional when updating a component. The maximum length is 255 characters.
                 */
                name: string;
                /**
                 * The description for the component. Optional when creating or updating a component.
                 */
                description?: string;
                /**
                 * This property is no longer available and will be removed from the documentation soon. See the [deprecation notice](https://developer.atlassian.com/cloud/jira/platform/deprecation-notice-user-privacy-api-migration-guide/) for details.
                 */
                leadUserName?: string;
                /**
                 * The accountId of the component's lead user. The accountId uniquely identifies the user across all Atlassian products. For example, *5b10ac8d82e05b22cc7d4ef5*.
                 */
                leadAccountId?: string;
                /**
        * The nominal user type used to determine the assignee for issues created with this component. See `realAssigneeType` for details on how the type of the user, and hence the user, assigned to issues is determined. Can take the following values:
        
         *  `PROJECT_LEAD` the assignee to any issues created with this component is nominally the lead for the project the component is in.
         *  `COMPONENT_LEAD` the assignee to any issues created with this component is nominally the lead for the component.
         *  `UNASSIGNED` an assignee is not set for issues created with this component.
         *  `PROJECT_DEFAULT` the assignee to any issues created with this component is nominally the default assignee for the project that the component is in.
        
        Default value: `PROJECT_DEFAULT`.
        Optional when creating or updating a component.
        */
                assigneeType?: "PROJECT_DEFAULT" | "COMPONENT_LEAD" | "PROJECT_LEAD" | "UNASSIGNED";
                /**
                 * The key of the project the component is assigned to. Required when creating a component. Can't be updated.
                 */
                project: string;
            };
            namespace Response {
                type OK = ProjectComponentAsResponse;
                type Error = undefined;
            }
            namespace Options {
                interface Base {
                    body: Project.Component.CreateComponent.Body;
                }
                interface RawApi extends Base, ConnectionOption, HeadersOption {
                }
                interface HandledApi extends RawApi, ErrorStrategyOption {
                }
            }
        }
        namespace GetComponent {
            interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
            }
            namespace Response {
                type OK = ProjectComponentAsResponse;
                type Error = undefined;
            }
            namespace Options {
                interface Base {
                    /**
                     * The ID of the component.
                     */
                    id: string;
                }
                interface RawApi extends Base, ConnectionOption, HeadersOption {
                }
                interface HandledApi extends RawApi, ErrorStrategyOption {
                }
            }
        }
        namespace UpdateComponent {
            interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
            }
            type Body = {
                /**
                 * The unique name for the component in the project. Required when creating a component. Optional when updating a component. The maximum length is 255 characters.
                 */
                name?: string;
                /**
                 * The description for the component. Optional when creating or updating a component.
                 */
                description?: string;
                /**
                 * The accountId of the component's lead user. The accountId uniquely identifies the user across all Atlassian products. For example, *5b10ac8d82e05b22cc7d4ef5*.
                 */
                leadAccountId?: string;
                /**
        * The nominal user type used to determine the assignee for issues created with this component. See `realAssigneeType` for details on how the type of the user, and hence the user, assigned to issues is determined. Can take the following values:
        
         *  `PROJECT_LEAD` the assignee to any issues created with this component is nominally the lead for the project the component is in.
         *  `COMPONENT_LEAD` the assignee to any issues created with this component is nominally the lead for the component.
         *  `UNASSIGNED` an assignee is not set for issues created with this component.
         *  `PROJECT_DEFAULT` the assignee to any issues created with this component is nominally the default assignee for the project that the component is in.
        
        Default value: `PROJECT_DEFAULT`.
        Optional when creating or updating a component.
        */
                assigneeType?: "PROJECT_DEFAULT" | "COMPONENT_LEAD" | "PROJECT_LEAD" | "UNASSIGNED";
            };
            namespace Response {
                type OK = ComponentAsResponse;
                type Error = undefined;
            }
            namespace Options {
                interface Base {
                    /**
                     * The ID of the component.
                     */
                    id: string;
                    body: Project.Component.UpdateComponent.Body;
                }
                interface RawApi extends Base, ConnectionOption, HeadersOption {
                }
                interface HandledApi extends RawApi, ErrorStrategyOption {
                }
            }
        }
        namespace DeleteComponent {
            interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
            }
            namespace Response {
                type OK = undefined;
                type Error = undefined;
            }
            namespace Options {
                interface Base {
                    /**
                     * The ID of the component.
                     */
                    id: string;
                    /**
                     * The ID of the component to replace the deleted component. If this value is null no replacement is made.
                     */
                    moveIssuesTo?: string;
                }
                interface RawApi extends Base, ConnectionOption, HeadersOption {
                }
                interface HandledApi extends RawApi, ErrorStrategyOption {
                }
            }
        }
        namespace GetIssueCount {
            interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
            }
            namespace Response {
                type OK = ComponentIssuesCountAsResponse;
                type Error = undefined;
            }
            namespace Options {
                interface Base {
                    /**
                     * The ID of the component.
                     */
                    id: string;
                }
                interface RawApi extends Base, ConnectionOption, HeadersOption {
                }
                interface HandledApi extends RawApi, ErrorStrategyOption {
                }
            }
        }
        namespace GetComponentsPaginated {
            interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
            }
            namespace Response {
                type OK = PageBeanComponentWithIssueCountAsResponse;
                type Error = undefined;
            }
            namespace Options {
                interface Base {
                    /**
                     * The project ID or project key (case sensitive).
                     */
                    projectIdOrKey: string;
                    /**
                     * The index of the first item to return in a page of results (page offset).
                     */
                    startAt?: number;
                    /**
                     * The maximum number of items to return per page.
                     */
                    maxResults?: number;
                    /**
          * [Order](#ordering) the results by a field:
          
           *  `description` Sorts by the component description.
           *  `issueCount` Sorts by the count of issues associated with the component.
           *  `lead` Sorts by the user key of the component's project lead.
           *  `name` Sorts by component name.
          */
                    orderBy?: "description" | "-description" | "+description" | "issueCount" | "-issueCount" | "+issueCount" | "lead" | "-lead" | "+lead" | "name" | "-name" | "+name";
                    /**
                     * Filter the results using a literal string. Components with a matching `name` or `description` are returned (case insensitive).
                     */
                    query?: string;
                }
                interface RawApi extends Base, ConnectionOption, HeadersOption {
                }
                interface HandledApi extends RawApi, ErrorStrategyOption {
                }
            }
        }
        namespace GetComponents {
            interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
            }
            namespace Response {
                type OK = Array<ProjectComponentAsResponse>;
                type Error = undefined;
            }
            namespace Options {
                interface Base {
                    /**
                     * The project ID or project key (case sensitive).
                     */
                    projectIdOrKey: string;
                }
                interface RawApi extends Base, ConnectionOption, HeadersOption {
                }
                interface HandledApi extends RawApi, ErrorStrategyOption {
                }
            }
        }
    }
    namespace CreateProject {
        interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
        }
        type Body = {
            /**
             * Project keys must be unique and start with an uppercase letter followed by one or more uppercase alphanumeric characters. The maximum length is 10 characters.
             */
            key: string;
            /**
             * The name of the project.
             */
            name: string;
            /**
             * A brief description of the project.
             */
            description?: string;
            /**
             * This parameter is deprecated because of privacy changes. Use `leadAccountId` instead. See the [migration guide](https://developer.atlassian.com/cloud/jira/platform/deprecation-notice-user-privacy-api-migration-guide/) for details. The user name of the project lead. Either `lead` or `leadAccountId` must be set when creating a project. Cannot be provided with `leadAccountId`.
             */
            lead?: string;
            /**
             * The account ID of the project lead. Either `lead` or `leadAccountId` must be set when creating a project. Cannot be provided with `lead`.
             */
            leadAccountId: string;
            /**
             * A link to information about this project, such as project documentation
             */
            url?: string;
            /**
             * The default assignee when creating issues for this project.
             */
            assigneeType?: "PROJECT_LEAD" | "UNASSIGNED";
            /**
             * An integer value for the project's avatar.
             */
            avatarId?: number;
            /**
             * The ID of the issue security scheme for the project, which enables you to control who can and cannot view issues. Use the [Get issue security schemes](#api-rest-api-3-issuesecurityschemes-get) resource to get all issue security scheme IDs.
             */
            issueSecurityScheme?: number;
            /**
             * The ID of the permission scheme for the project. Use the [Get all permission schemes](#api-rest-api-3-permissionscheme-get) resource to see a list of all permission scheme IDs.
             */
            permissionScheme?: number;
            /**
             * The ID of the notification scheme for the project. Use the [Get notification schemes](#api-rest-api-3-notificationscheme-get) resource to get a list of notification scheme IDs.
             */
            notificationScheme?: number;
            /**
             * The ID of the project's category. A complete list of category IDs is found using the [Get all project categories](#api-rest-api-3-projectCategory-get) operation.
             */
            categoryId?: number;
            /**
             * The [project type](https://confluence.atlassian.com/x/GwiiLQ#Jiraapplicationsoverview-Productfeaturesandprojecttypes), which defines the application-specific feature set. If you don't specify the project template you have to specify the project type.
             */
            projectTypeKey: "software" | "service_desk" | "business";
            /**
             * A predefined configuration for a project. The type of the `projectTemplateKey` must match with the type of the `projectTypeKey`.
             */
            projectTemplateKey: "com.pyxis.greenhopper.jira:gh-simplified-agility-kanban" | "com.pyxis.greenhopper.jira:gh-simplified-agility-scrum" | "com.pyxis.greenhopper.jira:gh-simplified-basic" | "com.pyxis.greenhopper.jira:gh-simplified-kanban-classic" | "com.pyxis.greenhopper.jira:gh-simplified-scrum-classic" | "com.atlassian.servicedesk:simplified-it-service-management" | "com.atlassian.servicedesk:simplified-general-service-desk" | "com.atlassian.servicedesk:simplified-internal-service-desk" | "com.atlassian.servicedesk:simplified-external-service-desk" | "com.atlassian.servicedesk:simplified-hr-service-desk" | "com.atlassian.servicedesk:simplified-facilities-service-desk" | "com.atlassian.servicedesk:simplified-legal-service-desk" | "com.atlassian.jira-core-project-templates:jira-core-simplified-content-management" | "com.atlassian.jira-core-project-templates:jira-core-simplified-document-approval" | "com.atlassian.jira-core-project-templates:jira-core-simplified-lead-tracking" | "com.atlassian.jira-core-project-templates:jira-core-simplified-process-control" | "com.atlassian.jira-core-project-templates:jira-core-simplified-procurement" | "com.atlassian.jira-core-project-templates:jira-core-simplified-project-management" | "com.atlassian.jira-core-project-templates:jira-core-simplified-recruitment" | "com.atlassian.jira-core-project-templates:jira-core-simplified-task-";
            /**
             * The ID of the workflow scheme for the project. Use the [Get all workflow schemes](#api-rest-api-3-workflowscheme-get) operation to get a list of workflow scheme IDs. If you specify the workflow scheme you cannot specify the project template key.
             */
            workflowScheme?: number;
            /**
             * The ID of the issue type screen scheme for the project. Use the [Get all issue type screen schemes](#api-rest-api-3-issuetypescreenscheme-get) operation to get a list of issue type screen scheme IDs. If you specify the issue type screen scheme you cannot specify the project template key.
             */
            issueTypeScreenScheme?: number;
            /**
             * The ID of the issue type scheme for the project. Use the [Get all issue type schemes](#api-rest-api-3-issuetypescheme-get) operation to get a list of issue type scheme IDs. If you specify the issue type scheme you cannot specify the project template key.
             */
            issueTypeScheme?: number;
            /**
             * The ID of the field configuration scheme for the project. Use the [Get all field configuration schemes](#api-rest-api-3-fieldconfigurationscheme-get) operation to get a list of field configuration scheme IDs. If you specify the field configuration scheme you cannot specify the project template key.
             */
            fieldConfigurationScheme?: number;
        };
        namespace Response {
            type OK = ProjectIdentifiersAsResponse;
            type Error = undefined;
        }
        namespace Options {
            interface Base {
                body: Project.CreateProject.Body;
            }
            interface RawApi extends Base, ConnectionOption, HeadersOption {
            }
            interface HandledApi extends RawApi, ErrorStrategyOption {
            }
        }
    }
    namespace GetProjects {
        interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
        }
        namespace Response {
            type OK = PageBeanProjectAsResponse;
            type Error = undefined;
        }
        namespace Options {
            interface Base {
                /**
                 * The index of the first item to return in a page of results (page offset).
                 */
                startAt?: number;
                /**
                 * The maximum number of items to return per page.
                 */
                maxResults?: number;
                /**
        * [Order](#ordering) the results by a field.
        
         *  `category` Sorts by project category. A complete list of category IDs is found using [Get all project categories](#api-rest-api-3-projectCategory-get).
         *  `issueCount` Sorts by the total number of issues in each project.
         *  `key` Sorts by project key.
         *  `lastIssueUpdatedTime` Sorts by the last issue update time.
         *  `name` Sorts by project name.
         *  `owner` Sorts by project lead.
         *  `archivedDate` EXPERIMENTAL. Sorts by project archived date.
         *  `deletedDate` EXPERIMENTAL. Sorts by project deleted date.
        */
                orderBy?: "category" | "-category" | "+category" | "key" | "-key" | "+key" | "name" | "-name" | "+name" | "owner" | "-owner" | "+owner" | "issueCount" | "-issueCount" | "+issueCount" | "lastIssueUpdatedDate" | "-lastIssueUpdatedDate" | "+lastIssueUpdatedDate" | "archivedDate" | "+archivedDate" | "-archivedDate" | "deletedDate" | "+deletedDate" | "-deletedDate";
                /**
                 * The project IDs to filter the results by. To include multiple IDs, provide an ampersand-separated list. For example, `id=10000&id=10001`. Up to 50 project IDs can be provided.
                 */
                id?: Array<number>;
                /**
                 * The project keys to filter the results by. To include multiple keys, provide an ampersand-separated list. For example, `keys=PA&keys=PB`. Up to 50 project keys can be provided.
                 */
                keys?: Array<string>;
                /**
                 * Filter the results using a literal string. Projects with a matching `key` or `name` are returned (case insensitive).
                 */
                query?: string;
                /**
                 * Orders results by the [project type](https://confluence.atlassian.com/x/GwiiLQ#Jiraapplicationsoverview-Productfeaturesandprojecttypes). This parameter accepts a comma-separated list. Valid values are `business`, `service_desk`, and `software`.
                 */
                typeKey?: string;
                /**
                 * The ID of the project's category. A complete list of category IDs is found using the [Get all project categories](#api-rest-api-3-projectCategory-get) operation.
                 */
                categoryId?: number;
                /**
        * Filter results by projects for which the user can:
        
         *  `view` the project, meaning that they have one of the following permissions:
            
             *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project.
             *  *Administer projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project.
             *  *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
         *  `browse` the project, meaning that they have the *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project.
         *  `edit` the project, meaning that they have one of the following permissions:
            
             *  *Administer projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project.
             *  *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
        */
                action?: "view" | "browse" | "edit";
                /**
        * Use [expand](#expansion) to include additional information in the response. This parameter accepts a comma-separated list. Expanded options include:
        
         *  `description` Returns the project description.
         *  `projectKeys` Returns all project keys associated with a project.
         *  `lead` Returns information about the project lead.
         *  `issueTypes` Returns all issue types associated with the project.
         *  `url` Returns the URL associated with the project.
         *  `insight` EXPERIMENTAL. Returns the insight details of total issue count and last issue update time for the project.
        */
                expand?: string;
                /**
        * EXPERIMENTAL. Filter results by project status:
        
         *  `live` Search live projects.
         *  `archived` Search archived projects.
         *  `deleted` Search deleted projects, those in the recycle bin.
        */
                status?: Array<"live" | "archived" | "deleted">;
                /**
                 * EXPERIMENTAL. A list of project properties to return for the project. This parameter accepts a comma-separated list.
                 */
                properties?: Array<StringList>;
                /**
                 * EXPERIMENTAL. A query string used to search properties. The query string cannot be specified using a JSON object. For example, to search for the value of `nested` from `{"something":{"nested":1,"other":2}}` use `[thepropertykey].something.nested=1`. Note that the propertyQuery key is enclosed in square brackets to enable searching where the propertyQuery key includes dot (.) or equals (=) characters. Note that `thepropertykey` is only returned when included in `properties`.
                 */
                propertyQuery?: string;
            }
            interface RawApi extends Base, ConnectionOption, HeadersOption {
            }
            interface HandledApi extends RawApi, ErrorStrategyOption {
            }
        }
    }
    namespace GetProject {
        interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
        }
        namespace Response {
            type OK = ProjectAsResponse;
            type Error = undefined;
        }
        namespace Options {
            interface Base {
                /**
                 * The project ID or project key (case sensitive).
                 */
                projectIdOrKey: string;
                /**
        * Use [expand](#expansion) to include additional information in the response. This parameter accepts a comma-separated list. Note that the project description, issue types, and project lead are included in all responses by default. Expand options include:
        
         *  `description` The project description.
         *  `issueTypes` The issue types associated with the project.
         *  `lead` The project lead.
         *  `projectKeys` All project keys associated with the project.
         *  `issueTypeHierarchy` The project issue type hierarchy.
        */
                expand?: string;
                /**
                 * A list of project properties to return for the project. This parameter accepts a comma-separated list.
                 */
                properties?: Array<string>;
            }
            interface RawApi extends Base, ConnectionOption, HeadersOption {
            }
            interface HandledApi extends RawApi, ErrorStrategyOption {
            }
        }
    }
    namespace UpdateProject {
        interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
        }
        type Body = {
            /**
             * Project keys must be unique and start with an uppercase letter followed by one or more uppercase alphanumeric characters. The maximum length is 10 characters. Required when creating a project. Optional when updating a project.
             */
            key?: string;
            /**
             * The name of the project. Required when creating a project. Optional when updating a project.
             */
            name?: string;
            /**
             * A brief description of the project.
             */
            description?: string;
            /**
             * The account ID of the project lead. Either `lead` or `leadAccountId` must be set when creating a project. Optional when updating a project. Cannot be provided with `lead`.
             */
            leadAccountId?: string;
            /**
             * A link to information about this project, such as project documentation
             */
            url?: string;
            /**
             * The default assignee when creating issues for this project.
             */
            assigneeType?: "PROJECT_LEAD" | "UNASSIGNED";
            /**
             * An integer value for the project's avatar.
             */
            avatarId?: number;
            /**
             * The ID of the issue security scheme for the project, which enables you to control who can and cannot view issues. Use the [Get issue security schemes](#api-rest-api-3-issuesecurityschemes-get) resource to get all issue security scheme IDs.
             */
            issueSecurityScheme?: number;
            /**
             * The ID of the permission scheme for the project. Use the [Get all permission schemes](#api-rest-api-3-permissionscheme-get) resource to see a list of all permission scheme IDs.
             */
            permissionScheme?: number;
            /**
             * The ID of the notification scheme for the project. Use the [Get notification schemes](#api-rest-api-3-notificationscheme-get) resource to get a list of notification scheme IDs.
             */
            notificationScheme?: number;
            /**
             * The ID of the project's category. A complete list of category IDs is found using the [Get all project categories](#api-rest-api-3-projectCategory-get) operation.
             */
            categoryId?: number;
        };
        namespace Response {
            type OK = ProjectAsResponse;
            type Error = undefined;
        }
        namespace Options {
            interface Base {
                /**
                 * The project ID or project key (case sensitive).
                 */
                projectIdOrKey: string;
                /**
        * Use [expand](#expansion) to include additional information in the response. This parameter accepts a comma-separated list. Note that the project description, issue types, and project lead are included in all responses by default. Expand options include:
        
         *  `description` The project description.
         *  `issueTypes` The issue types associated with the project.
         *  `lead` The project lead.
         *  `projectKeys` All project keys associated with the project.
        */
                expand?: string;
                body: Project.UpdateProject.Body;
            }
            interface RawApi extends Base, ConnectionOption, HeadersOption {
            }
            interface HandledApi extends RawApi, ErrorStrategyOption {
            }
        }
    }
    namespace DeleteProject {
        interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
        }
        namespace Response {
            type OK = undefined;
            type Error = undefined;
        }
        namespace Options {
            interface Base {
                /**
                 * The project ID or project key (case sensitive).
                 */
                projectIdOrKey: string;
                /**
                 * Whether this project is placed in the Jira recycle bin where it will be available for restoration.
                 */
                enableUndo?: boolean;
            }
            interface RawApi extends Base, ConnectionOption, HeadersOption {
            }
            interface HandledApi extends RawApi, ErrorStrategyOption {
            }
        }
    }
    namespace Role {
        namespace GetRolesForProject {
            interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
            }
            namespace Response {
                type OK = {
                    [x: string]: string;
                };
                type Error = undefined;
            }
            namespace Options {
                interface Base {
                    /**
                     * The project ID or project key (case sensitive).
                     */
                    projectIdOrKey: string;
                }
                interface RawApi extends Base, ConnectionOption, HeadersOption {
                }
                interface HandledApi extends RawApi, ErrorStrategyOption {
                }
            }
        }
        namespace GetRoleForProject {
            interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
            }
            namespace Response {
                type OK = ProjectRoleAsResponse;
                type Error = undefined;
            }
            namespace Options {
                interface Base {
                    /**
                     * The project ID or project key (case sensitive).
                     */
                    projectIdOrKey: string;
                    /**
                     * The ID of the project role. Use [Get all project roles](#api-rest-api-3-role-get) to get a list of project role IDs.
                     */
                    id: number;
                }
                interface RawApi extends Base, ConnectionOption, HeadersOption {
                }
                interface HandledApi extends RawApi, ErrorStrategyOption {
                }
            }
        }
        namespace Actor {
            namespace SetActors {
                interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
                }
                type Body = ProjectRoleActorsUpdateBean;
                namespace Response {
                    type OK = ProjectRoleAsResponse;
                    type Error = undefined;
                }
                namespace Options {
                    interface Base {
                        /**
                         * The project ID or project key (case sensitive).
                         */
                        projectIdOrKey: string;
                        /**
                         * The ID of the project role. Use [Get all project roles](#api-rest-api-3-role-get) to get a list of project role IDs.
                         */
                        id: number;
                        body: Project.Role.Actor.SetActors.Body;
                    }
                    interface RawApi extends Base, ConnectionOption, HeadersOption {
                    }
                    interface HandledApi extends RawApi, ErrorStrategyOption {
                    }
                }
            }
            namespace AddActors {
                interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
                }
                type Body = ActorsMap;
                namespace Response {
                    type OK = ProjectRoleAsResponse;
                    type Error = undefined;
                }
                namespace Options {
                    interface Base {
                        /**
                         * The project ID or project key (case sensitive).
                         */
                        projectIdOrKey: string;
                        /**
                         * The ID of the project role. Use [Get all project roles](#api-rest-api-3-role-get) to get a list of project role IDs.
                         */
                        id: number;
                        body: Project.Role.Actor.AddActors.Body;
                    }
                    interface RawApi extends Base, ConnectionOption, HeadersOption {
                    }
                    interface HandledApi extends RawApi, ErrorStrategyOption {
                    }
                }
            }
            namespace DeleteActors {
                interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
                }
                namespace Response {
                    type OK = undefined;
                    type Error = undefined;
                }
                namespace Options {
                    interface Base {
                        /**
                         * The project ID or project key (case sensitive).
                         */
                        projectIdOrKey: string;
                        /**
                         * The ID of the project role. Use [Get all project roles](#api-rest-api-3-role-get) to get a list of project role IDs.
                         */
                        id: number;
                        /**
                         * The user account ID of the user to remove from the project role.
                         */
                        user?: string;
                        /**
                         * The name of the group to remove from the project role.
                         */
                        group?: string;
                    }
                    interface RawApi extends Base, ConnectionOption, HeadersOption {
                    }
                    interface HandledApi extends RawApi, ErrorStrategyOption {
                    }
                }
            }
            namespace Default {
                namespace GetActors {
                    interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
                    }
                    namespace Response {
                        type OK = ProjectRoleAsResponse;
                        type Error = undefined;
                    }
                    namespace Options {
                        interface Base {
                            /**
                             * The ID of the project role. Use [Get all project roles](#api-rest-api-3-role-get) to get a list of project role IDs.
                             */
                            id: number;
                        }
                        interface RawApi extends Base, ConnectionOption, HeadersOption {
                        }
                        interface HandledApi extends RawApi, ErrorStrategyOption {
                        }
                    }
                }
                namespace AddActors {
                    interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
                    }
                    type Body = ActorInputBean;
                    namespace Response {
                        type OK = ProjectRoleAsResponse;
                        type Error = undefined;
                    }
                    namespace Options {
                        interface Base {
                            /**
                             * The ID of the project role. Use [Get all project roles](#api-rest-api-3-role-get) to get a list of project role IDs.
                             */
                            id: number;
                            body: Project.Role.Actor.Default.AddActors.Body;
                        }
                        interface RawApi extends Base, ConnectionOption, HeadersOption {
                        }
                        interface HandledApi extends RawApi, ErrorStrategyOption {
                        }
                    }
                }
                namespace DeleteActors {
                    interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
                    }
                    namespace Response {
                        type OK = ProjectRoleAsResponse;
                        type Error = undefined;
                    }
                    namespace Options {
                        interface Base {
                            /**
                             * The ID of the project role. Use [Get all project roles](#api-rest-api-3-role-get) to get a list of project role IDs.
                             */
                            id: number;
                            /**
                             * The user account ID of the user to remove as a default actor.
                             */
                            user?: string;
                            /**
                             * The group name of the group to be removed as a default actor.
                             */
                            group?: string;
                        }
                        interface RawApi extends Base, ConnectionOption, HeadersOption {
                        }
                        interface HandledApi extends RawApi, ErrorStrategyOption {
                        }
                    }
                }
            }
        }
        namespace GetDetails {
            interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
            }
            namespace Response {
                type OK = Array<ProjectRoleDetailsAsResponse>;
                type Error = undefined;
            }
            namespace Options {
                interface Base {
                    /**
                     * The project ID or project key (case sensitive).
                     */
                    projectIdOrKey: string;
                    /**
                     * Whether the roles should be filtered to include only those the user is assigned to.
                     */
                    currentMember?: boolean;
                    excludeConnectAddons?: boolean;
                }
                interface RawApi extends Base, ConnectionOption, HeadersOption {
                }
                interface HandledApi extends RawApi, ErrorStrategyOption {
                }
            }
        }
        namespace GetRoles {
            interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
            }
            namespace Response {
                type OK = Array<ProjectRoleAsResponse>;
                type Error = undefined;
            }
            namespace Options {
                interface Base {
                }
                interface RawApi extends Base, ConnectionOption, HeadersOption {
                }
                interface HandledApi extends RawApi, ErrorStrategyOption {
                }
            }
        }
        namespace CreateRole {
            interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
            }
            type Body = {
                /**
                 * The name of the project role. Must be unique. Cannot begin or end with whitespace. The maximum length is 255 characters. Required when creating a project role. Optional when partially updating a project role.
                 */
                name: string;
                /**
                 * A description of the project role. Required when fully updating a project role. Optional when creating or partially updating a project role.
                 */
                description?: string;
            };
            namespace Response {
                type OK = ProjectRoleAsResponse;
                type Error = undefined;
            }
            namespace Options {
                interface Base {
                    body: Project.Role.CreateRole.Body;
                }
                interface RawApi extends Base, ConnectionOption, HeadersOption {
                }
                interface HandledApi extends RawApi, ErrorStrategyOption {
                }
            }
        }
        namespace GetRole {
            interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
            }
            namespace Response {
                type OK = ProjectRoleAsResponse;
                type Error = undefined;
            }
            namespace Options {
                interface Base {
                    /**
                     * The ID of the project role. Use [Get all project roles](#api-rest-api-3-role-get) to get a list of project role IDs.
                     */
                    id: number;
                }
                interface RawApi extends Base, ConnectionOption, HeadersOption {
                }
                interface HandledApi extends RawApi, ErrorStrategyOption {
                }
            }
        }
        namespace FullyUpdateRole {
            interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
            }
            type Body = {
                /**
                 * The name of the project role. Must be unique. Cannot begin or end with whitespace. The maximum length is 255 characters. Required when creating a project role. Optional when partially updating a project role.
                 */
                name: string;
                /**
                 * A description of the project role. Required when fully updating a project role. Optional when creating or partially updating a project role.
                 */
                description: string;
            };
            namespace Response {
                type OK = ProjectRoleAsResponse;
                type Error = undefined;
            }
            namespace Options {
                interface Base {
                    /**
                     * The ID of the project role. Use [Get all project roles](#api-rest-api-3-role-get) to get a list of project role IDs.
                     */
                    id?: number;
                    body: Project.Role.FullyUpdateRole.Body;
                }
                interface RawApi extends Base, ConnectionOption, HeadersOption {
                }
                interface HandledApi extends RawApi, ErrorStrategyOption {
                }
            }
        }
        namespace PartiallyUpdateRole {
            interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
            }
            type Body = CreateUpdateRoleRequestBean;
            namespace Response {
                type OK = ProjectRoleAsResponse;
                type Error = undefined;
            }
            namespace Options {
                interface Base {
                    /**
                     * The ID of the project role. Use [Get all project roles](#api-rest-api-3-role-get) to get a list of project role IDs.
                     */
                    id: number;
                    body: Project.Role.PartiallyUpdateRole.Body;
                }
                interface RawApi extends Base, ConnectionOption, HeadersOption {
                }
                interface HandledApi extends RawApi, ErrorStrategyOption {
                }
            }
        }
        namespace DeleteRole {
            interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
            }
            namespace Response {
                type OK = undefined;
                type Error = undefined;
            }
            namespace Options {
                interface Base {
                    /**
                     * The ID of the project role to delete. Use [Get all project roles](#api-rest-api-3-role-get) to get a list of project role IDs.
                     */
                    id: number;
                    /**
                     * The ID of the project role that will replace the one being deleted.
                     */
                    swap?: number;
                }
                interface RawApi extends Base, ConnectionOption, HeadersOption {
                }
                interface HandledApi extends RawApi, ErrorStrategyOption {
                }
            }
        }
    }
    namespace GetStatuses {
        interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
        }
        namespace Response {
            type OK = Array<IssueTypeWithStatusAsResponse>;
            type Error = undefined;
        }
        namespace Options {
            interface Base {
                /**
                 * The project ID or project key (case sensitive).
                 */
                projectIdOrKey: string;
            }
            interface RawApi extends Base, ConnectionOption, HeadersOption {
            }
            interface HandledApi extends RawApi, ErrorStrategyOption {
            }
        }
    }
    namespace Version {
        namespace GetVersionsPaginated {
            interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
            }
            namespace Response {
                type OK = PageBeanVersionAsResponse;
                type Error = undefined;
            }
            namespace Options {
                interface Base {
                    /**
                     * The project ID or project key (case sensitive).
                     */
                    projectIdOrKey: string;
                    /**
                     * The index of the first item to return in a page of results (page offset).
                     */
                    startAt?: number;
                    /**
                     * The maximum number of items to return per page.
                     */
                    maxResults?: number;
                    /**
          * [Order](#ordering) the results by a field:
          
           *  `description` Sorts by version description.
           *  `name` Sorts by version name.
           *  `releaseDate` Sorts by release date, starting with the oldest date. Versions with no release date are listed last.
           *  `sequence` Sorts by the order of appearance in the user interface.
           *  `startDate` Sorts by start date, starting with the oldest date. Versions with no start date are listed last.
          */
                    orderBy?: "description" | "-description" | "+description" | "name" | "-name" | "+name" | "releaseDate" | "-releaseDate" | "+releaseDate" | "sequence" | "-sequence" | "+sequence" | "startDate" | "-startDate" | "+startDate";
                    /**
                     * Filter the results using a literal string. Versions with matching `name` or `description` are returned (case insensitive).
                     */
                    query?: string;
                    /**
                     * A list of status values used to filter the results by version status. This parameter accepts a comma-separated list. The status values are `released`, `unreleased`, and `archived`.
                     */
                    status?: string;
                    /**
          * Use [expand](#expansion) to include additional information in the response. This parameter accepts a comma-separated list. Expand options include:
          
           *  `issuesstatus` Returns the number of issues in each status category for each version.
           *  `operations` Returns actions that can be performed on the specified version.
          */
                    expand?: string;
                }
                interface RawApi extends Base, ConnectionOption, HeadersOption {
                }
                interface HandledApi extends RawApi, ErrorStrategyOption {
                }
            }
        }
        namespace GetVersions {
            interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
            }
            namespace Response {
                type OK = Array<VersionAsResponse>;
                type Error = undefined;
            }
            namespace Options {
                interface Base {
                    /**
                     * The project ID or project key (case sensitive).
                     */
                    projectIdOrKey: string;
                    /**
                     * Use [expand](#expansion) to include additional information in the response. This parameter accepts `operations`, which returns actions that can be performed on the version.
                     */
                    expand?: string;
                }
                interface RawApi extends Base, ConnectionOption, HeadersOption {
                }
                interface HandledApi extends RawApi, ErrorStrategyOption {
                }
            }
        }
        namespace CreateVersion {
            interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
            }
            type Body = {
                /**
        * Use [expand](em>#expansion) to include additional information about version in the response. This parameter accepts a comma-separated list. Expand options include:
        
         *  `operations` Returns the list of operations available for this version.
         *  `issuesstatus` Returns the count of issues in this version for each of the status categories *to do*, *in progress*, *done*, and *unmapped*. The *unmapped* property contains a count of issues with a status other than *to do*, *in progress*, and *done*.
        
        Optional for create and update.
        */
                expand?: string;
                /**
                 * The description of the version. Optional when creating or updating a version.
                 */
                description?: string;
                /**
                 * The unique name of the version. Required when creating a version. Optional when updating a version. The maximum length is 255 characters.
                 */
                name: string;
                /**
                 * Indicates that the version is archived. Optional when creating or updating a version.
                 */
                archived?: boolean;
                /**
                 * The start date of the version. Expressed in ISO 8601 format (yyyy-mm-dd). Optional when creating or updating a version.
                 */
                startDate?: string;
                /**
                 * The release date of the version. Expressed in ISO 8601 format (yyyy-mm-dd). Optional when creating or updating a version.
                 */
                releaseDate?: string;
                /**
                 * The ID of the project to which this version is attached. Required when creating a version. Not applicable when updating a version.
                 */
                projectId: number;
            };
            namespace Response {
                type OK = VersionAsResponse;
                type Error = undefined;
            }
            namespace Options {
                interface Base {
                    body: Project.Version.CreateVersion.Body;
                }
                interface RawApi extends Base, ConnectionOption, HeadersOption {
                }
                interface HandledApi extends RawApi, ErrorStrategyOption {
                }
            }
        }
        namespace GetVersion {
            interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
            }
            namespace Response {
                type OK = VersionAsResponse;
                type Error = undefined;
            }
            namespace Options {
                interface Base {
                    /**
                     * The ID of the version.
                     */
                    id: string;
                    /**
          * Use [expand](#expansion) to include additional information about version in the response. This parameter accepts a comma-separated list. Expand options include:
          
           *  `operations` Returns the list of operations available for this version.
           *  `issuesstatus` Returns the count of issues in this version for each of the status categories *to do*, *in progress*, *done*, and *unmapped*. The *unmapped* property represents the number of issues with a status other than *to do*, *in progress*, and *done*.
          */
                    expand?: string;
                }
                interface RawApi extends Base, ConnectionOption, HeadersOption {
                }
                interface HandledApi extends RawApi, ErrorStrategyOption {
                }
            }
        }
        namespace UpdateVersion {
            interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
            }
            type Body = {
                /**
        * Use [expand](em>#expansion) to include additional information about version in the response. This parameter accepts a comma-separated list. Expand options include:
        
         *  `operations` Returns the list of operations available for this version.
         *  `issuesstatus` Returns the count of issues in this version for each of the status categories *to do*, *in progress*, *done*, and *unmapped*. The *unmapped* property contains a count of issues with a status other than *to do*, *in progress*, and *done*.
        
        Optional for create and update.
        */
                expand?: string;
                /**
                 * The description of the version. Optional when creating or updating a version.
                 */
                description?: string;
                /**
                 * The unique name of the version. Required when creating a version. Optional when updating a version. The maximum length is 255 characters.
                 */
                name?: string;
                /**
                 * Indicates that the version is archived. Optional when creating or updating a version.
                 */
                archived?: boolean;
                /**
                 * Indicates that the version is released. If the version is released a request to release again is ignored. Not applicable when creating a version. Optional when updating a version.
                 */
                released?: boolean;
                /**
                 * The start date of the version. Expressed in ISO 8601 format (yyyy-mm-dd). Optional when creating or updating a version.
                 */
                startDate?: string;
                /**
                 * The release date of the version. Expressed in ISO 8601 format (yyyy-mm-dd). Optional when creating or updating a version.
                 */
                releaseDate?: string;
                /**
                 * The URL of the self link to the version to which all unfixed issues are moved when a version is released. Not applicable when creating a version. Optional when updating a version.
                 */
                moveUnfixedIssuesTo?: string;
            };
            namespace Response {
                type OK = VersionAsResponse;
                type Error = undefined;
            }
            namespace Options {
                interface Base {
                    /**
                     * The ID of the version.
                     */
                    id: string;
                    body: Project.Version.UpdateVersion.Body;
                }
                interface RawApi extends Base, ConnectionOption, HeadersOption {
                }
                interface HandledApi extends RawApi, ErrorStrategyOption {
                }
            }
        }
        namespace MergeVersions {
            interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
            }
            namespace Response {
                type OK = any;
                type Error = undefined;
            }
            namespace Options {
                interface Base {
                    /**
                     * The ID of the version to delete.
                     */
                    id: string;
                    /**
                     * The ID of the version to merge into.
                     */
                    moveIssuesTo: string;
                }
                interface RawApi extends Base, ConnectionOption, HeadersOption {
                }
                interface HandledApi extends RawApi, ErrorStrategyOption {
                }
            }
        }
        namespace MoveVersion {
            interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
            }
            type Body = VersionMoveBean;
            namespace Response {
                type OK = VersionAsResponse;
                type Error = undefined;
            }
            namespace Options {
                interface Base {
                    /**
                     * The ID of the version to be moved.
                     */
                    id: string;
                    body: Project.Version.MoveVersion.Body;
                }
                interface RawApi extends Base, ConnectionOption, HeadersOption {
                }
                interface HandledApi extends RawApi, ErrorStrategyOption {
                }
            }
        }
        namespace Count {
            namespace GetRelatedIssueCount {
                interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
                }
                namespace Response {
                    type OK = VersionIssueCountsAsResponse;
                    type Error = undefined;
                }
                namespace Options {
                    interface Base {
                        /**
                         * The ID of the version.
                         */
                        id: string;
                    }
                    interface RawApi extends Base, ConnectionOption, HeadersOption {
                    }
                    interface HandledApi extends RawApi, ErrorStrategyOption {
                    }
                }
            }
            namespace GetUnresolvedIssueCount {
                interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
                }
                namespace Response {
                    type OK = VersionUnresolvedIssuesCountAsResponse;
                    type Error = undefined;
                }
                namespace Options {
                    interface Base {
                        /**
                         * The ID of the version.
                         */
                        id: string;
                    }
                    interface RawApi extends Base, ConnectionOption, HeadersOption {
                    }
                    interface HandledApi extends RawApi, ErrorStrategyOption {
                    }
                }
            }
        }
        namespace DeleteAndReplaceVersion {
            interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
            }
            type Body = DeleteAndReplaceVersionBean;
            namespace Response {
                type OK = any;
                type Error = undefined;
            }
            namespace Options {
                interface Base {
                    /**
                     * The ID of the version.
                     */
                    id: string;
                    body: Project.Version.DeleteAndReplaceVersion.Body;
                }
                interface RawApi extends Base, ConnectionOption, HeadersOption {
                }
                interface HandledApi extends RawApi, ErrorStrategyOption {
                }
            }
        }
    }
    namespace IssueType {
        namespace GetHierarchy {
            interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
            }
            namespace Response {
                type OK = ProjectIssueTypeHierarchyAsResponse;
                type Error = undefined;
            }
            namespace Options {
                interface Base {
                    /**
                     * The ID of the project.
                     */
                    projectId: number;
                }
                interface RawApi extends Base, ConnectionOption, HeadersOption {
                }
                interface HandledApi extends RawApi, ErrorStrategyOption {
                }
            }
        }
    }
    namespace Validation {
        namespace ValidateProjectKey {
            interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
            }
            namespace Response {
                type OK = ErrorCollectionAsResponse;
                type Error = undefined;
            }
            namespace Options {
                interface Base {
                    /**
                     * The project key.
                     */
                    key: string;
                }
                interface RawApi extends Base, ConnectionOption, HeadersOption {
                }
                interface HandledApi extends RawApi, ErrorStrategyOption {
                }
            }
        }
        namespace GetValidProjectKey {
            interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
            }
            namespace Response {
                type OK = string;
                type Error = undefined;
            }
            namespace Options {
                interface Base {
                    /**
                     * The project key.
                     */
                    key: string;
                }
                interface RawApi extends Base, ConnectionOption, HeadersOption {
                }
                interface HandledApi extends RawApi, ErrorStrategyOption {
                }
            }
        }
        namespace GetValidProjectName {
            interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
            }
            namespace Response {
                type OK = string;
                type Error = undefined;
            }
            namespace Options {
                interface Base {
                    /**
                     * The project name.
                     */
                    name: string;
                }
                interface RawApi extends Base, ConnectionOption, HeadersOption {
                }
                interface HandledApi extends RawApi, ErrorStrategyOption {
                }
            }
        }
    }
    namespace Type {
        namespace GetTypes {
            interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
            }
            namespace Response {
                type OK = Array<ProjectTypeAsResponse>;
                type Error = undefined;
            }
            namespace Options {
                interface Base {
                }
                interface RawApi extends Base, ConnectionOption, HeadersOption {
                }
                interface HandledApi extends RawApi, ErrorStrategyOption {
                }
            }
        }
        namespace GetLicensedTypes {
            interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
            }
            namespace Response {
                type OK = Array<ProjectTypeAsResponse>;
                type Error = undefined;
            }
            namespace Options {
                interface Base {
                }
                interface RawApi extends Base, ConnectionOption, HeadersOption {
                }
                interface HandledApi extends RawApi, ErrorStrategyOption {
                }
            }
        }
        namespace GetTypeByKey {
            interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
            }
            namespace Response {
                type OK = ProjectTypeAsResponse;
                type Error = undefined;
            }
            namespace Options {
                interface Base {
                    /**
                     * The key of the project type.
                     */
                    projectTypeKey: "software" | "service_desk" | "business" | "product_discovery";
                }
                interface RawApi extends Base, ConnectionOption, HeadersOption {
                }
                interface HandledApi extends RawApi, ErrorStrategyOption {
                }
            }
        }
        namespace GetAccessibleTypeByKey {
            interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
            }
            namespace Response {
                type OK = ProjectTypeAsResponse;
                type Error = undefined;
            }
            namespace Options {
                interface Base {
                    /**
                     * The key of the project type.
                     */
                    projectTypeKey: "software" | "service_desk" | "business" | "product_discovery";
                }
                interface RawApi extends Base, ConnectionOption, HeadersOption {
                }
                interface HandledApi extends RawApi, ErrorStrategyOption {
                }
            }
        }
    }
    namespace Category {
        namespace GetCategories {
            interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
            }
            namespace Response {
                type OK = Array<ProjectCategoryAsResponse>;
                type Error = undefined;
            }
            namespace Options {
                interface Base {
                }
                interface RawApi extends Base, ConnectionOption, HeadersOption {
                }
                interface HandledApi extends RawApi, ErrorStrategyOption {
                }
            }
        }
        namespace CreateCategory {
            interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
            }
            type Body = {
                /**
                 * The name of the project category. Required on create, optional on update.
                 */
                name: string;
                /**
                 * The description of the project category.
                 */
                description: string;
            };
            namespace Response {
                type OK = ProjectCategoryAsResponse;
                type Error = undefined;
            }
            namespace Options {
                interface Base {
                    body: Project.Category.CreateCategory.Body;
                }
                interface RawApi extends Base, ConnectionOption, HeadersOption {
                }
                interface HandledApi extends RawApi, ErrorStrategyOption {
                }
            }
        }
        namespace GetCategory {
            interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
            }
            namespace Response {
                type OK = ProjectCategoryAsResponse;
                type Error = undefined;
            }
            namespace Options {
                interface Base {
                    /**
                     * The ID of the project category.
                     */
                    id: number;
                }
                interface RawApi extends Base, ConnectionOption, HeadersOption {
                }
                interface HandledApi extends RawApi, ErrorStrategyOption {
                }
            }
        }
        namespace UpdateCategory {
            interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
            }
            type Body = ProjectCategory;
            namespace Response {
                type OK = UpdatedProjectCategoryAsResponse;
                type Error = undefined;
            }
            namespace Options {
                interface Base {
                    id: number;
                    body: Project.Category.UpdateCategory.Body;
                }
                interface RawApi extends Base, ConnectionOption, HeadersOption {
                }
                interface HandledApi extends RawApi, ErrorStrategyOption {
                }
            }
        }
        namespace DeleteCategory {
            interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
            }
            namespace Response {
                type OK = undefined;
                type Error = undefined;
            }
            namespace Options {
                interface Base {
                    /**
                     * ID of the project category to delete.
                     */
                    id: number;
                }
                interface RawApi extends Base, ConnectionOption, HeadersOption {
                }
                interface HandledApi extends RawApi, ErrorStrategyOption {
                }
            }
        }
    }
    namespace Notification {
        namespace Scheme {
            namespace GetScheme {
                interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
                }
                namespace Response {
                    type OK = NotificationSchemeAsResponse;
                    type Error = undefined;
                }
                namespace Options {
                    interface Base {
                        /**
                         * The project ID or project key (case sensitive).
                         */
                        projectKeyOrId: string;
                        /**
            * Use [expand](#expansion) to include additional information in the response. This parameter accepts a comma-separated list. Expand options include:
            
             *  `all` Returns all expandable information.
             *  `field` Returns information about any custom fields assigned to receive an event.
             *  `group` Returns information about any groups assigned to receive an event.
             *  `notificationSchemeEvents` Returns a list of event associations. This list is returned for all expandable information.
             *  `projectRole` Returns information about any project roles assigned to receive an event.
             *  `user` Returns information about any users assigned to receive an event.
            */
                        expand?: string;
                    }
                    interface RawApi extends Base, ConnectionOption, HeadersOption {
                    }
                    interface HandledApi extends RawApi, ErrorStrategyOption {
                    }
                }
            }
        }
    }
    namespace Permission {
        namespace Scheme {
            namespace AssignScheme {
                interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
                }
                type Body = IdBean;
                namespace Response {
                    type OK = PermissionSchemeAsResponse;
                    type Error = undefined;
                }
                namespace Options {
                    interface Base {
                        /**
                         * The project ID or project key (case sensitive).
                         */
                        projectKeyOrId: string;
                        /**
            * Use [expand](#expansion) to include additional information in the response. This parameter accepts a comma-separated list. Note that permissions are included when you specify any value. Expand options include:
            
             *  `all` Returns all expandable information.
             *  `field` Returns information about the custom field granted the permission.
             *  `group` Returns information about the group that is granted the permission.
             *  `permissions` Returns all permission grants for each permission scheme.
             *  `projectRole` Returns information about the project role granted the permission.
             *  `user` Returns information about the user who is granted the permission.
            */
                        expand?: string;
                        body: Project.Permission.Scheme.AssignScheme.Body;
                    }
                    interface RawApi extends Base, ConnectionOption, HeadersOption {
                    }
                    interface HandledApi extends RawApi, ErrorStrategyOption {
                    }
                }
            }
            namespace GetScheme {
                interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
                }
                namespace Response {
                    type OK = PermissionSchemeAsResponse;
                    type Error = undefined;
                }
                namespace Options {
                    interface Base {
                        /**
                         * The project ID or project key (case sensitive).
                         */
                        projectKeyOrId: string;
                        /**
            * Use [expand](#expansion) to include additional information in the response. This parameter accepts a comma-separated list. Note that permissions are included when you specify any value. Expand options include:
            
             *  `all` Returns all expandable information.
             *  `field` Returns information about the custom field granted the permission.
             *  `group` Returns information about the group that is granted the permission.
             *  `permissions` Returns all permission grants for each permission scheme.
             *  `projectRole` Returns information about the project role granted the permission.
             *  `user` Returns information about the user who is granted the permission.
            */
                        expand?: string;
                    }
                    interface RawApi extends Base, ConnectionOption, HeadersOption {
                    }
                    interface HandledApi extends RawApi, ErrorStrategyOption {
                    }
                }
            }
            namespace GetIssueSecurityLevels {
                interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
                }
                namespace Response {
                    type OK = ProjectIssueSecurityLevelsAsResponse;
                    type Error = undefined;
                }
                namespace Options {
                    interface Base {
                        /**
                         * The project ID or project key (case sensitive).
                         */
                        projectKeyOrId: string;
                    }
                    interface RawApi extends Base, ConnectionOption, HeadersOption {
                    }
                    interface HandledApi extends RawApi, ErrorStrategyOption {
                    }
                }
            }
        }
    }
    namespace Security {
        namespace Scheme {
            namespace GetIssueScheme {
                interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
                }
                namespace Response {
                    type OK = SecuritySchemeAsResponse;
                    type Error = undefined;
                }
                namespace Options {
                    interface Base {
                        /**
                         * The project ID or project key (case sensitive).
                         */
                        projectKeyOrId: string;
                    }
                    interface RawApi extends Base, ConnectionOption, HeadersOption {
                    }
                    interface HandledApi extends RawApi, ErrorStrategyOption {
                    }
                }
            }
        }
    }
    namespace Property {
        namespace GetPropertyKeys {
            interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
            }
            namespace Response {
                type OK = PropertyKeysAsResponse;
                type Error = undefined;
            }
            namespace Options {
                interface Base {
                    /**
                     * The project ID or project key (case sensitive).
                     */
                    projectIdOrKey: string;
                }
                interface RawApi extends Base, ConnectionOption, HeadersOption {
                }
                interface HandledApi extends RawApi, ErrorStrategyOption {
                }
            }
        }
        namespace GetProperty {
            interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
            }
            namespace Response {
                type OK = EntityPropertyAsResponse;
                type Error = undefined;
            }
            namespace Options {
                interface Base {
                    /**
                     * The project ID or project key (case sensitive).
                     */
                    projectIdOrKey: string;
                    /**
                     * The project property key. Use [Get project property keys](#api-rest-api-3-project-projectIdOrKey-properties-get) to get a list of all project property keys.
                     */
                    propertyKey: string;
                }
                interface RawApi extends Base, ConnectionOption, HeadersOption {
                }
                interface HandledApi extends RawApi, ErrorStrategyOption {
                }
            }
        }
        namespace SetProperty {
            interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
            }
            type Body = any;
            namespace Response {
                type OK = any;
                type Error = undefined;
            }
            namespace Options {
                interface Base {
                    /**
                     * The project ID or project key (case sensitive).
                     */
                    projectIdOrKey: string;
                    /**
                     * The key of the project property. The maximum length is 255 characters.
                     */
                    propertyKey: string;
                    body: Project.Property.SetProperty.Body;
                }
                interface RawApi extends Base, ConnectionOption, HeadersOption {
                }
                interface HandledApi extends RawApi, ErrorStrategyOption {
                }
            }
        }
        namespace DeleteProperty {
            interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
            }
            namespace Response {
                type OK = undefined;
                type Error = undefined;
            }
            namespace Options {
                interface Base {
                    /**
                     * The project ID or project key (case sensitive).
                     */
                    projectIdOrKey: string;
                    /**
                     * The project property key. Use [Get project property keys](#api-rest-api-3-project-projectIdOrKey-properties-get) to get a list of all project property keys.
                     */
                    propertyKey: string;
                }
                interface RawApi extends Base, ConnectionOption, HeadersOption {
                }
                interface HandledApi extends RawApi, ErrorStrategyOption {
                }
            }
        }
    }
}
//# sourceMappingURL=project.d.ts.map