import { PageBeanScreenSchemeAsResponse } from "../definitions/PageBeanScreenSchemeAsResponse";
import { HeadersOption, ConnectionOption } from "@avst-api/commons";
import { AssistedErrorStrategyOption } from "../handled-api/common";
import { ErrorStrategyOption } from "../handled-api/common";
import { ScreenSchemeDetails } from "../definitions/ScreenSchemeDetails";
import { ScreenSchemeIdAsResponse } from "../definitions/ScreenSchemeIdAsResponse";
import { UpdateScreenSchemeDetails } from "../definitions/UpdateScreenSchemeDetails";
import { PageBeanScreenWithTabAsResponse } from "../definitions/PageBeanScreenWithTabAsResponse";
import { PageBeanScreenAsResponse } from "../definitions/PageBeanScreenAsResponse";
import { ScreenDetails } from "../definitions/ScreenDetails";
import { ScreenAsResponse } from "../definitions/ScreenAsResponse";
import { ScreenableFieldAsResponse } from "../definitions/ScreenableFieldAsResponse";
import { ScreenableTabAsResponse } from "../definitions/ScreenableTabAsResponse";
import { ScreenableTab } from "../definitions/ScreenableTab";
import { AddFieldBean } from "../definitions/AddFieldBean";
import { MoveFieldBean } from "../definitions/MoveFieldBean";
import { UpdateScreenDetails } from "../definitions/UpdateScreenDetails";
export declare namespace Screen {
    namespace Scheme {
        namespace GetSchemes {
            interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
            }
            namespace Response {
                type OK = PageBeanScreenSchemeAsResponse;
                type Error = undefined;
            }
            namespace Options {
                interface Base {
                    /**
                     * The index of the first item to return in a page of results (page offset).
                     */
                    startAt?: number;
                    /**
                     * The maximum number of items to return per page.
                     */
                    maxResults?: number;
                    /**
                     * The list of screen scheme IDs. To include multiple IDs, provide an ampersand-separated list. For example, `id=10000&id=10001`.
                     */
                    id?: Array<number>;
                }
                interface RawApi extends Base, ConnectionOption, HeadersOption {
                }
                interface HandledApi extends RawApi, ErrorStrategyOption {
                }
            }
        }
        namespace CreateScheme {
            interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
            }
            type Body = ScreenSchemeDetails;
            namespace Response {
                type OK = ScreenSchemeIdAsResponse;
                type Error = undefined;
            }
            namespace Options {
                interface Base {
                    body: Screen.Scheme.CreateScheme.Body;
                }
                interface RawApi extends Base, ConnectionOption, HeadersOption {
                }
                interface HandledApi extends RawApi, ErrorStrategyOption {
                }
            }
        }
        namespace UpdateScheme {
            interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
            }
            type Body = UpdateScreenSchemeDetails;
            namespace Response {
                type OK = any;
                type Error = undefined;
            }
            namespace Options {
                interface Base {
                    /**
                     * The ID of the screen scheme.
                     */
                    screenSchemeId: string;
                    body: Screen.Scheme.UpdateScheme.Body;
                }
                interface RawApi extends Base, ConnectionOption, HeadersOption {
                }
                interface HandledApi extends RawApi, ErrorStrategyOption {
                }
            }
        }
        namespace DeleteScheme {
            interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
            }
            namespace Response {
                type OK = undefined;
                type Error = undefined;
            }
            namespace Options {
                interface Base {
                    /**
                     * The ID of the screen scheme.
                     */
                    screenSchemeId: string;
                }
                interface RawApi extends Base, ConnectionOption, HeadersOption {
                }
                interface HandledApi extends RawApi, ErrorStrategyOption {
                }
            }
        }
    }
    namespace GetScreensForField {
        interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
        }
        namespace Response {
            type OK = PageBeanScreenWithTabAsResponse;
            type Error = undefined;
        }
        namespace Options {
            interface Base {
                /**
                 * The ID of the field to return screens for.
                 */
                fieldId: string;
                /**
                 * The index of the first item to return in a page of results (page offset).
                 */
                startAt?: number;
                /**
                 * The maximum number of items to return per page.
                 */
                maxResults?: number;
                /**
                 * Use [expand](#expansion) to include additional information about screens in the response. This parameter accepts `tab` which returns details about the screen tabs the field is used in.
                 */
                expand?: string;
            }
            interface RawApi extends Base, ConnectionOption, HeadersOption {
            }
            interface HandledApi extends RawApi, ErrorStrategyOption {
            }
        }
    }
    namespace GetScreens {
        interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
        }
        namespace Response {
            type OK = PageBeanScreenAsResponse;
            type Error = undefined;
        }
        namespace Options {
            interface Base {
                /**
                 * The index of the first item to return in a page of results (page offset).
                 */
                startAt?: number;
                /**
                 * The maximum number of items to return per page.
                 */
                maxResults?: number;
                /**
                 * The list of screen IDs. To include multiple IDs, provide an ampersand-separated list. For example, `id=10000&id=10001`.
                 */
                id?: Array<number>;
            }
            interface RawApi extends Base, ConnectionOption, HeadersOption {
            }
            interface HandledApi extends RawApi, ErrorStrategyOption {
            }
        }
    }
    namespace CreateScreen {
        interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
        }
        type Body = ScreenDetails;
        namespace Response {
            type OK = ScreenAsResponse;
            type Error = undefined;
        }
        namespace Options {
            interface Base {
                body: Screen.CreateScreen.Body;
            }
            interface RawApi extends Base, ConnectionOption, HeadersOption {
            }
            interface HandledApi extends RawApi, ErrorStrategyOption {
            }
        }
    }
    namespace AddFieldToDefaultScreen {
        interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
        }
        namespace Response {
            type OK = "CREATED";
            type Error = undefined;
        }
        namespace Options {
            interface Base {
                /**
                 * The ID of the field.
                 */
                fieldId: string;
            }
            interface RawApi extends Base, ConnectionOption, HeadersOption {
            }
            interface HandledApi extends RawApi, ErrorStrategyOption {
            }
        }
    }
    namespace GetAvailableScreenFields {
        interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
        }
        namespace Response {
            type OK = Array<ScreenableFieldAsResponse>;
            type Error = undefined;
        }
        namespace Options {
            interface Base {
                /**
                 * The ID of the screen.
                 */
                screenId: number;
            }
            interface RawApi extends Base, ConnectionOption, HeadersOption {
            }
            interface HandledApi extends RawApi, ErrorStrategyOption {
            }
        }
    }
    namespace Tab {
        namespace GetTabs {
            interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
            }
            namespace Response {
                type OK = Array<ScreenableTabAsResponse>;
                type Error = undefined;
            }
            namespace Options {
                interface Base {
                    /**
                     * The ID of the screen.
                     */
                    screenId: number;
                    /**
                     * The key of the project.
                     */
                    projectKey?: string;
                }
                interface RawApi extends Base, ConnectionOption, HeadersOption {
                }
                interface HandledApi extends RawApi, ErrorStrategyOption {
                }
            }
        }
        namespace CreateTab {
            interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
            }
            type Body = ScreenableTab;
            namespace Response {
                type OK = ScreenableTabAsResponse;
                type Error = undefined;
            }
            namespace Options {
                interface Base {
                    /**
                     * The ID of the screen.
                     */
                    screenId: number;
                    body: Screen.Tab.CreateTab.Body;
                }
                interface RawApi extends Base, ConnectionOption, HeadersOption {
                }
                interface HandledApi extends RawApi, ErrorStrategyOption {
                }
            }
        }
        namespace UpdateTab {
            interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
            }
            type Body = ScreenableTab;
            namespace Response {
                type OK = ScreenableTabAsResponse;
                type Error = undefined;
            }
            namespace Options {
                interface Base {
                    /**
                     * The ID of the screen.
                     */
                    screenId: number;
                    /**
                     * The ID of the screen tab.
                     */
                    tabId: number;
                    body: Screen.Tab.UpdateTab.Body;
                }
                interface RawApi extends Base, ConnectionOption, HeadersOption {
                }
                interface HandledApi extends RawApi, ErrorStrategyOption {
                }
            }
        }
        namespace DeleteTab {
            interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
            }
            namespace Response {
                type OK = undefined;
                type Error = undefined;
            }
            namespace Options {
                interface Base {
                    /**
                     * The ID of the screen.
                     */
                    screenId: number;
                    /**
                     * The ID of the screen tab.
                     */
                    tabId: number;
                }
                interface RawApi extends Base, ConnectionOption, HeadersOption {
                }
                interface HandledApi extends RawApi, ErrorStrategyOption {
                }
            }
        }
        namespace Field {
            namespace GetFields {
                interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
                }
                namespace Response {
                    type OK = Array<ScreenableFieldAsResponse>;
                    type Error = undefined;
                }
                namespace Options {
                    interface Base {
                        /**
                         * The ID of the screen.
                         */
                        screenId: number;
                        /**
                         * The ID of the screen tab.
                         */
                        tabId: number;
                        /**
                         * The key of the project.
                         */
                        projectKey?: string;
                    }
                    interface RawApi extends Base, ConnectionOption, HeadersOption {
                    }
                    interface HandledApi extends RawApi, ErrorStrategyOption {
                    }
                }
            }
            namespace AddField {
                interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
                }
                type Body = AddFieldBean;
                namespace Response {
                    type OK = ScreenableFieldAsResponse;
                    type Error = undefined;
                }
                namespace Options {
                    interface Base {
                        /**
                         * The ID of the screen.
                         */
                        screenId: number;
                        /**
                         * The ID of the screen tab.
                         */
                        tabId: number;
                        body: Screen.Tab.Field.AddField.Body;
                    }
                    interface RawApi extends Base, ConnectionOption, HeadersOption {
                    }
                    interface HandledApi extends RawApi, ErrorStrategyOption {
                    }
                }
            }
            namespace RemoveField {
                interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
                }
                namespace Response {
                    type OK = undefined;
                    type Error = undefined;
                }
                namespace Options {
                    interface Base {
                        /**
                         * The ID of the screen.
                         */
                        screenId: number;
                        /**
                         * The ID of the screen tab.
                         */
                        tabId: number;
                        /**
                         * The ID of the field.
                         */
                        id: string;
                    }
                    interface RawApi extends Base, ConnectionOption, HeadersOption {
                    }
                    interface HandledApi extends RawApi, ErrorStrategyOption {
                    }
                }
            }
            namespace MoveField {
                interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
                }
                type Body = MoveFieldBean;
                namespace Response {
                    type OK = any;
                    type Error = undefined;
                }
                namespace Options {
                    interface Base {
                        /**
                         * The ID of the screen.
                         */
                        screenId: number;
                        /**
                         * The ID of the screen tab.
                         */
                        tabId: number;
                        /**
                         * The ID of the field.
                         */
                        id: string;
                        body: Screen.Tab.Field.MoveField.Body;
                    }
                    interface RawApi extends Base, ConnectionOption, HeadersOption {
                    }
                    interface HandledApi extends RawApi, ErrorStrategyOption {
                    }
                }
            }
        }
        namespace MoveTab {
            interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
            }
            namespace Response {
                type OK = any;
                type Error = undefined;
            }
            namespace Options {
                interface Base {
                    /**
                     * The ID of the screen.
                     */
                    screenId: number;
                    /**
                     * The ID of the screen tab.
                     */
                    tabId: number;
                    /**
                     * The position of tab. The base index is 0.
                     */
                    pos: number;
                }
                interface RawApi extends Base, ConnectionOption, HeadersOption {
                }
                interface HandledApi extends RawApi, ErrorStrategyOption {
                }
            }
        }
    }
    namespace UpdateScreen {
        interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
        }
        type Body = UpdateScreenDetails;
        namespace Response {
            type OK = ScreenAsResponse;
            type Error = undefined;
        }
        namespace Options {
            interface Base {
                /**
                 * The ID of the screen.
                 */
                screenId: number;
                body: Screen.UpdateScreen.Body;
            }
            interface RawApi extends Base, ConnectionOption, HeadersOption {
            }
            interface HandledApi extends RawApi, ErrorStrategyOption {
            }
        }
    }
    namespace DeleteScreen {
        interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
        }
        namespace Response {
            type OK = undefined;
            type Error = undefined;
        }
        namespace Options {
            interface Base {
                /**
                 * The ID of the screen.
                 */
                screenId: number;
            }
            interface RawApi extends Base, ConnectionOption, HeadersOption {
            }
            interface HandledApi extends RawApi, ErrorStrategyOption {
            }
        }
    }
}
//# sourceMappingURL=screen.d.ts.map